"""
Action enums.
"""

# pylint: disable=too-many-public-methods, unused-import

import typing as t

import typing_extensions as te  # noqa: F401

from composio.client.enums.base import (
    ACTIONS_CACHE,
    ActionData,
    _AnnotatedEnum,
    add_runtime_action,
    enum,
)


class SentinalObject:
    """Sentinal object."""

    sentinal = None


@enum
class Action(_AnnotatedEnum[ActionData], path=ACTIONS_CACHE):
    """Class to represent `Action` entity."""

    APIFY_CREATE_APIFY_ACTOR: "Action"
    APIFY_GET_ACTOR_ID: "Action"
    APIFY_GET_LAST_RUN_DATA: "Action"
    APIFY_LIST_APIFY_ACTORS: "Action"
    APIFY_LIST_APIFY_TASKS: "Action"
    APIFY_SEARCH_STORE: "Action"
    ASANA_ADD_A_COLLABORATOR_TO_A_GOAL: "Action"
    ASANA_ADD_A_CUSTOM_FIELD_TO_A_PORTFOLIO: "Action"
    ASANA_ADD_A_CUSTOM_FIELD_TO_A_PROJECT: "Action"
    ASANA_ADD_A_PORTFOLIO_ITEM: "Action"
    ASANA_ADD_A_PROJECT_TO_A_TASK: "Action"
    ASANA_ADD_A_SUPPORTING_GOAL_RELATIONSHIP: "Action"
    ASANA_ADD_A_TAG_TO_A_TASK: "Action"
    ASANA_ADD_A_USER_TO_A_TEAM: "Action"
    ASANA_ADD_A_USER_TO_A_WORKSPACE_OR_ORGANIZATION: "Action"
    ASANA_ADD_FOLLOWERS_TO_A_PROJECT: "Action"
    ASANA_ADD_FOLLOWERS_TO_A_TASK: "Action"
    ASANA_ADD_TASK_TO_SECTION: "Action"
    ASANA_ADD_USERS_TO_A_PORTFOLIO: "Action"
    ASANA_ADD_USERS_TO_A_PROJECT: "Action"
    ASANA_CREATE_AN_ALLOCATION: "Action"
    ASANA_CREATE_AN_ENUM_OPTION: "Action"
    ASANA_CREATE_AN_ORGANIZATION_EXPORT_REQUEST: "Action"
    ASANA_CREATE_A_CUSTOM_FIELD: "Action"
    ASANA_CREATE_A_GOAL: "Action"
    ASANA_CREATE_A_GOAL_METRIC: "Action"
    ASANA_CREATE_A_MEMBERSHIP: "Action"
    ASANA_CREATE_A_PORTFOLIO: "Action"
    ASANA_CREATE_A_PROJECT: "Action"
    ASANA_CREATE_A_PROJECT_BRIEF: "Action"
    ASANA_CREATE_A_PROJECT_IN_A_TEAM: "Action"
    ASANA_CREATE_A_PROJECT_IN_A_WORKSPACE: "Action"
    ASANA_CREATE_A_PROJECT_STATUS: "Action"
    ASANA_CREATE_A_PROJECT_TEMPLATE_FROM_A_PROJECT: "Action"
    ASANA_CREATE_A_SECTION_IN_A_PROJECT: "Action"
    ASANA_CREATE_A_STATUS_UPDATE: "Action"
    ASANA_CREATE_A_STORY_ON_A_TASK: "Action"
    ASANA_CREATE_A_SUBTASK: "Action"
    ASANA_CREATE_A_TAG: "Action"
    ASANA_CREATE_A_TAG_IN_A_WORKSPACE: "Action"
    ASANA_CREATE_A_TASK: "Action"
    ASANA_CREATE_A_TEAM: "Action"
    ASANA_CREATE_A_TIME_TRACKING_ENTRY: "Action"
    ASANA_DELETE_AN_ALLOCATION: "Action"
    ASANA_DELETE_AN_ATTACHMENT: "Action"
    ASANA_DELETE_A_CUSTOM_FIELD: "Action"
    ASANA_DELETE_A_GOAL: "Action"
    ASANA_DELETE_A_MEMBERSHIP: "Action"
    ASANA_DELETE_A_PORTFOLIO: "Action"
    ASANA_DELETE_A_PROJECT: "Action"
    ASANA_DELETE_A_PROJECT_BRIEF: "Action"
    ASANA_DELETE_A_PROJECT_STATUS: "Action"
    ASANA_DELETE_A_PROJECT_TEMPLATE: "Action"
    ASANA_DELETE_A_SECTION: "Action"
    ASANA_DELETE_A_STATUS_UPDATE: "Action"
    ASANA_DELETE_A_STORY: "Action"
    ASANA_DELETE_A_TAG: "Action"
    ASANA_DELETE_A_TASK: "Action"
    ASANA_DELETE_A_TASK_TEMPLATE: "Action"
    ASANA_DELETE_A_TIME_TRACKING_ENTRY: "Action"
    ASANA_DELETE_A_WEBHOOK: "Action"
    ASANA_DUPLICATE_A_PROJECT: "Action"
    ASANA_DUPLICATE_A_TASK: "Action"
    ASANA_ESTABLISH_A_WEBHOOK: "Action"
    ASANA_GET_ALL_PROJECTS_IN_A_WORKSPACE: "Action"
    ASANA_GET_AN_ALLOCATION: "Action"
    ASANA_GET_AN_ATTACHMENT: "Action"
    ASANA_GET_ATTACHMENTS_FROM_AN_OBJECT: "Action"
    ASANA_GET_AUDIT_LOG_EVENTS: "Action"
    ASANA_GET_A_CUSTOM_FIELD: "Action"
    ASANA_GET_A_GOAL: "Action"
    ASANA_GET_A_GOAL_RELATIONSHIP: "Action"
    ASANA_GET_A_JOB_BY_ID: "Action"
    ASANA_GET_A_MEMBERSHIP: "Action"
    ASANA_GET_A_PORTFOLIO: "Action"
    ASANA_GET_A_PORTFOLIO_MEMBERSHIP: "Action"
    ASANA_GET_A_PORTFOLIO_S_CUSTOM_FIELDS: "Action"
    ASANA_GET_A_PROJECT: "Action"
    ASANA_GET_A_PROJECT_BRIEF: "Action"
    ASANA_GET_A_PROJECT_MEMBERSHIP: "Action"
    ASANA_GET_A_PROJECT_STATUS: "Action"
    ASANA_GET_A_PROJECT_S_CUSTOM_FIELDS: "Action"
    ASANA_GET_A_PROJECT_TEMPLATE: "Action"
    ASANA_GET_A_SECTION: "Action"
    ASANA_GET_A_STATUS_UPDATE: "Action"
    ASANA_GET_A_STORY: "Action"
    ASANA_GET_A_TAG: "Action"
    ASANA_GET_A_TASK: "Action"
    ASANA_GET_A_TASK_FOR_A_GIVEN_CUSTOM_ID: "Action"
    ASANA_GET_A_TASK_S_TAGS: "Action"
    ASANA_GET_A_TASK_TEMPLATE: "Action"
    ASANA_GET_A_TEAM: "Action"
    ASANA_GET_A_TEAM_MEMBERSHIP: "Action"
    ASANA_GET_A_TEAM_S_PROJECTS: "Action"
    ASANA_GET_A_TEAM_S_PROJECT_TEMPLATES: "Action"
    ASANA_GET_A_TIME_PERIOD: "Action"
    ASANA_GET_A_TIME_TRACKING_ENTRY: "Action"
    ASANA_GET_A_USER: "Action"
    ASANA_GET_A_USER_S_FAVORITES: "Action"
    ASANA_GET_A_USER_S_TASK_LIST: "Action"
    ASANA_GET_A_USER_TASK_LIST: "Action"
    ASANA_GET_A_WEBHOOK: "Action"
    ASANA_GET_A_WORKSPACE: "Action"
    ASANA_GET_A_WORKSPACE_MEMBERSHIP: "Action"
    ASANA_GET_A_WORKSPACE_S_CUSTOM_FIELDS: "Action"
    ASANA_GET_DEPENDENCIES_FROM_A_TASK: "Action"
    ASANA_GET_DEPENDENTS_FROM_A_TASK: "Action"
    ASANA_GET_DETAILS_ON_AN_ORG_EXPORT_REQUEST: "Action"
    ASANA_GET_EVENTS_ON_A_RESOURCE: "Action"
    ASANA_GET_GOALS: "Action"
    ASANA_GET_GOAL_RELATIONSHIPS: "Action"
    ASANA_GET_MEMBERSHIPS_FROM_A_PORTFOLIO: "Action"
    ASANA_GET_MEMBERSHIPS_FROM_A_PROJECT: "Action"
    ASANA_GET_MEMBERSHIPS_FROM_A_TEAM: "Action"
    ASANA_GET_MEMBERSHIPS_FROM_A_USER: "Action"
    ASANA_GET_MULTIPLE_ALLOCATIONS: "Action"
    ASANA_GET_MULTIPLE_MEMBERSHIPS: "Action"
    ASANA_GET_MULTIPLE_PORTFOLIOS: "Action"
    ASANA_GET_MULTIPLE_PORTFOLIO_MEMBERSHIPS: "Action"
    ASANA_GET_MULTIPLE_PROJECTS: "Action"
    ASANA_GET_MULTIPLE_PROJECT_TEMPLATES: "Action"
    ASANA_GET_MULTIPLE_TAGS: "Action"
    ASANA_GET_MULTIPLE_TASKS: "Action"
    ASANA_GET_MULTIPLE_TASK_TEMPLATES: "Action"
    ASANA_GET_MULTIPLE_USERS: "Action"
    ASANA_GET_MULTIPLE_WEBHOOKS: "Action"
    ASANA_GET_MULTIPLE_WORKSPACES: "Action"
    ASANA_GET_OBJECTS_VIA_TYPEAHEAD: "Action"
    ASANA_GET_PARENT_GOALS_FROM_A_GOAL: "Action"
    ASANA_GET_PORTFOLIO_ITEMS: "Action"
    ASANA_GET_PROJECTS_A_TASK_IS_IN: "Action"
    ASANA_GET_SECTIONS_IN_A_PROJECT: "Action"
    ASANA_GET_STATUSES_FROM_A_PROJECT: "Action"
    ASANA_GET_STATUS_UPDATES_FROM_AN_OBJECT: "Action"
    ASANA_GET_STORIES_FROM_A_TASK: "Action"
    ASANA_GET_SUBTASKS_FROM_A_TASK: "Action"
    ASANA_GET_TAGS_IN_A_WORKSPACE: "Action"
    ASANA_GET_TASKS_FROM_A_PROJECT: "Action"
    ASANA_GET_TASKS_FROM_A_SECTION: "Action"
    ASANA_GET_TASKS_FROM_A_TAG: "Action"
    ASANA_GET_TASKS_FROM_A_USER_TASK_LIST: "Action"
    ASANA_GET_TASK_COUNT_OF_A_PROJECT: "Action"
    ASANA_GET_TEAMS_FOR_A_USER: "Action"
    ASANA_GET_TEAMS_IN_A_WORKSPACE: "Action"
    ASANA_GET_TEAM_MEMBERSHIPS: "Action"
    ASANA_GET_THE_WORKSPACE_MEMBERSHIPS_FOR_A_WORKSPACE: "Action"
    ASANA_GET_TIME_PERIODS: "Action"
    ASANA_GET_TIME_TRACKING_ENTRIES_FOR_A_TASK: "Action"
    ASANA_GET_USERS_IN_A_TEAM: "Action"
    ASANA_GET_USERS_IN_A_WORKSPACE_OR_ORGANIZATION: "Action"
    ASANA_GET_WORKSPACE_MEMBERSHIPS_FOR_A_USER: "Action"
    ASANA_INSTANTIATE_A_PROJECT_FROM_A_PROJECT_TEMPLATE: "Action"
    ASANA_INSTANTIATE_A_TASK_FROM_A_TASK_TEMPLATE: "Action"
    ASANA_MOVE_OR_INSERT_SECTIONS: "Action"
    ASANA_REMOVES_A_SUPPORTING_GOAL_RELATIONSHIP: "Action"
    ASANA_REMOVE_A_COLLABORATOR_FROM_A_GOAL: "Action"
    ASANA_REMOVE_A_CUSTOM_FIELD_FROM_A_PORTFOLIO: "Action"
    ASANA_REMOVE_A_CUSTOM_FIELD_FROM_A_PROJECT: "Action"
    ASANA_REMOVE_A_PORTFOLIO_ITEM: "Action"
    ASANA_REMOVE_A_PROJECT_FROM_A_TASK: "Action"
    ASANA_REMOVE_A_TAG_FROM_A_TASK: "Action"
    ASANA_REMOVE_A_USER_FROM_A_TEAM: "Action"
    ASANA_REMOVE_A_USER_FROM_A_WORKSPACE_OR_ORGANIZATION: "Action"
    ASANA_REMOVE_FOLLOWERS_FROM_A_PROJECT: "Action"
    ASANA_REMOVE_FOLLOWERS_FROM_A_TASK: "Action"
    ASANA_REMOVE_USERS_FROM_A_PORTFOLIO: "Action"
    ASANA_REMOVE_USERS_FROM_A_PROJECT: "Action"
    ASANA_REORDER_A_CUSTOM_FIELD_S_ENUM: "Action"
    ASANA_SEARCH_TASKS_IN_A_WORKSPACE: "Action"
    ASANA_SET_DEPENDENCIES_FOR_A_TASK: "Action"
    ASANA_SET_DEPENDENTS_FOR_A_TASK: "Action"
    ASANA_SET_THE_PARENT_OF_A_TASK: "Action"
    ASANA_SUBMIT_PARALLEL_REQUESTS: "Action"
    ASANA_TRIGGER_A_RULE: "Action"
    ASANA_UNLINK_DEPENDENCIES_FROM_A_TASK: "Action"
    ASANA_UNLINK_DEPENDENTS_FROM_A_TASK: "Action"
    ASANA_UPDATE_AN_ALLOCATION: "Action"
    ASANA_UPDATE_AN_ENUM_OPTION: "Action"
    ASANA_UPDATE_A_CUSTOM_FIELD: "Action"
    ASANA_UPDATE_A_GOAL: "Action"
    ASANA_UPDATE_A_GOAL_METRIC: "Action"
    ASANA_UPDATE_A_GOAL_RELATIONSHIP: "Action"
    ASANA_UPDATE_A_MEMBERSHIP: "Action"
    ASANA_UPDATE_A_PORTFOLIO: "Action"
    ASANA_UPDATE_A_PROJECT: "Action"
    ASANA_UPDATE_A_PROJECT_BRIEF: "Action"
    ASANA_UPDATE_A_SECTION: "Action"
    ASANA_UPDATE_A_STORY: "Action"
    ASANA_UPDATE_A_TAG: "Action"
    ASANA_UPDATE_A_TASK: "Action"
    ASANA_UPDATE_A_TEAM: "Action"
    ASANA_UPDATE_A_TIME_TRACKING_ENTRY: "Action"
    ASANA_UPDATE_A_WEBHOOK: "Action"
    ASANA_UPDATE_A_WORKSPACE: "Action"
    ASANA_UPLOAD_AN_ATTACHMENT: "Action"
    ATTIO_ASSERT_A_LIST_ENTRY_BY_PARENT: "Action"
    ATTIO_ASSERT_A_RECORD: "Action"
    ATTIO_CREATE_AN_ATTRIBUTE: "Action"
    ATTIO_CREATE_AN_ENTRY_ADD_RECORD_TO_LIST: "Action"
    ATTIO_CREATE_AN_OBJECT: "Action"
    ATTIO_CREATE_A_COMMENT: "Action"
    ATTIO_CREATE_A_LIST: "Action"
    ATTIO_CREATE_A_NOTE: "Action"
    ATTIO_CREATE_A_RECORD: "Action"
    ATTIO_CREATE_A_SELECT_OPTION: "Action"
    ATTIO_CREATE_A_STATUS: "Action"
    ATTIO_CREATE_A_TASK: "Action"
    ATTIO_CREATE_A_WEBHOOK: "Action"
    ATTIO_DELETE_A_COMMENT: "Action"
    ATTIO_DELETE_A_LIST_ENTRY: "Action"
    ATTIO_DELETE_A_NOTE: "Action"
    ATTIO_DELETE_A_RECORD: "Action"
    ATTIO_DELETE_A_TASK: "Action"
    ATTIO_DELETE_A_WEBHOOK: "Action"
    ATTIO_GET_AN_ATTRIBUTE: "Action"
    ATTIO_GET_AN_OBJECT: "Action"
    ATTIO_GET_A_COMMENT: "Action"
    ATTIO_GET_A_LIST: "Action"
    ATTIO_GET_A_LIST_ENTRY: "Action"
    ATTIO_GET_A_NOTE: "Action"
    ATTIO_GET_A_RECORD: "Action"
    ATTIO_GET_A_TASK: "Action"
    ATTIO_GET_A_THREAD: "Action"
    ATTIO_GET_A_WEBHOOK: "Action"
    ATTIO_GET_A_WORKSPACE_MEMBER: "Action"
    ATTIO_IDENTIFY: "Action"
    ATTIO_LIST_ALL_LISTS: "Action"
    ATTIO_LIST_ATTRIBUTES: "Action"
    ATTIO_LIST_ATTRIBUTE_VALUES_FOR_A_LIST_ENTRY: "Action"
    ATTIO_LIST_ENTRIES: "Action"
    ATTIO_LIST_NOTES: "Action"
    ATTIO_LIST_OBJECTS: "Action"
    ATTIO_LIST_RECORDS: "Action"
    ATTIO_LIST_RECORD_ATTRIBUTE_VALUES: "Action"
    ATTIO_LIST_RECORD_ENTRIES: "Action"
    ATTIO_LIST_SELECT_OPTIONS: "Action"
    ATTIO_LIST_STATUSES: "Action"
    ATTIO_LIST_TASKS: "Action"
    ATTIO_LIST_THREADS: "Action"
    ATTIO_LIST_WEBHOOKS: "Action"
    ATTIO_LIST_WORKSPACE_MEMBERS: "Action"
    ATTIO_UPDATE_AN_ATTRIBUTE: "Action"
    ATTIO_UPDATE_AN_OBJECT: "Action"
    ATTIO_UPDATE_A_LIST: "Action"
    ATTIO_UPDATE_A_LIST_ENTRY_APPEND_MULTISELECT_VALUES: "Action"
    ATTIO_UPDATE_A_LIST_ENTRY_OVERWRITE_MULTISELECT_VALUES: "Action"
    ATTIO_UPDATE_A_RECORD: "Action"
    ATTIO_UPDATE_A_SELECT_OPTION: "Action"
    ATTIO_UPDATE_A_STATUS: "Action"
    ATTIO_UPDATE_A_TASK: "Action"
    ATTIO_UPDATE_A_WEBHOOK: "Action"
    BREVO_ACTIVATE_THE_E_COMMERCE_APP: "Action"
    BREVO_ADD_A_NEW_DOMAIN_TO_THE_LIST_OF_BLOCKED_DOMAINS: "Action"
    BREVO_ADD_EMAIL_AND_OR_SMS_CREDITS_TO_A_SPECIFIC_CHILD_ACCOUNT: "Action"
    BREVO_ADD_EXISTING_CONTACTS_TO_A_LIST: "Action"
    BREVO_AGGREGATE_EMAIL_ACTIVITY: "Action"
    BREVO_ASSOCIATE_A_DEDICATED_IP_TO_THE_CHILD: "Action"
    BREVO_AUTHENTICATE_A_DOMAIN: "Action"
    BREVO_CHECK_ADMIN_USER_PERMISSIONS: "Action"
    BREVO_CHECK_RESELLER_CHILD_ACCOUNT_CREATION_STATUS: "Action"
    BREVO_CHECK_USER_PERMISSION: "Action"
    BREVO_CREATES_AN_SMS_CAMPAIGN: "Action"
    BREVO_CREATES_A_RESELLER_CHILD: "Action"
    BREVO_CREATE_AND_SEND_A_WHATS_APP_CAMPAIGN: "Action"
    BREVO_CREATE_AN_API_KEY_FOR_A_SUB_ACCOUNT: "Action"
    BREVO_CREATE_AN_EMAIL_CAMPAIGN: "Action"
    BREVO_CREATE_AN_EMAIL_TEMPLATE: "Action"
    BREVO_CREATE_AN_EVENT: "Action"
    BREVO_CREATE_AN_EXTERNAL_FEED: "Action"
    BREVO_CREATE_A_COMPANY: "Action"
    BREVO_CREATE_A_CONTACT: "Action"
    BREVO_CREATE_A_COUPON_COLLECTION: "Action"
    BREVO_CREATE_A_DEAL: "Action"
    BREVO_CREATE_A_DOMAIN_FOR_A_CHILD_ACCOUNT: "Action"
    BREVO_CREATE_A_FOLDER: "Action"
    BREVO_CREATE_A_GROUP_OF_SUB_ACCOUNTS: "Action"
    BREVO_CREATE_A_LIST: "Action"
    BREVO_CREATE_A_NEW_DOMAIN: "Action"
    BREVO_CREATE_A_NEW_SENDER: "Action"
    BREVO_CREATE_A_NEW_SUB_ACCOUNT_UNDER_A_MASTER_ACCOUNT: "Action"
    BREVO_CREATE_A_NOTE: "Action"
    BREVO_CREATE_A_TASK: "Action"
    BREVO_CREATE_A_WEBHOOK: "Action"
    BREVO_CREATE_A_WHATS_APP_TEMPLATE: "Action"
    BREVO_CREATE_CATEGORIES_IN_BATCH: "Action"
    BREVO_CREATE_CONTACT_ATTRIBUTE: "Action"
    BREVO_CREATE_CONTACT_VIA_DOI_DOUBLE_OPT_IN_FLOW: "Action"
    BREVO_CREATE_COUPONS_FOR_A_COUPON_COLLECTION: "Action"
    BREVO_CREATE_ORDERS_IN_BATCH: "Action"
    BREVO_CREATE_PRODUCTS_IN_BATCH: "Action"
    BREVO_CREATE_UPDATE_A_CATEGORY: "Action"
    BREVO_CREATE_UPDATE_A_PRODUCT: "Action"
    BREVO_DELETE_AN_ATTRIBUTE: "Action"
    BREVO_DELETE_AN_AUTOMATED_MESSAGE: "Action"
    BREVO_DELETE_AN_EMAIL_CAMPAIGN: "Action"
    BREVO_DELETE_AN_EXTERNAL_FEED: "Action"
    BREVO_DELETE_AN_INACTIVE_EMAIL_TEMPLATE: "Action"
    BREVO_DELETE_AN_SMS_CAMPAIGN: "Action"
    BREVO_DELETE_AN_SMTP_TRANSACTIONAL_LOG: "Action"
    BREVO_DELETE_A_COMPANY: "Action"
    BREVO_DELETE_A_CONTACT: "Action"
    BREVO_DELETE_A_CONTACT_FROM_A_LIST: "Action"
    BREVO_DELETE_A_DEAL: "Action"
    BREVO_DELETE_A_DOMAIN: "Action"
    BREVO_DELETE_A_FILE: "Action"
    BREVO_DELETE_A_FOLDER_AND_ALL_ITS_LISTS: "Action"
    BREVO_DELETE_A_GROUP: "Action"
    BREVO_DELETE_A_LIST: "Action"
    BREVO_DELETE_A_MESSAGE_SENT_BY_AN_AGENT: "Action"
    BREVO_DELETE_A_NOTE: "Action"
    BREVO_DELETE_A_SENDER: "Action"
    BREVO_DELETE_A_SUB_ACCOUNT: "Action"
    BREVO_DELETE_A_TASK: "Action"
    BREVO_DELETE_A_WEBHOOK: "Action"
    BREVO_DELETE_A_WHATS_APP_CAMPAIGN: "Action"
    BREVO_DELETE_HARDBOUNCES: "Action"
    BREVO_DELETE_RESELLER_CHILD_BY_ID: "Action"
    BREVO_DELETE_SCHEDULED_EMAILS_BY_BATCH_ID_OR_MESSAGE_ID: "Action"
    BREVO_DELETE_SUB_ACCOUNT_FROM_GROUP: "Action"
    BREVO_DISSOCIATE_A_DEDICATED_IP_TO_THE_CHILD: "Action"
    BREVO_DOWNLOAD_A_FILE: "Action"
    BREVO_ENABLE_DISABLE_SUB_ACCOUNT_APPLICATION_S: "Action"
    BREVO_EXPORT_ALL_WEBHOOK_EVENTS: "Action"
    BREVO_EXPORT_AN_SMS_CAMPAIGN_S_RECIPIENTS: "Action"
    BREVO_EXPORT_CONTACTS: "Action"
    BREVO_EXPORT_THE_RECIPIENTS_OF_AN_EMAIL_CAMPAIGN: "Action"
    BREVO_FETCH_ALL_EVENTS_HISTORY_FOR_ONE_PARTICULAR_RECEIVED_EMAIL: "Action"
    BREVO_FETCH_ALL_EXTERNAL_FEEDS: "Action"
    BREVO_FETCH_SCHEDULED_EMAILS_BY_BATCH_ID_OR_MESSAGE_ID: "Action"
    BREVO_FILTER_TRANSACTIONAL_EMAILS_LIST: "Action"
    BREVO_GENERATE_SSO_TOKEN_TO_ACCESS_ADMIN_ACCOUNT: "Action"
    BREVO_GENERATE_SSO_TOKEN_TO_ACCESS_SUB_ACCOUNT: "Action"
    BREVO_GET_ALL_COMPANIES: "Action"
    BREVO_GET_ALL_DEALS: "Action"
    BREVO_GET_ALL_FILES: "Action"
    BREVO_GET_ALL_FOLDERS: "Action"
    BREVO_GET_ALL_NOTES: "Action"
    BREVO_GET_ALL_PIPELINES: "Action"
    BREVO_GET_ALL_SENDER_DOMAINS_FOR_A_SPECIFIC_CHILD_ACCOUNT: "Action"
    BREVO_GET_ALL_TASKS: "Action"
    BREVO_GET_ALL_TASK_TYPES: "Action"
    BREVO_GET_ALL_THE_CONTACTS: "Action"
    BREVO_GET_ALL_THE_DEDICATED_IPS_FOR_A_SENDER: "Action"
    BREVO_GET_ALL_THE_DEDICATED_IPS_FOR_YOUR_ACCOUNT: "Action"
    BREVO_GET_ALL_THE_LISTS: "Action"
    BREVO_GET_ALL_THE_SEGMENTS: "Action"
    BREVO_GET_ALL_WEBHOOKS: "Action"
    BREVO_GET_ALL_YOUR_COUPON_COLLECTIONS: "Action"
    BREVO_GET_ALL_YOUR_SMS_ACTIVITY_UNAGGREGATED_EVENTS: "Action"
    BREVO_GET_ALL_YOUR_TRANSACTIONAL_EMAIL_ACTIVITY_UNAGGREGATED_EVENTS: "Action"
    BREVO_GET_ALL_YOUR_WHATS_APP_ACTIVITY_UNAGGREGATED_EVENTS: "Action"
    BREVO_GET_AN_AB_TEST_EMAIL_CAMPAIGN_RESULTS: "Action"
    BREVO_GET_AN_AUTOMATED_MESSAGE: "Action"
    BREVO_GET_AN_EMAIL_CAMPAIGN_REPORT: "Action"
    BREVO_GET_AN_EXTERNAL_FEED_BY_UUID: "Action"
    BREVO_GET_AN_SMS_CAMPAIGN: "Action"
    BREVO_GET_A_CATEGORY_DETAILS: "Action"
    BREVO_GET_A_CHILD_ACCOUNT_S_DETAILS: "Action"
    BREVO_GET_A_COMPANY: "Action"
    BREVO_GET_A_CONTACT_S_DETAILS: "Action"
    BREVO_GET_A_COUPON_COLLECTION_BY_ID: "Action"
    BREVO_GET_A_DEAL: "Action"
    BREVO_GET_A_GROUP_DETAILS: "Action"
    BREVO_GET_A_LIST_S_DETAILS: "Action"
    BREVO_GET_A_MESSAGE: "Action"
    BREVO_GET_A_NOTE: "Action"
    BREVO_GET_A_PIPELINE: "Action"
    BREVO_GET_A_PRODUCT_S_DETAILS: "Action"
    BREVO_GET_A_SHARED_TEMPLATE_URL: "Action"
    BREVO_GET_A_TASK: "Action"
    BREVO_GET_A_WEBHOOK_DETAILS: "Action"
    BREVO_GET_A_WHATS_APP_CAMPAIGN: "Action"
    BREVO_GET_COMPANY_ATTRIBUTES: "Action"
    BREVO_GET_CONTACTS_IN_A_LIST: "Action"
    BREVO_GET_DEAL_ATTRIBUTES: "Action"
    BREVO_GET_EMAIL_CAMPAIGNS_STATISTICS_FOR_A_CONTACT: "Action"
    BREVO_GET_FILE_DETAILS: "Action"
    BREVO_GET_LISTS_IN_A_FOLDER: "Action"
    BREVO_GET_ORDER_DETAILS: "Action"
    BREVO_GET_PIPELINE_STAGES: "Action"
    BREVO_GET_SESSION_TOKEN_TO_ACCESS_BREVO_SSO: "Action"
    BREVO_GET_SUB_ACCOUNT_DETAILS: "Action"
    BREVO_GET_THE_DETAILS_OF_REQUESTED_MASTER_ACCOUNT: "Action"
    BREVO_GET_THE_LIST_OF_ALL_ADMIN_USERS: "Action"
    BREVO_GET_THE_LIST_OF_ALL_CHILDREN_ACCOUNTS: "Action"
    BREVO_GET_THE_LIST_OF_ALL_THE_EVENTS_FOR_THE_RECEIVED_EMAILS: "Action"
    BREVO_GET_THE_LIST_OF_ALL_THE_SUB_ACCOUNTS_OF_THE_MASTER_ACCOUNT: "Action"
    BREVO_GET_THE_LIST_OF_ALL_YOUR_DOMAINS: "Action"
    BREVO_GET_THE_LIST_OF_ALL_YOUR_SENDERS: "Action"
    BREVO_GET_THE_LIST_OF_ALL_YOUR_USERS: "Action"
    BREVO_GET_THE_LIST_OF_BLOCKED_DOMAINS: "Action"
    BREVO_GET_THE_LIST_OF_BLOCKED_OR_UNSUBSCRIBED_TRANSACTIONAL_CONTACTS: "Action"
    BREVO_GET_THE_LIST_OF_EMAIL_TEMPLATES: "Action"
    BREVO_GET_THE_LIST_OF_GROUPS: "Action"
    BREVO_GET_THE_PERSONALIZED_CONTENT_OF_A_SENT_TRANSACTIONAL_EMAIL: "Action"
    BREVO_GET_USER_ACTIVITY_LOGS: "Action"
    BREVO_GET_YOUR_ACCOUNT_INFORMATION_PLAN_AND_CREDITS_DETAILS: "Action"
    BREVO_GET_YOUR_SMS_ACTIVITY_AGGREGATED_OVER_A_PERIOD_OF_TIME: "Action"
    BREVO_GET_YOUR_SMS_ACTIVITY_AGGREGATED_PER_DAY: "Action"
    BREVO_GET_YOUR_TRANSACTIONAL_EMAIL_ACTIVITY_AGGREGATED_PER_DAY: "Action"
    BREVO_GET_YOUR_WHATS_APP_API_ACCOUNT_INFORMATION: "Action"
    BREVO_IMPORT_CONTACTS: "Action"
    BREVO_LINK_AND_UNLINK_A_DEAL_WITH_CONTACTS_AND_COMPANIES: "Action"
    BREVO_LINK_AND_UNLINK_COMPANY_WITH_CONTACT_AND_DEAL: "Action"
    BREVO_LIST_ALL_ATTRIBUTES: "Action"
    BREVO_MANAGING_THE_STATUS_OF_THE_ORDER: "Action"
    BREVO_REMOVE_EMAIL_AND_OR_SMS_CREDITS_FROM_A_SPECIFIC_CHILD_ACCOUNT: "Action"
    BREVO_REMOVE_RESELLER_CHILD_S_SENDER_DOMAIN: "Action"
    BREVO_RESEND_CANCEL_ADMIN_USER_INVITATION: "Action"
    BREVO_RESEND_CANCEL_INVITATION: "Action"
    BREVO_RETRIEVE_INBOUND_ATTACHMENT_WITH_DOWNLOAD_TOKEN: "Action"
    BREVO_RETURNS_A_FOLDER_S_DETAILS: "Action"
    BREVO_RETURNS_THE_INFORMATION_FOR_ALL_YOUR_CREATED_SMS_CAMPAIGNS: "Action"
    BREVO_RETURNS_THE_TEMPLATE_INFORMATION: "Action"
    BREVO_RETURN_ALL_THE_PROCESSES_FOR_YOUR_ACCOUNT: "Action"
    BREVO_RETURN_ALL_YOUR_CATEGORIES: "Action"
    BREVO_RETURN_ALL_YOUR_CREATED_EMAIL_CAMPAIGNS: "Action"
    BREVO_RETURN_ALL_YOUR_CREATED_WHATS_APP_CAMPAIGNS: "Action"
    BREVO_RETURN_ALL_YOUR_CREATED_WHATS_APP_TEMPLATES: "Action"
    BREVO_RETURN_ALL_YOUR_PRODUCTS: "Action"
    BREVO_RETURN_THE_INFORMATIONS_FOR_A_PROCESS: "Action"
    BREVO_REVOKE_AN_ADMIN_USER: "Action"
    BREVO_REVOKE_USER_PERMISSION: "Action"
    BREVO_SEND_AN_AUTOMATED_MESSAGE_TO_A_VISITOR: "Action"
    BREVO_SEND_AN_EMAIL_CAMPAIGN_IMMEDIATELY_BASED_ON_CAMPAIGN_ID: "Action"
    BREVO_SEND_AN_EMAIL_CAMPAIGN_TO_YOUR_TEST_LIST: "Action"
    BREVO_SEND_AN_SMS_CAMPAIGN_S_REPORT: "Action"
    BREVO_SEND_A_MESSAGE_AS_AN_AGENT: "Action"
    BREVO_SEND_A_TEMPLATE_TO_YOUR_TEST_LIST: "Action"
    BREVO_SEND_A_TEST_SMS_CAMPAIGN: "Action"
    BREVO_SEND_A_TRANSACTIONAL_EMAIL: "Action"
    BREVO_SEND_A_WHATS_APP_MESSAGE: "Action"
    BREVO_SEND_INVITATION_TO_AN_ADMIN_USER: "Action"
    BREVO_SEND_INVITATION_TO_USER: "Action"
    BREVO_SEND_SMS_MESSAGE_TO_A_MOBILE_NUMBER: "Action"
    BREVO_SEND_THE_REPORT_OF_A_CAMPAIGN: "Action"
    BREVO_SEND_YOUR_SMS_CAMPAIGN_IMMEDIATELY: "Action"
    BREVO_SEND_YOUR_WHATS_APP_TEMPLATE_FOR_APPROVAL: "Action"
    BREVO_SETS_AGENT_S_STATUS_TO_ONLINE_FOR23_MINUTES: "Action"
    BREVO_UNBLOCK_AN_EXISTING_DOMAIN_FROM_THE_LIST_OF_BLOCKED_DOMAINS: "Action"
    BREVO_UNBLOCK_OR_RESUBSCRIBE_A_TRANSACTIONAL_CONTACT: "Action"
    BREVO_UPDATE_AN_AUTOMATED_MESSAGE: "Action"
    BREVO_UPDATE_AN_EMAIL_CAMPAIGN: "Action"
    BREVO_UPDATE_AN_EMAIL_CAMPAIGN_STATUS: "Action"
    BREVO_UPDATE_AN_EMAIL_TEMPLATE: "Action"
    BREVO_UPDATE_AN_EXTERNAL_FEED: "Action"
    BREVO_UPDATE_AN_SMS_CAMPAIGN: "Action"
    BREVO_UPDATE_A_CAMPAIGN_S_STATUS: "Action"
    BREVO_UPDATE_A_COMPANY: "Action"
    BREVO_UPDATE_A_CONTACT: "Action"
    BREVO_UPDATE_A_COUPON_COLLECTION_BY_ID: "Action"
    BREVO_UPDATE_A_DEAL: "Action"
    BREVO_UPDATE_A_FOLDER: "Action"
    BREVO_UPDATE_A_GROUP_OF_SUB_ACCOUNTS: "Action"
    BREVO_UPDATE_A_LIST: "Action"
    BREVO_UPDATE_A_MESSAGE_SENT_BY_AN_AGENT: "Action"
    BREVO_UPDATE_A_NOTE: "Action"
    BREVO_UPDATE_A_SENDER: "Action"
    BREVO_UPDATE_A_TASK: "Action"
    BREVO_UPDATE_A_WEBHOOK: "Action"
    BREVO_UPDATE_A_WHATS_APP_CAMPAIGN: "Action"
    BREVO_UPDATE_CHILD_ACCOUNT_STATUS_BY_IDENTIFIER: "Action"
    BREVO_UPDATE_CHILD_INFO_BASED_ON_ID: "Action"
    BREVO_UPDATE_CONTACT_ATTRIBUTE: "Action"
    BREVO_UPDATE_MULTIPLE_CONTACTS: "Action"
    BREVO_UPDATE_PERMISSION_FOR_A_USER: "Action"
    BREVO_UPDATE_RESELLER_CHILD_S_SENDER_DOMAIN: "Action"
    BREVO_UPDATE_SUB_ACCOUNT_PLAN: "Action"
    BREVO_UPLOAD_AN_IMAGE_TO_YOUR_ACCOUNT_S_IMAGE_GALLERY: "Action"
    BREVO_UPLOAD_A_FILE: "Action"
    BREVO_VALIDATE_DOMAIN_CONFIGURATION: "Action"
    BREVO_VALIDATE_SENDER_USING_OTP: "Action"
    BROWSERTOOL_CLICK_ELEMENT: "Action"
    BROWSERTOOL_GET_ELEMENT_DETAILS: "Action"
    BROWSERTOOL_GET_PAGE_DETAILS: "Action"
    BROWSERTOOL_GET_SCREENSHOT: "Action"
    BROWSERTOOL_GOTO_PAGE: "Action"
    BROWSERTOOL_NAVIGATE_HISTORY: "Action"
    BROWSERTOOL_REFRESH_PAGE: "Action"
    BROWSERTOOL_SCROLL_PAGE: "Action"
    BROWSERTOOL_TYPE_TEXT: "Action"
    CLICKUP_ADD_DEPENDENCY: "Action"
    CLICKUP_ADD_GUEST_TO_FOLDER: "Action"
    CLICKUP_ADD_GUEST_TO_LIST: "Action"
    CLICKUP_ADD_GUEST_TO_TASK: "Action"
    CLICKUP_ADD_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_ADD_TAG_TO_TASK: "Action"
    CLICKUP_ADD_TASK_LINK: "Action"
    CLICKUP_ADD_TASK_TO_LIST: "Action"
    CLICKUP_AUTHORIZATION_GET_WORK_SPACE_LIST: "Action"
    CLICKUP_AUTHORIZATION_VIEW_ACCOUNT_DETAILS: "Action"
    CLICKUP_CHANGE_TAG_NAMES_FROM_TIME_ENTRIES: "Action"
    CLICKUP_CREATE_A_TIME_ENTRY: "Action"
    CLICKUP_CREATE_CHAT_VIEW_COMMENT: "Action"
    CLICKUP_CREATE_CHECKLIST: "Action"
    CLICKUP_CREATE_CHECKLIST_ITEM: "Action"
    CLICKUP_CREATE_FOLDER: "Action"
    CLICKUP_CREATE_FOLDERLESS_LIST: "Action"
    CLICKUP_CREATE_FOLDER_VIEW: "Action"
    CLICKUP_CREATE_GOAL: "Action"
    CLICKUP_CREATE_KEY_RESULT: "Action"
    CLICKUP_CREATE_LIST: "Action"
    CLICKUP_CREATE_LIST_COMMENT: "Action"
    CLICKUP_CREATE_LIST_VIEW: "Action"
    CLICKUP_CREATE_SPACE: "Action"
    CLICKUP_CREATE_SPACE_TAG: "Action"
    CLICKUP_CREATE_SPACE_VIEW: "Action"
    CLICKUP_CREATE_TASK: "Action"
    CLICKUP_CREATE_TASK_ATTACHMENT: "Action"
    CLICKUP_CREATE_TASK_COMMENT: "Action"
    CLICKUP_CREATE_TASK_FROM_TEMPLATE: "Action"
    CLICKUP_CREATE_TEAM: "Action"
    CLICKUP_CREATE_WEBHOOK: "Action"
    CLICKUP_CREATE_WORKSPACE_EVERYTHING_LEVEL_VIEW: "Action"
    CLICKUP_DELETE_A_TIME_ENTRY: "Action"
    CLICKUP_DELETE_CHECKLIST: "Action"
    CLICKUP_DELETE_CHECKLIST_ITEM: "Action"
    CLICKUP_DELETE_COMMENT: "Action"
    CLICKUP_DELETE_DEPENDENCY: "Action"
    CLICKUP_DELETE_FOLDER: "Action"
    CLICKUP_DELETE_GOAL: "Action"
    CLICKUP_DELETE_KEY_RESULT: "Action"
    CLICKUP_DELETE_LIST: "Action"
    CLICKUP_DELETE_SPACE: "Action"
    CLICKUP_DELETE_SPACE_TAG: "Action"
    CLICKUP_DELETE_TASK: "Action"
    CLICKUP_DELETE_TASK_LINK: "Action"
    CLICKUP_DELETE_TEAM: "Action"
    CLICKUP_DELETE_TIME_TRACKED: "Action"
    CLICKUP_DELETE_VIEW: "Action"
    CLICKUP_DELETE_WEBHOOK: "Action"
    CLICKUP_EDIT_CHECKLIST: "Action"
    CLICKUP_EDIT_CHECKLIST_ITEM: "Action"
    CLICKUP_EDIT_GUEST_ON_WORKSPACE: "Action"
    CLICKUP_EDIT_KEY_RESULT: "Action"
    CLICKUP_EDIT_SPACE_TAG: "Action"
    CLICKUP_EDIT_TIME_TRACKED: "Action"
    CLICKUP_EDIT_USER_ON_WORKSPACE: "Action"
    CLICKUP_GET_ACCESSIBLE_CUSTOM_FIELDS: "Action"
    CLICKUP_GET_ACCESS_TOKEN: "Action"
    CLICKUP_GET_ALL_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_GET_AUTHORIZED_TEAMS_WORKSPACES: "Action"
    CLICKUP_GET_AUTHORIZED_USER: "Action"
    CLICKUP_GET_BULK_TASKS_TIME_IN_STATUS: "Action"
    CLICKUP_GET_CHAT_VIEW_COMMENTS: "Action"
    CLICKUP_GET_CUSTOM_ROLES: "Action"
    CLICKUP_GET_CUSTOM_TASK_TYPES: "Action"
    CLICKUP_GET_FILTERED_TEAM_TASKS: "Action"
    CLICKUP_GET_FOLDER: "Action"
    CLICKUP_GET_FOLDERLESS_LISTS: "Action"
    CLICKUP_GET_FOLDERS: "Action"
    CLICKUP_GET_FOLDER_VIEWS: "Action"
    CLICKUP_GET_GOAL: "Action"
    CLICKUP_GET_GOALS: "Action"
    CLICKUP_GET_GUEST: "Action"
    CLICKUP_GET_LIST: "Action"
    CLICKUP_GET_LISTS: "Action"
    CLICKUP_GET_LIST_COMMENTS: "Action"
    CLICKUP_GET_LIST_MEMBERS: "Action"
    CLICKUP_GET_LIST_VIEWS: "Action"
    CLICKUP_GET_RUNNING_TIME_ENTRY: "Action"
    CLICKUP_GET_SINGULAR_TIME_ENTRY: "Action"
    CLICKUP_GET_SPACE: "Action"
    CLICKUP_GET_SPACES: "Action"
    CLICKUP_GET_SPACE_TAGS: "Action"
    CLICKUP_GET_SPACE_VIEWS: "Action"
    CLICKUP_GET_TASK: "Action"
    CLICKUP_GET_TASKS: "Action"
    CLICKUP_GET_TASK_COMMENTS: "Action"
    CLICKUP_GET_TASK_MEMBERS: "Action"
    CLICKUP_GET_TASK_S_TIME_IN_STATUS: "Action"
    CLICKUP_GET_TASK_TEMPLATES: "Action"
    CLICKUP_GET_TEAMS: "Action"
    CLICKUP_GET_TIME_ENTRIES_WITHIN_A_DATE_RANGE: "Action"
    CLICKUP_GET_TIME_ENTRY_HISTORY: "Action"
    CLICKUP_GET_TRACKED_TIME: "Action"
    CLICKUP_GET_USER: "Action"
    CLICKUP_GET_VIEW: "Action"
    CLICKUP_GET_VIEW_TASKS: "Action"
    CLICKUP_GET_WEBHOOKS: "Action"
    CLICKUP_GET_WORKSPACE_EVERYTHING_LEVEL_VIEWS: "Action"
    CLICKUP_GET_WORKSPACE_PLAN: "Action"
    CLICKUP_GET_WORKSPACE_SEATS: "Action"
    CLICKUP_INVITE_GUEST_TO_WORKSPACE: "Action"
    CLICKUP_INVITE_USER_TO_WORKSPACE: "Action"
    CLICKUP_LOCAL_ADD_DEPENDENCY: "Action"
    CLICKUP_LOCAL_ADD_GUEST_TO_FOLDER: "Action"
    CLICKUP_LOCAL_ADD_GUEST_TO_LIST: "Action"
    CLICKUP_LOCAL_ADD_GUEST_TO_TASK: "Action"
    CLICKUP_LOCAL_ADD_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_LOCAL_ADD_TAG_TO_TASK: "Action"
    CLICKUP_LOCAL_ADD_TASK_LINK: "Action"
    CLICKUP_LOCAL_ADD_TASK_TO_LIST: "Action"
    CLICKUP_LOCAL_ATTACHMENTS_UPLOAD_FILE_TO_TASK_AS_ATTACHMENT: "Action"
    CLICKUP_LOCAL_AUTHORIZATION_GET_ACCESS_TOKEN: "Action"
    CLICKUP_LOCAL_AUTHORIZATION_GET_WORK_SPACE_LIST: "Action"
    CLICKUP_LOCAL_AUTHORIZATION_VIEW_ACCOUNT_DETAILS: "Action"
    CLICKUP_LOCAL_CHANGE_TAG_NAMES_FROM_TIME_ENTRIES: "Action"
    CLICKUP_LOCAL_CREATE_A_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_CREATE_CHAT_VIEW_COMMENT: "Action"
    CLICKUP_LOCAL_CREATE_CHECKLIST: "Action"
    CLICKUP_LOCAL_CREATE_CHECKLIST_ITEM: "Action"
    CLICKUP_LOCAL_CREATE_FOLDER: "Action"
    CLICKUP_LOCAL_CREATE_FOLDERLESS_LIST: "Action"
    CLICKUP_LOCAL_CREATE_FOLDER_VIEW: "Action"
    CLICKUP_LOCAL_CREATE_GOAL: "Action"
    CLICKUP_LOCAL_CREATE_KEY_RESULT: "Action"
    CLICKUP_LOCAL_CREATE_LIST: "Action"
    CLICKUP_LOCAL_CREATE_LIST_COMMENT: "Action"
    CLICKUP_LOCAL_CREATE_LIST_VIEW: "Action"
    CLICKUP_LOCAL_CREATE_SPACE: "Action"
    CLICKUP_LOCAL_CREATE_SPACE_TAG: "Action"
    CLICKUP_LOCAL_CREATE_SPACE_VIEW: "Action"
    CLICKUP_LOCAL_CREATE_TASK: "Action"
    CLICKUP_LOCAL_CREATE_TASK_ATTACHMENT: "Action"
    CLICKUP_LOCAL_CREATE_TASK_COMMENT: "Action"
    CLICKUP_LOCAL_CREATE_TASK_FROM_TEMPLATE: "Action"
    CLICKUP_LOCAL_CREATE_TEAM: "Action"
    CLICKUP_LOCAL_CREATE_WEBHOOK: "Action"
    CLICKUP_LOCAL_CREATE_WORKSPACE_EVERYTHING_LEVEL_VIEW: "Action"
    CLICKUP_LOCAL_DELETE_A_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_DELETE_CHECKLIST: "Action"
    CLICKUP_LOCAL_DELETE_CHECKLIST_ITEM: "Action"
    CLICKUP_LOCAL_DELETE_COMMENT: "Action"
    CLICKUP_LOCAL_DELETE_DEPENDENCY: "Action"
    CLICKUP_LOCAL_DELETE_FOLDER: "Action"
    CLICKUP_LOCAL_DELETE_GOAL: "Action"
    CLICKUP_LOCAL_DELETE_KEY_RESULT: "Action"
    CLICKUP_LOCAL_DELETE_LIST: "Action"
    CLICKUP_LOCAL_DELETE_SPACE: "Action"
    CLICKUP_LOCAL_DELETE_SPACE_TAG: "Action"
    CLICKUP_LOCAL_DELETE_TASK: "Action"
    CLICKUP_LOCAL_DELETE_TASK_LINK: "Action"
    CLICKUP_LOCAL_DELETE_TEAM: "Action"
    CLICKUP_LOCAL_DELETE_TIME_TRACKED: "Action"
    CLICKUP_LOCAL_DELETE_VIEW: "Action"
    CLICKUP_LOCAL_DELETE_WEBHOOK: "Action"
    CLICKUP_LOCAL_EDIT_CHECKLIST: "Action"
    CLICKUP_LOCAL_EDIT_CHECKLIST_ITEM: "Action"
    CLICKUP_LOCAL_EDIT_GUEST_ON_WORKSPACE: "Action"
    CLICKUP_LOCAL_EDIT_KEY_RESULT: "Action"
    CLICKUP_LOCAL_EDIT_SPACE_TAG: "Action"
    CLICKUP_LOCAL_EDIT_TIME_TRACKED: "Action"
    CLICKUP_LOCAL_EDIT_USER_ON_WORKSPACE: "Action"
    CLICKUP_LOCAL_FOLDERS_CREATE_NEW_FOLDER: "Action"
    CLICKUP_LOCAL_FOLDERS_GET_CONTENTS_OF: "Action"
    CLICKUP_LOCAL_FOLDERS_GET_FOLDER_CONTENT: "Action"
    CLICKUP_LOCAL_GET_ACCESSIBLE_CUSTOM_FIELDS: "Action"
    CLICKUP_LOCAL_GET_ACCESS_TOKEN: "Action"
    CLICKUP_LOCAL_GET_ALL_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_LOCAL_GET_AUTHORIZED_TEAMS_WORKSPACES: "Action"
    CLICKUP_LOCAL_GET_AUTHORIZED_USER: "Action"
    CLICKUP_LOCAL_GET_BULK_TASKS_TIME_IN_STATUS: "Action"
    CLICKUP_LOCAL_GET_CHAT_VIEW_COMMENTS: "Action"
    CLICKUP_LOCAL_GET_CUSTOM_ROLES: "Action"
    CLICKUP_LOCAL_GET_CUSTOM_TASK_TYPES: "Action"
    CLICKUP_LOCAL_GET_FILTERED_TEAM_TASKS: "Action"
    CLICKUP_LOCAL_GET_FOLDER: "Action"
    CLICKUP_LOCAL_GET_FOLDERLESS_LISTS: "Action"
    CLICKUP_LOCAL_GET_FOLDERS: "Action"
    CLICKUP_LOCAL_GET_FOLDER_VIEWS: "Action"
    CLICKUP_LOCAL_GET_GOAL: "Action"
    CLICKUP_LOCAL_GET_GOALS: "Action"
    CLICKUP_LOCAL_GET_GUEST: "Action"
    CLICKUP_LOCAL_GET_LIST: "Action"
    CLICKUP_LOCAL_GET_LISTS: "Action"
    CLICKUP_LOCAL_GET_LIST_COMMENTS: "Action"
    CLICKUP_LOCAL_GET_LIST_MEMBERS: "Action"
    CLICKUP_LOCAL_GET_LIST_VIEWS: "Action"
    CLICKUP_LOCAL_GET_RUNNING_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_GET_SINGULAR_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_GET_SPACE: "Action"
    CLICKUP_LOCAL_GET_SPACES: "Action"
    CLICKUP_LOCAL_GET_SPACE_TAGS: "Action"
    CLICKUP_LOCAL_GET_SPACE_VIEWS: "Action"
    CLICKUP_LOCAL_GET_TASK: "Action"
    CLICKUP_LOCAL_GET_TASKS: "Action"
    CLICKUP_LOCAL_GET_TASK_COMMENTS: "Action"
    CLICKUP_LOCAL_GET_TASK_MEMBERS: "Action"
    CLICKUP_LOCAL_GET_TASK_S_TIME_IN_STATUS: "Action"
    CLICKUP_LOCAL_GET_TASK_TEMPLATES: "Action"
    CLICKUP_LOCAL_GET_TEAMS: "Action"
    CLICKUP_LOCAL_GET_TIME_ENTRIES_WITHIN_A_DATE_RANGE: "Action"
    CLICKUP_LOCAL_GET_TIME_ENTRY_HISTORY: "Action"
    CLICKUP_LOCAL_GET_TRACKED_TIME: "Action"
    CLICKUP_LOCAL_GET_USER: "Action"
    CLICKUP_LOCAL_GET_VIEW: "Action"
    CLICKUP_LOCAL_GET_VIEW_TASKS: "Action"
    CLICKUP_LOCAL_GET_WEBHOOKS: "Action"
    CLICKUP_LOCAL_GET_WORKSPACE_EVERYTHING_LEVEL_VIEWS: "Action"
    CLICKUP_LOCAL_GET_WORKSPACE_PLAN: "Action"
    CLICKUP_LOCAL_GET_WORKSPACE_SEATS: "Action"
    CLICKUP_LOCAL_INVITE_GUEST_TO_WORKSPACE: "Action"
    CLICKUP_LOCAL_INVITE_USER_TO_WORKSPACE: "Action"
    CLICKUP_LOCAL_LISTS_GET_FOLDER_LISTS: "Action"
    CLICKUP_LOCAL_MEMBERS_GET_LIST_USERS: "Action"
    CLICKUP_LOCAL_REMOVE_CUSTOM_FIELD_VALUE: "Action"
    CLICKUP_LOCAL_REMOVE_GUEST_FROM_FOLDER: "Action"
    CLICKUP_LOCAL_REMOVE_GUEST_FROM_LIST: "Action"
    CLICKUP_LOCAL_REMOVE_GUEST_FROM_TASK: "Action"
    CLICKUP_LOCAL_REMOVE_GUEST_FROM_WORKSPACE: "Action"
    CLICKUP_LOCAL_REMOVE_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_LOCAL_REMOVE_TAG_FROM_TASK: "Action"
    CLICKUP_LOCAL_REMOVE_TASK_FROM_LIST: "Action"
    CLICKUP_LOCAL_REMOVE_USER_FROM_WORKSPACE: "Action"
    CLICKUP_LOCAL_SET_CUSTOM_FIELD_VALUE: "Action"
    CLICKUP_LOCAL_SHARED_HIERARCHY: "Action"
    CLICKUP_LOCAL_SPACES_GET_DETAILS: "Action"
    CLICKUP_LOCAL_SPACES_GET_SPACE_DETAILS: "Action"
    CLICKUP_LOCAL_START_A_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_STOP_A_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_TASKS_GET_LIST_TASKS: "Action"
    CLICKUP_LOCAL_TASKS_GET_TASK_DETAILS: "Action"
    CLICKUP_LOCAL_TASK_CHECKLISTS_CREATE_NEW_CHECKLIST: "Action"
    CLICKUP_LOCAL_TEAMS_USER_GROUPS_CREATE_TEAM: "Action"
    CLICKUP_LOCAL_TEAMS_WORK_SPACES_GET_WORK_SPACE_PLAN: "Action"
    CLICKUP_LOCAL_TEAMS_WORK_SPACES_GET_WORK_SPACE_SEATS: "Action"
    CLICKUP_LOCAL_TRACK_TIME: "Action"
    CLICKUP_LOCAL_UPDATE_A_TIME_ENTRY: "Action"
    CLICKUP_LOCAL_UPDATE_COMMENT: "Action"
    CLICKUP_LOCAL_UPDATE_FOLDER: "Action"
    CLICKUP_LOCAL_UPDATE_GOAL: "Action"
    CLICKUP_LOCAL_UPDATE_LIST: "Action"
    CLICKUP_LOCAL_UPDATE_SPACE: "Action"
    CLICKUP_LOCAL_UPDATE_TASK: "Action"
    CLICKUP_LOCAL_UPDATE_TEAM: "Action"
    CLICKUP_LOCAL_UPDATE_VIEW: "Action"
    CLICKUP_LOCAL_UPDATE_WEBHOOK: "Action"
    CLICKUP_LOCAL_VIEWS_GET_EVERYTHING_LEVEL: "Action"
    CLICKUP_LOCAL_VIEWS_SPACE_VIEWS_GET: "Action"
    CLICKUP_REMOVE_CUSTOM_FIELD_VALUE: "Action"
    CLICKUP_REMOVE_GUEST_FROM_FOLDER: "Action"
    CLICKUP_REMOVE_GUEST_FROM_LIST: "Action"
    CLICKUP_REMOVE_GUEST_FROM_TASK: "Action"
    CLICKUP_REMOVE_GUEST_FROM_WORKSPACE: "Action"
    CLICKUP_REMOVE_TAGS_FROM_TIME_ENTRIES: "Action"
    CLICKUP_REMOVE_TAG_FROM_TASK: "Action"
    CLICKUP_REMOVE_TASK_FROM_LIST: "Action"
    CLICKUP_REMOVE_USER_FROM_WORKSPACE: "Action"
    CLICKUP_SET_CUSTOM_FIELD_VALUE: "Action"
    CLICKUP_SHARED_HIERARCHY: "Action"
    CLICKUP_START_A_TIME_ENTRY: "Action"
    CLICKUP_STOP_A_TIME_ENTRY: "Action"
    CLICKUP_TASKS_GET_TASK_DETAILS: "Action"
    CLICKUP_TEAMS_WORK_SPACES_GET_WORK_SPACE_PLAN: "Action"
    CLICKUP_TEAMS_WORK_SPACES_GET_WORK_SPACE_SEATS: "Action"
    CLICKUP_TRACK_TIME: "Action"
    CLICKUP_UPDATE_A_TIME_ENTRY: "Action"
    CLICKUP_UPDATE_COMMENT: "Action"
    CLICKUP_UPDATE_FOLDER: "Action"
    CLICKUP_UPDATE_GOAL: "Action"
    CLICKUP_UPDATE_LIST: "Action"
    CLICKUP_UPDATE_SPACE: "Action"
    CLICKUP_UPDATE_TASK: "Action"
    CLICKUP_UPDATE_TEAM: "Action"
    CLICKUP_UPDATE_VIEW: "Action"
    CLICKUP_UPDATE_WEBHOOK: "Action"
    CLICKUP_VIEWS_GET_EVERYTHING_LEVEL: "Action"
    CODEFORMAT_FORMAT_AND_LINT_CODEBASE: "Action"
    CODEGREP_SEARCH_CODEBASE: "Action"
    CODEINDEX_CREATE_INDEX: "Action"
    CODEINDEX_INDEX_STATUS: "Action"
    CODEINDEX_SEARCH_CODEBASE: "Action"
    CODEINTERPRETER_EXECUTE_CODE: "Action"
    CODEINTERPRETER_GET_FILE_CMD: "Action"
    CODEINTERPRETER_RUN_TERMINAL_CMD: "Action"
    CODEMAP_DELETE_REPO_MAP: "Action"
    CODEMAP_GENERATE_RANKED_TAGS: "Action"
    CODEMAP_GET_REPO_MAP: "Action"
    CODEMAP_GET_REPO_STRUCTURE: "Action"
    CODEMAP_INIT_REPO_MAP: "Action"
    COMPOSIO_CHECK_ACTIVE_CONNECTION: "Action"
    COMPOSIO_INITIATE_CONNECTION: "Action"
    COMPOSIO_RETRIEVE_ACTIONS: "Action"
    COMPOSIO_RETRIEVE_APPS: "Action"
    COMPOSIO_WAIT_FOR_CONNECTION: "Action"
    DISCORD_ADD_GROUP_DM_USER: "Action"
    DISCORD_ADD_GUILD_MEMBER: "Action"
    DISCORD_ADD_GUILD_MEMBER_ROLE: "Action"
    DISCORD_ADD_MY_MESSAGE_REACTION: "Action"
    DISCORD_ADD_THREAD_MEMBER: "Action"
    DISCORD_BAN_USER_FROM_GUILD: "Action"
    DISCORD_BULK_BAN_USERS_FROM_GUILD: "Action"
    DISCORD_BULK_DELETE_MESSAGES: "Action"
    DISCORD_CREATE_APPLICATION_COMMAND: "Action"
    DISCORD_CREATE_AUTO_MODERATION_RULE: "Action"
    DISCORD_CREATE_CHANNEL_INVITE: "Action"
    DISCORD_CREATE_DM: "Action"
    DISCORD_CREATE_GUILD: "Action"
    DISCORD_CREATE_GUILD_APPLICATION_COMMAND: "Action"
    DISCORD_CREATE_GUILD_CHANNEL: "Action"
    DISCORD_CREATE_GUILD_EMOJI: "Action"
    DISCORD_CREATE_GUILD_FROM_TEMPLATE: "Action"
    DISCORD_CREATE_GUILD_ROLE: "Action"
    DISCORD_CREATE_GUILD_SCHEDULED_EVENT: "Action"
    DISCORD_CREATE_GUILD_STICKER: "Action"
    DISCORD_CREATE_GUILD_TEMPLATE: "Action"
    DISCORD_CREATE_INTERACTION_RESPONSE: "Action"
    DISCORD_CREATE_MESSAGE: "Action"
    DISCORD_CREATE_STAGE_INSTANCE: "Action"
    DISCORD_CREATE_THREAD: "Action"
    DISCORD_CREATE_THREAD_FROM_MESSAGE: "Action"
    DISCORD_CREATE_WEBHOOK: "Action"
    DISCORD_CROSSPOST_MESSAGE: "Action"
    DISCORD_DELETE_ALL_MESSAGE_REACTIONS: "Action"
    DISCORD_DELETE_ALL_MESSAGE_REACTIONS_BY_EMOJI: "Action"
    DISCORD_DELETE_APPLICATION_COMMAND: "Action"
    DISCORD_DELETE_AUTO_MODERATION_RULE: "Action"
    DISCORD_DELETE_CHANNEL: "Action"
    DISCORD_DELETE_CHANNEL_PERMISSION_OVERWRITE: "Action"
    DISCORD_DELETE_GROUP_DM_USER: "Action"
    DISCORD_DELETE_GUILD: "Action"
    DISCORD_DELETE_GUILD_APPLICATION_COMMAND: "Action"
    DISCORD_DELETE_GUILD_EMOJI: "Action"
    DISCORD_DELETE_GUILD_INTEGRATION: "Action"
    DISCORD_DELETE_GUILD_MEMBER: "Action"
    DISCORD_DELETE_GUILD_MEMBER_ROLE: "Action"
    DISCORD_DELETE_GUILD_ROLE: "Action"
    DISCORD_DELETE_GUILD_SCHEDULED_EVENT: "Action"
    DISCORD_DELETE_GUILD_STICKER: "Action"
    DISCORD_DELETE_GUILD_TEMPLATE: "Action"
    DISCORD_DELETE_MESSAGE: "Action"
    DISCORD_DELETE_MY_MESSAGE_REACTION: "Action"
    DISCORD_DELETE_ORIGINAL_WEBHOOK_MESSAGE: "Action"
    DISCORD_DELETE_STAGE_INSTANCE: "Action"
    DISCORD_DELETE_THREAD_MEMBER: "Action"
    DISCORD_DELETE_USER_MESSAGE_REACTION: "Action"
    DISCORD_DELETE_WEBHOOK: "Action"
    DISCORD_DELETE_WEBHOOK_BY_TOKEN: "Action"
    DISCORD_DELETE_WEBHOOK_MESSAGE: "Action"
    DISCORD_EXECUTE_GITHUB_COMPATIBLE_WEBHOOK: "Action"
    DISCORD_EXECUTE_SLACK_COMPATIBLE_WEBHOOK: "Action"
    DISCORD_EXECUTE_WEBHOOK: "Action"
    DISCORD_FOLLOW_CHANNEL: "Action"
    DISCORD_GETMYOAUTH2APPLICATION: "Action"
    DISCORD_GETMYOAUTH2AUTHORIZATION: "Action"
    DISCORD_GETPUBLICKEYS: "Action"
    DISCORD_GETUSER: "Action"
    DISCORD_GET_ACTIVE_GUILD_THREADS: "Action"
    DISCORD_GET_APPLICATION: "Action"
    DISCORD_GET_APPLICATION_COMMAND: "Action"
    DISCORD_GET_APPLICATION_ROLE_CONNECTIONS_METADATA: "Action"
    DISCORD_GET_APPLICATION_USER_ROLE_CONNECTION: "Action"
    DISCORD_GET_AUTO_MODERATION_RULE: "Action"
    DISCORD_GET_BOT_GATEWAY: "Action"
    DISCORD_GET_CHANNEL: "Action"
    DISCORD_GET_GATEWAY: "Action"
    DISCORD_GET_GUILD: "Action"
    DISCORD_GET_GUILDS_ONBOARDING: "Action"
    DISCORD_GET_GUILD_APPLICATION_COMMAND: "Action"
    DISCORD_GET_GUILD_APPLICATION_COMMAND_PERMISSIONS: "Action"
    DISCORD_GET_GUILD_BAN: "Action"
    DISCORD_GET_GUILD_EMOJI: "Action"
    DISCORD_GET_GUILD_MEMBER: "Action"
    DISCORD_GET_GUILD_NEW_MEMBER_WELCOME: "Action"
    DISCORD_GET_GUILD_PREVIEW: "Action"
    DISCORD_GET_GUILD_SCHEDULED_EVENT: "Action"
    DISCORD_GET_GUILD_STICKER: "Action"
    DISCORD_GET_GUILD_TEMPLATE: "Action"
    DISCORD_GET_GUILD_VANITY_URL: "Action"
    DISCORD_GET_GUILD_WEBHOOKS: "Action"
    DISCORD_GET_GUILD_WELCOME_SCREEN: "Action"
    DISCORD_GET_GUILD_WIDGET: "Action"
    DISCORD_GET_GUILD_WIDGET_SETTINGS: "Action"
    DISCORD_GET_MESSAGE: "Action"
    DISCORD_GET_MY_APPLICATION: "Action"
    DISCORD_GET_MY_GUILD_MEMBER: "Action"
    DISCORD_GET_MY_OAUTH2_APPLICATION: "Action"
    DISCORD_GET_MY_OAUTH2_AUTHORIZATION: "Action"
    DISCORD_GET_MY_USER: "Action"
    DISCORD_GET_ORIGINAL_WEBHOOK_MESSAGE: "Action"
    DISCORD_GET_PUBLIC_KEYS: "Action"
    DISCORD_GET_STAGE_INSTANCE: "Action"
    DISCORD_GET_STICKER: "Action"
    DISCORD_GET_THREAD_MEMBER: "Action"
    DISCORD_GET_USER: "Action"
    DISCORD_GET_WEBHOOK: "Action"
    DISCORD_GET_WEBHOOK_BY_TOKEN: "Action"
    DISCORD_GET_WEBHOOK_MESSAGE: "Action"
    DISCORD_INVITE_RESOLVE: "Action"
    DISCORD_INVITE_REVOKE: "Action"
    DISCORD_JOIN_THREAD: "Action"
    DISCORD_LEAVE_GUILD: "Action"
    DISCORD_LEAVE_THREAD: "Action"
    DISCORD_LISTMYCONNECTIONS: "Action"
    DISCORD_LISTMYGUILDS: "Action"
    DISCORD_LIST_APPLICATION_COMMANDS: "Action"
    DISCORD_LIST_AUTO_MODERATION_RULES: "Action"
    DISCORD_LIST_CHANNEL_INVITES: "Action"
    DISCORD_LIST_CHANNEL_WEBHOOKS: "Action"
    DISCORD_LIST_GUILD_APPLICATION_COMMANDS: "Action"
    DISCORD_LIST_GUILD_APPLICATION_COMMAND_PERMISSIONS: "Action"
    DISCORD_LIST_GUILD_AUDIT_LOG_ENTRIES: "Action"
    DISCORD_LIST_GUILD_BANS: "Action"
    DISCORD_LIST_GUILD_CHANNELS: "Action"
    DISCORD_LIST_GUILD_EMOJIS: "Action"
    DISCORD_LIST_GUILD_INTEGRATIONS: "Action"
    DISCORD_LIST_GUILD_INVITES: "Action"
    DISCORD_LIST_GUILD_MEMBERS: "Action"
    DISCORD_LIST_GUILD_ROLES: "Action"
    DISCORD_LIST_GUILD_SCHEDULED_EVENTS: "Action"
    DISCORD_LIST_GUILD_SCHEDULED_EVENT_USERS: "Action"
    DISCORD_LIST_GUILD_STICKERS: "Action"
    DISCORD_LIST_GUILD_TEMPLATES: "Action"
    DISCORD_LIST_GUILD_VOICE_REGIONS: "Action"
    DISCORD_LIST_MESSAGES: "Action"
    DISCORD_LIST_MESSAGE_REACTIONS_BY_EMOJI: "Action"
    DISCORD_LIST_MY_CONNECTIONS: "Action"
    DISCORD_LIST_MY_GUILDS: "Action"
    DISCORD_LIST_MY_PRIVATE_ARCHIVED_THREADS: "Action"
    DISCORD_LIST_PINNED_MESSAGES: "Action"
    DISCORD_LIST_PRIVATE_ARCHIVED_THREADS: "Action"
    DISCORD_LIST_PUBLIC_ARCHIVED_THREADS: "Action"
    DISCORD_LIST_STICKER_PACKS: "Action"
    DISCORD_LIST_THREAD_MEMBERS: "Action"
    DISCORD_LIST_VOICE_REGIONS: "Action"
    DISCORD_PIN_MESSAGE: "Action"
    DISCORD_PREVIEW_PRUNE_GUILD: "Action"
    DISCORD_PRUNE_GUILD: "Action"
    DISCORD_PUT_GUILDS_ONBOARDING: "Action"
    DISCORD_SEARCH_GUILD_MEMBERS: "Action"
    DISCORD_SET_CHANNEL_PERMISSION_OVERWRITE: "Action"
    DISCORD_SET_GUILD_APPLICATION_COMMAND_PERMISSIONS: "Action"
    DISCORD_SYNC_GUILD_TEMPLATE: "Action"
    DISCORD_TRIGGER_TYPING_INDICATOR: "Action"
    DISCORD_UNBAN_USER_FROM_GUILD: "Action"
    DISCORD_UNPIN_MESSAGE: "Action"
    DISCORD_UPDATE_APPLICATION: "Action"
    DISCORD_UPDATE_APPLICATION_COMMAND: "Action"
    DISCORD_UPDATE_APPLICATION_USER_ROLE_CONNECTION: "Action"
    DISCORD_UPDATE_AUTO_MODERATION_RULE: "Action"
    DISCORD_UPDATE_CHANNEL: "Action"
    DISCORD_UPDATE_GUILD: "Action"
    DISCORD_UPDATE_GUILD_APPLICATION_COMMAND: "Action"
    DISCORD_UPDATE_GUILD_EMOJI: "Action"
    DISCORD_UPDATE_GUILD_MEMBER: "Action"
    DISCORD_UPDATE_GUILD_ROLE: "Action"
    DISCORD_UPDATE_GUILD_SCHEDULED_EVENT: "Action"
    DISCORD_UPDATE_GUILD_STICKER: "Action"
    DISCORD_UPDATE_GUILD_TEMPLATE: "Action"
    DISCORD_UPDATE_GUILD_WELCOME_SCREEN: "Action"
    DISCORD_UPDATE_GUILD_WIDGET_SETTINGS: "Action"
    DISCORD_UPDATE_MESSAGE: "Action"
    DISCORD_UPDATE_MY_APPLICATION: "Action"
    DISCORD_UPDATE_MY_GUILD_MEMBER: "Action"
    DISCORD_UPDATE_MY_USER: "Action"
    DISCORD_UPDATE_ORIGINAL_WEBHOOK_MESSAGE: "Action"
    DISCORD_UPDATE_SELF_VOICE_STATE: "Action"
    DISCORD_UPDATE_VOICE_STATE: "Action"
    DISCORD_UPDATE_WEBHOOK: "Action"
    DISCORD_UPDATE_WEBHOOK_BY_TOKEN: "Action"
    DISCORD_UPDATE_WEBHOOK_MESSAGE: "Action"
    DROPBOX_GET_ABOUT_ME: "Action"
    ELEVENLABS_ADD_A_PRONUNCIATION_DICTIONARY: "Action"
    ELEVENLABS_ADD_PROJECT: "Action"
    ELEVENLABS_ADD_RULES_TO_THE_PRONUNCIATION_DICTIONARY: "Action"
    ELEVENLABS_ADD_SHARING_VOICE: "Action"
    ELEVENLABS_ADD_VOICE: "Action"
    ELEVENLABS_CONVERT_CHAPTER: "Action"
    ELEVENLABS_CONVERT_PROJECT: "Action"
    ELEVENLABS_CREATES_AUDIONATIVE_ENABLED_PROJECT: "Action"
    ELEVENLABS_CREATE_A_PREVIOUSLY_GENERATED_VOICE: "Action"
    ELEVENLABS_DELETE_CHAPTER: "Action"
    ELEVENLABS_DELETE_DUBBING_PROJECT: "Action"
    ELEVENLABS_DELETE_HISTORY_ITEM: "Action"
    ELEVENLABS_DELETE_PROJECT: "Action"
    ELEVENLABS_DELETE_SAMPLE: "Action"
    ELEVENLABS_DELETE_VOICE: "Action"
    ELEVENLABS_DOWNLOAD_HISTORY_ITEMS: "Action"
    ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIO_FILE: "Action"
    ELEVENLABS_EDIT_VOICE: "Action"
    ELEVENLABS_EDIT_VOICE_SETTINGS: "Action"
    ELEVENLABS_GENERATE_A_RANDOM_VOICE: "Action"
    ELEVENLABS_GET_AUDIO_FROM_HISTORY_ITEM: "Action"
    ELEVENLABS_GET_AUDIO_FROM_SAMPLE: "Action"
    ELEVENLABS_GET_A_PROFILE_PAGE: "Action"
    ELEVENLABS_GET_CHAPTERS: "Action"
    ELEVENLABS_GET_CHAPTER_BY_ID: "Action"
    ELEVENLABS_GET_CHAPTER_SNAPSHOTS: "Action"
    ELEVENLABS_GET_DEFAULT_VOICE_SETTINGS: "Action"
    ELEVENLABS_GET_DUBBED_FILE: "Action"
    ELEVENLABS_GET_DUBBING_PROJECT_METADATA: "Action"
    ELEVENLABS_GET_GENERATED_ITEMS: "Action"
    ELEVENLABS_GET_HISTORY_ITEM_BY_ID: "Action"
    ELEVENLABS_GET_METADATA_FOR_A_PRONUNCIATION_DICTIONARY: "Action"
    ELEVENLABS_GET_MODELS: "Action"
    ELEVENLABS_GET_PLS_FILE_WITH_A_PRONUNCIATION_DICTIONARY_VERSION_RULES: "Action"
    ELEVENLABS_GET_PROJECTS: "Action"
    ELEVENLABS_GET_PROJECT_BY_ID: "Action"
    ELEVENLABS_GET_PROJECT_SNAPSHOTS: "Action"
    ELEVENLABS_GET_PRONUNCIATION_DICTIONARIES: "Action"
    ELEVENLABS_GET_SHARED_VOICES: "Action"
    ELEVENLABS_GET_SSO_PROVIDER_ADMIN: "Action"
    ELEVENLABS_GET_TRANSCRIPT_FOR_DUB: "Action"
    ELEVENLABS_GET_USER_INFO: "Action"
    ELEVENLABS_GET_USER_SUBSCRIPTION_INFO: "Action"
    ELEVENLABS_GET_VOICE: "Action"
    ELEVENLABS_GET_VOICES: "Action"
    ELEVENLABS_GET_VOICE_SETTINGS: "Action"
    ELEVENLABS_REDIRECT_TO_MINTLIFY: "Action"
    ELEVENLABS_REMOVE_RULES_FROM_THE_PRONUNCIATION_DICTIONARY: "Action"
    ELEVENLABS_SPEECH_TO_SPEECH: "Action"
    ELEVENLABS_SPEECH_TO_SPEECH_STREAMING: "Action"
    ELEVENLABS_STREAMS_ARCHIVE_WITH_PROJECT_AUDIO: "Action"
    ELEVENLABS_STREAM_CHAPTER_AUDIO: "Action"
    ELEVENLABS_STREAM_PROJECT_AUDIO: "Action"
    ELEVENLABS_TEXT_TO_SPEECH: "Action"
    ELEVENLABS_TEXT_TO_SPEECH_STREAM: "Action"
    ELEVENLABS_UPDATE_PRONUNCIATION_DICTIONARIES: "Action"
    ELEVENLABS_VOICE_GENERATION_PARAMETERS: "Action"
    EMBEDTOOL_CREATE_IMAGE_VECTOR_STORE: "Action"
    EMBEDTOOL_QUERY_IMAGE_VECTOR_STORE: "Action"
    EXA_SEARCH: "Action"
    EXA_SIMILARLINK: "Action"
    FIGMA_ADD_A_COMMENT_TO_A_FILE: "Action"
    FIGMA_ADD_A_REACTION_TO_A_COMMENT: "Action"
    FIGMA_CREATE_A_WEBHOOK: "Action"
    FIGMA_CREATE_DEV_RESOURCES: "Action"
    FIGMA_CREATE_MODIFY_DELETE_VARIABLES: "Action"
    FIGMA_DELETE_A_COMMENT: "Action"
    FIGMA_DELETE_A_REACTION: "Action"
    FIGMA_DELETE_A_WEBHOOK: "Action"
    FIGMA_DELETE_DEV_RESOURCE: "Action"
    FIGMA_GET_ACTIVITY_LOGS: "Action"
    FIGMA_GET_A_WEBHOOK: "Action"
    FIGMA_GET_COMMENTS_IN_A_FILE: "Action"
    FIGMA_GET_COMPONENT: "Action"
    FIGMA_GET_COMPONENT_SET: "Action"
    FIGMA_GET_CURRENT_USER: "Action"
    FIGMA_GET_DEV_RESOURCES: "Action"
    FIGMA_GET_FILES_IN_A_PROJECT: "Action"
    FIGMA_GET_FILE_COMPONENTS: "Action"
    FIGMA_GET_FILE_COMPONENT_SETS: "Action"
    FIGMA_GET_FILE_JSON: "Action"
    FIGMA_GET_FILE_JSON_FOR_SPECIFIC_NODES: "Action"
    FIGMA_GET_FILE_STYLES: "Action"
    FIGMA_GET_IMAGE_FILLS: "Action"
    FIGMA_GET_LOCAL_VARIABLES: "Action"
    FIGMA_GET_ME: "Action"
    FIGMA_GET_PAYMENTS: "Action"
    FIGMA_GET_PROJECTS_IN_A_TEAM: "Action"
    FIGMA_GET_PUBLISHED_VARIABLES: "Action"
    FIGMA_GET_REACTIONS_FOR_A_COMMENT: "Action"
    FIGMA_GET_STYLE: "Action"
    FIGMA_GET_TEAM_COMPONENTS: "Action"
    FIGMA_GET_TEAM_COMPONENT_SETS: "Action"
    FIGMA_GET_TEAM_STYLES: "Action"
    FIGMA_GET_TEAM_WEBHOOKS: "Action"
    FIGMA_GET_VERSIONS_OF_A_FILE: "Action"
    FIGMA_GET_WEBHOOK_REQUESTS: "Action"
    FIGMA_RENDER_IMAGES_OF_FILE_NODES: "Action"
    FIGMA_UPDATE_A_WEBHOOK: "Action"
    FIGMA_UPDATE_DEV_RESOURCES: "Action"
    FILEEDITTOOL_CREATE_FILE_CMD: "Action"
    FILEEDITTOOL_EDIT_FILE: "Action"
    FILEEDITTOOL_OPEN_FILE: "Action"
    FILEEDITTOOL_SCROLL: "Action"
    FILETOOL_CHANGE_WORKING_DIRECTORY: "Action"
    FILETOOL_CREATE_FILE: "Action"
    FILETOOL_EDIT_FILE: "Action"
    FILETOOL_FIND_FILE: "Action"
    FILETOOL_GIT_CLONE: "Action"
    FILETOOL_GIT_PATCH: "Action"
    FILETOOL_GIT_REPO_TREE: "Action"
    FILETOOL_LIST_FILES: "Action"
    FILETOOL_OPEN_FILE: "Action"
    FILETOOL_SCROLL: "Action"
    FILETOOL_SEARCH_WORD: "Action"
    FILETOOL_WRITE: "Action"
    FIRECRAWL_CHECK_CRAWL_STATUS: "Action"
    FIRECRAWL_CRAWL: "Action"
    FIRECRAWL_EXTRACT: "Action"
    FIRECRAWL_SCRAPE: "Action"
    FIRECRAWL_SEARCH: "Action"
    GITCMDTOOL_GET_PATCH_CMD: "Action"
    GITCMDTOOL_GITHUB_CLONE_CMD: "Action"
    GITCMDTOOL_GIT_REPO_TREE: "Action"
    GITHUB_ACCEPT_A_REPOSITORY_INVITATION: "Action"
    GITHUB_ACTIVITY_LIST_STARGAZERS_FOR_REPO: "Action"
    GITHUB_ACTIVITY_STAR_REPO_FOR_AUTHENTICATED_USER: "Action"
    GITHUB_ADD_AN_EMAIL_ADDRESS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_ADD_APP_ACCESS_RESTRICTIONS: "Action"
    GITHUB_ADD_ASSIGNEES_TO_AN_ISSUE: "Action"
    GITHUB_ADD_A_REPOSITORY_COLLABORATOR: "Action"
    GITHUB_ADD_A_REPOSITORY_TO_AN_APP_INSTALLATION: "Action"
    GITHUB_ADD_A_SECURITY_MANAGER_TEAM: "Action"
    GITHUB_ADD_A_SELECTED_REPOSITORY_TO_A_USER_SECRET: "Action"
    GITHUB_ADD_CUSTOM_LABELS_TO_A_SELF_HOSTED_RUNNER_FOR_AN_ORGANIZATION: "Action"
    GITHUB_ADD_CUSTOM_LABELS_TO_A_SELF_HOSTED_RUNNER_FOR_A_REPOSITORY: "Action"
    GITHUB_ADD_LABELS_TO_AN_ISSUE: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_MEMBERSHIP_FOR_A_USER_LEGACY: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_PROJECT_PERMISSIONS: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_PROJECT_PERMISSIONS_LEGACY: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_REPOSITORY_PERMISSIONS: "Action"
    GITHUB_ADD_OR_UPDATE_TEAM_REPOSITORY_PERMISSIONS_LEGACY: "Action"
    GITHUB_ADD_PROJECT_COLLABORATOR: "Action"
    GITHUB_ADD_REPO_TO_ORG_SECRET_WITH_SELECTED_ACCESS: "Action"
    GITHUB_ADD_REPO_TO_ORG_SECRET_WITH_SELECTED_VISIBILITY: "Action"
    GITHUB_ADD_SELECTED_REPOSITORY_TO_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_ADD_SELECTED_REPOSITORY_TO_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_ADD_SOCIAL_ACCOUNTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_ADD_STATUS_CHECK_CONTEXTS: "Action"
    GITHUB_ADD_TEAMS_TO_THE_COPILOT_SUBSCRIPTION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_ADD_TEAM_ACCESS_RESTRICTIONS: "Action"
    GITHUB_ADD_TEAM_MEMBER_LEGACY: "Action"
    GITHUB_ADD_USERS_TO_CODESPACES_ACCESS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_ADD_USERS_TO_THE_COPILOT_SUBSCRIPTION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_ADD_USER_ACCESS_RESTRICTIONS: "Action"
    GITHUB_APPROVE_A_WORKFLOW_RUN_FOR_A_FORK_PULL_REQUEST: "Action"
    GITHUB_ASSIGN_AN_ORGANIZATION_ROLE_TO_A_TEAM: "Action"
    GITHUB_ASSIGN_AN_ORGANIZATION_ROLE_TO_A_USER: "Action"
    GITHUB_AUTH_USER_DOCKER_CONFLICT_PACKAGES_LIST: "Action"
    GITHUB_BLOCK_A_USER: "Action"
    GITHUB_BLOCK_A_USER_FROM_AN_ORGANIZATION: "Action"
    GITHUB_CANCEL_AN_IMPORT: "Action"
    GITHUB_CANCEL_AN_ORGANIZATION_INVITATION: "Action"
    GITHUB_CANCEL_A_GITHUB_PAGES_DEPLOYMENT: "Action"
    GITHUB_CANCEL_A_WORKFLOW_RUN: "Action"
    GITHUB_CHECK_A_TOKEN: "Action"
    GITHUB_CHECK_IF_AUTOMATED_SECURITY_FIXES_ARE_ENABLED_FOR_A_REPOSITORY: "Action"
    GITHUB_CHECK_IF_A_GIST_IS_STARRED: "Action"
    GITHUB_CHECK_IF_A_PERSON_IS_FOLLOWED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CHECK_IF_A_PULL_REQUEST_HAS_BEEN_MERGED: "Action"
    GITHUB_CHECK_IF_A_REPOSITORY_IS_STARRED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CHECK_IF_A_USER_CAN_BE_ASSIGNED: "Action"
    GITHUB_CHECK_IF_A_USER_CAN_BE_ASSIGNED_TO_A_ISSUE: "Action"
    GITHUB_CHECK_IF_A_USER_FOLLOWS_ANOTHER_USER: "Action"
    GITHUB_CHECK_IF_A_USER_IS_A_REPOSITORY_COLLABORATOR: "Action"
    GITHUB_CHECK_IF_A_USER_IS_BLOCKED_BY_AN_ORGANIZATION: "Action"
    GITHUB_CHECK_IF_A_USER_IS_BLOCKED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CHECK_IF_VULNERABILITY_ALERTS_ARE_ENABLED_FOR_A_REPOSITORY: "Action"
    GITHUB_CHECK_ORGANIZATION_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_CHECK_PRIVATE_VULNERABILITY_REPORTING_STATUS: "Action"
    GITHUB_CHECK_PUBLIC_ORGANIZATION_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_A_PROJECT: "Action"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_A_PROJECT_LEGACY: "Action"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_A_REPOSITORY_LEGACY: "Action"
    GITHUB_CLEAR_REPOSITORY_CACHE_BY_KEY: "Action"
    GITHUB_CLEAR_SELF_HOSTED_RUNNER_ORG_LABELS: "Action"
    GITHUB_COMPARE_TWO_COMMITS: "Action"
    GITHUB_CONFIGURE_JITRUNNER_FOR_ORG: "Action"
    GITHUB_CONFIGURE_OIDCSUBJECT_CLAIM_TEMPLATE: "Action"
    GITHUB_CONVERT_AN_ORGANIZATION_MEMBER_TO_OUTSIDE_COLLABORATOR: "Action"
    GITHUB_CREATE_AN_AUTOLINK_REFERENCE_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_AN_ENVIRONMENT_VARIABLE: "Action"
    GITHUB_CREATE_AN_INSTALLATION_ACCESS_TOKEN_FOR_AN_APP: "Action"
    GITHUB_CREATE_AN_ISSUE: "Action"
    GITHUB_CREATE_AN_ISSUE_COMMENT: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_INVITATION: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_PROJECT: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_REPOSITORY: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_REPOSITORY_RULESET: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_CREATE_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_CREATE_A_BLOB: "Action"
    GITHUB_CREATE_A_CHECK_RUN: "Action"
    GITHUB_CREATE_A_CHECK_SUITE: "Action"
    GITHUB_CREATE_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_A_CODESPACE_FROM_A_PULL_REQUEST: "Action"
    GITHUB_CREATE_A_CODESPACE_IN_A_REPOSITORY: "Action"
    GITHUB_CREATE_A_COMMIT: "Action"
    GITHUB_CREATE_A_COMMIT_COMMENT: "Action"
    GITHUB_CREATE_A_COMMIT_STATUS: "Action"
    GITHUB_CREATE_A_CUSTOM_DEPLOYMENT_PROTECTION_RULE_ON_AN_ENVIRONMENT: "Action"
    GITHUB_CREATE_A_CUSTOM_ORGANIZATION_ROLE: "Action"
    GITHUB_CREATE_A_DEPLOYMENT: "Action"
    GITHUB_CREATE_A_DEPLOYMENT_BRANCH_POLICY: "Action"
    GITHUB_CREATE_A_DEPLOYMENT_STATUS: "Action"
    GITHUB_CREATE_A_DEPLOY_KEY: "Action"
    GITHUB_CREATE_A_DISCUSSION: "Action"
    GITHUB_CREATE_A_DISCUSSION_COMMENT: "Action"
    GITHUB_CREATE_A_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_CREATE_A_DISCUSSION_LEGACY: "Action"
    GITHUB_CREATE_A_FORK: "Action"
    GITHUB_CREATE_A_GIST: "Action"
    GITHUB_CREATE_A_GIST_COMMENT: "Action"
    GITHUB_CREATE_A_GITHUB_APP_FROM_A_MANIFEST: "Action"
    GITHUB_CREATE_A_GITHUB_PAGES_DEPLOYMENT: "Action"
    GITHUB_CREATE_A_GITHUB_PAGES_SITE: "Action"
    GITHUB_CREATE_A_GPG_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_A_LABEL: "Action"
    GITHUB_CREATE_A_MILESTONE: "Action"
    GITHUB_CREATE_A_PROJECT_CARD: "Action"
    GITHUB_CREATE_A_PROJECT_COLUMN: "Action"
    GITHUB_CREATE_A_PUBLIC_SSH_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_A_PULL_REQUEST: "Action"
    GITHUB_CREATE_A_REFERENCE: "Action"
    GITHUB_CREATE_A_REGISTRATION_TOKEN_FOR_AN_ORGANIZATION: "Action"
    GITHUB_CREATE_A_REGISTRATION_TOKEN_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_A_RELEASE: "Action"
    GITHUB_CREATE_A_REMOVE_TOKEN_FOR_AN_ORGANIZATION: "Action"
    GITHUB_CREATE_A_REMOVE_TOKEN_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_A_REPLY_FOR_A_REVIEW_COMMENT: "Action"
    GITHUB_CREATE_A_REPOSITORY_DISPATCH_EVENT: "Action"
    GITHUB_CREATE_A_REPOSITORY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_A_REPOSITORY_FROM_AN_UNPUBLISHED_CODESPACE: "Action"
    GITHUB_CREATE_A_REPOSITORY_PROJECT: "Action"
    GITHUB_CREATE_A_REPOSITORY_RULESET: "Action"
    GITHUB_CREATE_A_REPOSITORY_SECURITY_ADVISORY: "Action"
    GITHUB_CREATE_A_REPOSITORY_USING_A_TEMPLATE: "Action"
    GITHUB_CREATE_A_REPOSITORY_VARIABLE: "Action"
    GITHUB_CREATE_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_CREATE_A_REVIEW_COMMENT_FOR_A_PULL_REQUEST: "Action"
    GITHUB_CREATE_A_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_CREATE_A_SCOPED_ACCESS_TOKEN: "Action"
    GITHUB_CREATE_A_SNAPSHOT_OF_DEPENDENCIES_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_A_SSH_SIGNING_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_A_TAG_OBJECT: "Action"
    GITHUB_CREATE_A_TAG_PROTECTION_STATE_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_A_TEAM: "Action"
    GITHUB_CREATE_A_TEMPORARY_PRIVATE_FORK: "Action"
    GITHUB_CREATE_A_TREE: "Action"
    GITHUB_CREATE_A_USER_PROJECT: "Action"
    GITHUB_CREATE_A_WORKFLOW_DISPATCH_EVENT: "Action"
    GITHUB_CREATE_COMMIT_SIGNATURE_PROTECTION: "Action"
    GITHUB_CREATE_CONFIGURATION_FOR_A_JUST_IN_TIME_RUNNER_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_OR_UPDATE_AN_ENVIRONMENT: "Action"
    GITHUB_CREATE_OR_UPDATE_AN_ENVIRONMENT_SECRET: "Action"
    GITHUB_CREATE_OR_UPDATE_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_CREATE_OR_UPDATE_A_CUSTOM_PROPERTY_FOR_AN_ORGANIZATION: "Action"
    GITHUB_CREATE_OR_UPDATE_A_REPOSITORY_SECRET: "Action"
    GITHUB_CREATE_OR_UPDATE_A_SECRET_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_CREATE_OR_UPDATE_CUSTOM_PROPERTIES_FOR_AN_ORGANIZATION: "Action"
    GITHUB_CREATE_OR_UPDATE_CUSTOM_PROPERTY_VALUES_FOR_A_REPOSITORY: "Action"
    GITHUB_CREATE_OR_UPDATE_FILE_CONTENTS: "Action"
    GITHUB_CREATE_OR_UPDATE_REPO_SECRET_WITH_ENCRYPTED_VALUE: "Action"
    GITHUB_CREATE_REACTION_FOR_AN_ISSUE: "Action"
    GITHUB_CREATE_REACTION_FOR_AN_ISSUE_COMMENT: "Action"
    GITHUB_CREATE_REACTION_FOR_A_COMMIT_COMMENT: "Action"
    GITHUB_CREATE_REACTION_FOR_A_PULL_REQUEST_REVIEW_COMMENT: "Action"
    GITHUB_CREATE_REACTION_FOR_A_RELEASE: "Action"
    GITHUB_CREATE_REACTION_FOR_A_TEAM_DISCUSSION: "Action"
    GITHUB_CREATE_REACTION_FOR_A_TEAM_DISCUSSION_COMMENT: "Action"
    GITHUB_CREATE_REACTION_FOR_A_TEAM_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_CREATE_REACTION_FOR_A_TEAM_DISCUSSION_LEGACY: "Action"
    GITHUB_CREATE_UPDATE_ORG_SECRET_WITH_LIB_SODIUM: "Action"
    GITHUB_CUSTOMIZE_OIDC_SUBJECT_CLAIM_TEMPLATE: "Action"
    GITHUB_CUSTOM_OIDCSUBJECT_CLAIM_TEMPLATE: "Action"
    GITHUB_CUSTOM_OIDCSUBJECT_CLAIM_TEMPLATE_SETTER: "Action"
    GITHUB_DECLINE_A_REPOSITORY_INVITATION: "Action"
    GITHUB_DELETE_ACCESS_RESTRICTIONS: "Action"
    GITHUB_DELETE_ADMIN_BRANCH_PROTECTION: "Action"
    GITHUB_DELETE_AN_APP_AUTHORIZATION: "Action"
    GITHUB_DELETE_AN_APP_TOKEN: "Action"
    GITHUB_DELETE_AN_ARTIFACT: "Action"
    GITHUB_DELETE_AN_AUTOLINK_REFERENCE_FROM_A_REPOSITORY: "Action"
    GITHUB_DELETE_AN_EMAIL_ADDRESS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_AN_ENVIRONMENT: "Action"
    GITHUB_DELETE_AN_ENVIRONMENT_SECRET: "Action"
    GITHUB_DELETE_AN_ENVIRONMENT_VARIABLE: "Action"
    GITHUB_DELETE_AN_INSTALLATION_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_DELETE_AN_ISSUE_COMMENT: "Action"
    GITHUB_DELETE_AN_ISSUE_COMMENT_REACTION: "Action"
    GITHUB_DELETE_AN_ISSUE_REACTION: "Action"
    GITHUB_DELETE_AN_ORGANIZATION: "Action"
    GITHUB_DELETE_AN_ORGANIZATION_MIGRATION_ARCHIVE: "Action"
    GITHUB_DELETE_AN_ORGANIZATION_REPOSITORY_RULESET: "Action"
    GITHUB_DELETE_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_DELETE_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_DELETE_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_DELETE_AN_SSH_SIGNING_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_CODESPACE_FROM_THE_ORGANIZATION: "Action"
    GITHUB_DELETE_A_CODE_SCANNING_ANALYSIS_FROM_A_REPOSITORY: "Action"
    GITHUB_DELETE_A_COMMIT_COMMENT: "Action"
    GITHUB_DELETE_A_COMMIT_COMMENT_REACTION: "Action"
    GITHUB_DELETE_A_CUSTOM_ORGANIZATION_ROLE: "Action"
    GITHUB_DELETE_A_DEPLOYMENT: "Action"
    GITHUB_DELETE_A_DEPLOYMENT_BRANCH_POLICY: "Action"
    GITHUB_DELETE_A_DEPLOY_KEY: "Action"
    GITHUB_DELETE_A_DISCUSSION: "Action"
    GITHUB_DELETE_A_DISCUSSION_COMMENT: "Action"
    GITHUB_DELETE_A_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_DELETE_A_DISCUSSION_LEGACY: "Action"
    GITHUB_DELETE_A_FILE: "Action"
    GITHUB_DELETE_A_GIST: "Action"
    GITHUB_DELETE_A_GIST_COMMENT: "Action"
    GITHUB_DELETE_A_GITHUB_PAGES_SITE: "Action"
    GITHUB_DELETE_A_GPG_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_LABEL: "Action"
    GITHUB_DELETE_A_MILESTONE: "Action"
    GITHUB_DELETE_A_PACKAGE_FOR_AN_ORGANIZATION: "Action"
    GITHUB_DELETE_A_PACKAGE_FOR_A_USER: "Action"
    GITHUB_DELETE_A_PACKAGE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_PACKAGE_VERSION_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_PENDING_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_DELETE_A_PROJECT: "Action"
    GITHUB_DELETE_A_PROJECT_CARD: "Action"
    GITHUB_DELETE_A_PROJECT_COLUMN: "Action"
    GITHUB_DELETE_A_PUBLIC_SSH_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_PULL_REQUEST_COMMENT_REACTION: "Action"
    GITHUB_DELETE_A_REFERENCE: "Action"
    GITHUB_DELETE_A_RELEASE: "Action"
    GITHUB_DELETE_A_RELEASE_ASSET: "Action"
    GITHUB_DELETE_A_RELEASE_REACTION: "Action"
    GITHUB_DELETE_A_REPOSITORY: "Action"
    GITHUB_DELETE_A_REPOSITORY_INVITATION: "Action"
    GITHUB_DELETE_A_REPOSITORY_RULESET: "Action"
    GITHUB_DELETE_A_REPOSITORY_SECRET: "Action"
    GITHUB_DELETE_A_REPOSITORY_SUBSCRIPTION: "Action"
    GITHUB_DELETE_A_REPOSITORY_VARIABLE: "Action"
    GITHUB_DELETE_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_DELETE_A_REVIEW_COMMENT_FOR_A_PULL_REQUEST: "Action"
    GITHUB_DELETE_A_SECRET_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_A_SELF_HOSTED_RUNNER_FROM_AN_ORGANIZATION: "Action"
    GITHUB_DELETE_A_SELF_HOSTED_RUNNER_FROM_A_REPOSITORY: "Action"
    GITHUB_DELETE_A_TAG_PROTECTION_STATE_FOR_A_REPOSITORY: "Action"
    GITHUB_DELETE_A_TEAM: "Action"
    GITHUB_DELETE_A_TEAM_LEGACY: "Action"
    GITHUB_DELETE_A_THREAD_SUBSCRIPTION: "Action"
    GITHUB_DELETE_A_USER_MIGRATION_ARCHIVE: "Action"
    GITHUB_DELETE_A_WORKFLOW_RUN: "Action"
    GITHUB_DELETE_BRANCH_PROTECTION: "Action"
    GITHUB_DELETE_COMMIT_SIGNATURE_PROTECTION: "Action"
    GITHUB_DELETE_DEPENDEBOT_SECRET_BY_NAME: "Action"
    GITHUB_DELETE_GITHUB_ACTIONS_CACHE_BY_ID: "Action"
    GITHUB_DELETE_PACKAGE_VERSION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_DELETE_PACKAGE_VERSION_FOR_A_USER: "Action"
    GITHUB_DELETE_PULL_REQUEST_REVIEW_PROTECTION: "Action"
    GITHUB_DELETE_REPO_CODESPACE_SECRET_BY_NAME: "Action"
    GITHUB_DELETE_SOCIAL_ACCOUNTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_DELETE_TEAM_DISCUSSION_COMMENT_REACTION: "Action"
    GITHUB_DELETE_TEAM_DISCUSSION_REACTION: "Action"
    GITHUB_DELETE_WORKFLOW_RUN_LOGS: "Action"
    GITHUB_DISABLE_AUTOMATED_SECURITY_FIXES: "Action"
    GITHUB_DISABLE_A_CUSTOM_PROTECTION_RULE_FOR_AN_ENVIRONMENT: "Action"
    GITHUB_DISABLE_A_WORKFLOW: "Action"
    GITHUB_DISABLE_PRIVATE_VULNERABILITY_REPORTING_FOR_A_REPOSITORY: "Action"
    GITHUB_DISABLE_REPOSITORY_ACTIONS_IN_ORG: "Action"
    GITHUB_DISABLE_VULNERABILITY_ALERTS: "Action"
    GITHUB_DISMISS_A_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_DOWNLOAD_AN_ARTIFACT: "Action"
    GITHUB_DOWNLOAD_AN_ORGANIZATION_MIGRATION_ARCHIVE: "Action"
    GITHUB_DOWNLOAD_A_REPOSITORY_ARCHIVE_TAR: "Action"
    GITHUB_DOWNLOAD_A_REPOSITORY_ARCHIVE_ZIP: "Action"
    GITHUB_DOWNLOAD_A_USER_MIGRATION_ARCHIVE: "Action"
    GITHUB_DOWNLOAD_JOB_LOGS_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_DOWNLOAD_WORKFLOW_RUN_ATTEMPT_LOGS: "Action"
    GITHUB_DOWNLOAD_WORKFLOW_RUN_LOGS: "Action"
    GITHUB_ENABLE_AUTOMATED_SECURITY_FIXES: "Action"
    GITHUB_ENABLE_A_WORKFLOW: "Action"
    GITHUB_ENABLE_GITHUB_ACTIONS_IN_SELECTED_REPOSITORIES: "Action"
    GITHUB_ENABLE_OR_DISABLE_A_SECURITY_FEATURE_FOR_AN_ORGANIZATION: "Action"
    GITHUB_ENABLE_PRIVATE_VULNERABILITY_REPORTING_FOR_A_REPOSITORY: "Action"
    GITHUB_ENABLE_REPO_FORGITHUB_ACTIONS: "Action"
    GITHUB_ENABLE_VULNERABILITY_ALERTS: "Action"
    GITHUB_ENCRYPT_AND_UPDATE_DEV_SECRET: "Action"
    GITHUB_ENCRYPT_ORG_DEV_ENV_SECRET: "Action"
    GITHUB_ENCRYPT_ORG_SECRETS_USING_PUBLIC_KEY: "Action"
    GITHUB_EXPORT_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_EXPORT_A_SOFTWARE_BILL_OF_MATERIALS_SBOM_FOR_A_REPOSITORY: "Action"
    GITHUB_FETCH_PUBLIC_KEY_FOR_SECRET_ENCRYPTION: "Action"
    GITHUB_FIND_CONFLICTING_PACKAGES_FOR_DOCKER_MIGRATION: "Action"
    GITHUB_FOLLOW_A_USER: "Action"
    GITHUB_FORCE_CANCEL_A_WORKFLOW_RUN: "Action"
    GITHUB_FORK_A_GIST: "Action"
    GITHUB_GENERATE_RELEASE_NOTES_CONTENT_FOR_A_RELEASE: "Action"
    GITHUB_GET_ACCESS_RESTRICTIONS: "Action"
    GITHUB_GET_ADMIN_BRANCH_PROTECTION: "Action"
    GITHUB_GET_ALLOWED_ACTIONS_AND_REUSABLE_WORKFLOWS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_ALLOWED_ACTIONS_AND_REUSABLE_WORKFLOWS_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_ALL_API_VERSIONS: "Action"
    GITHUB_GET_ALL_AUTOLINKS_OF_A_REPOSITORY: "Action"
    GITHUB_GET_ALL_CODES_OF_CONDUCT: "Action"
    GITHUB_GET_ALL_COMMONLY_USED_LICENSES: "Action"
    GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY: "Action"
    GITHUB_GET_ALL_CUSTOM_PROPERTIES_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_ALL_CUSTOM_PROPERTY_VALUES_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_ALL_DEPLOYMENT_PROTECTION_RULES_FOR_AN_ENVIRONMENT: "Action"
    GITHUB_GET_ALL_GITIGNORE_TEMPLATES: "Action"
    GITHUB_GET_ALL_ORGANIZATION_REPOSITORY_RULESETS: "Action"
    GITHUB_GET_ALL_ORGANIZATION_ROLES_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_ALL_REPOSITORY_RULESETS: "Action"
    GITHUB_GET_ALL_REPOSITORY_TOPICS: "Action"
    GITHUB_GET_ALL_REQUESTED_REVIEWERS_FOR_A_PULL_REQUEST: "Action"
    GITHUB_GET_ALL_STATUS_CHECK_CONTEXTS: "Action"
    GITHUB_GET_AN_APP: "Action"
    GITHUB_GET_AN_ARTIFACT: "Action"
    GITHUB_GET_AN_ASSIGNMENT: "Action"
    GITHUB_GET_AN_AUTOLINK_REFERENCE_OF_A_REPOSITORY: "Action"
    GITHUB_GET_AN_ENVIRONMENT: "Action"
    GITHUB_GET_AN_ENVIRONMENT_PUBLIC_KEY: "Action"
    GITHUB_GET_AN_ENVIRONMENT_SECRET: "Action"
    GITHUB_GET_AN_ENVIRONMENT_VARIABLE: "Action"
    GITHUB_GET_AN_IMPORT_STATUS: "Action"
    GITHUB_GET_AN_INSTALLATION_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_GET_AN_ISSUE: "Action"
    GITHUB_GET_AN_ISSUE_COMMENT: "Action"
    GITHUB_GET_AN_ISSUE_EVENT: "Action"
    GITHUB_GET_AN_ORGANIZATION: "Action"
    GITHUB_GET_AN_ORGANIZATION_INSTALLATION_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_GET_AN_ORGANIZATION_MEMBERSHIP_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_AN_ORGANIZATION_MIGRATION_STATUS: "Action"
    GITHUB_GET_AN_ORGANIZATION_PUBLIC_KEY: "Action"
    GITHUB_GET_AN_ORGANIZATION_REPOSITORY_RULESET: "Action"
    GITHUB_GET_AN_ORGANIZATION_ROLE: "Action"
    GITHUB_GET_AN_ORGANIZATION_RULE_SUITE: "Action"
    GITHUB_GET_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_GET_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_GET_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_GET_AN_SSH_SIGNING_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_APPS_WITH_ACCESS_TO_THE_PROTECTED_BRANCH: "Action"
    GITHUB_GET_ASSIGNMENT_GRADES: "Action"
    GITHUB_GET_A_BLOB: "Action"
    GITHUB_GET_A_BRANCH: "Action"
    GITHUB_GET_A_CHECK_RUN: "Action"
    GITHUB_GET_A_CHECK_SUITE: "Action"
    GITHUB_GET_A_CLASSROOM: "Action"
    GITHUB_GET_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_CODE_OF_CONDUCT: "Action"
    GITHUB_GET_A_CODE_QL_DATABASE_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_A_CODE_SCANNING_ALERT: "Action"
    GITHUB_GET_A_CODE_SCANNING_ANALYSIS_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_A_CODE_SCANNING_DEFAULT_SETUP_CONFIGURATION: "Action"
    GITHUB_GET_A_COMMIT: "Action"
    GITHUB_GET_A_COMMIT_COMMENT: "Action"
    GITHUB_GET_A_COMMIT_OBJECT: "Action"
    GITHUB_GET_A_CUSTOM_DEPLOYMENT_PROTECTION_RULE: "Action"
    GITHUB_GET_A_CUSTOM_PROPERTY_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_A_DELIVERY_FOR_AN_APP_WEBHOOK: "Action"
    GITHUB_GET_A_DELIVERY_FOR_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_GET_A_DEPENDABOT_ALERT: "Action"
    GITHUB_GET_A_DEPLOYMENT: "Action"
    GITHUB_GET_A_DEPLOYMENT_BRANCH_POLICY: "Action"
    GITHUB_GET_A_DEPLOYMENT_STATUS: "Action"
    GITHUB_GET_A_DEPLOY_KEY: "Action"
    GITHUB_GET_A_DIFF_OF_THE_DEPENDENCIES_BETWEEN_COMMITS: "Action"
    GITHUB_GET_A_DISCUSSION: "Action"
    GITHUB_GET_A_DISCUSSION_COMMENT: "Action"
    GITHUB_GET_A_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_GET_A_DISCUSSION_LEGACY: "Action"
    GITHUB_GET_A_DNS_HEALTH_CHECK_FOR_GITHUB_PAGES: "Action"
    GITHUB_GET_A_GIST: "Action"
    GITHUB_GET_A_GIST_COMMENT: "Action"
    GITHUB_GET_A_GIST_REVISION: "Action"
    GITHUB_GET_A_GITHUB_PAGES_SITE: "Action"
    GITHUB_GET_A_GITIGNORE_TEMPLATE: "Action"
    GITHUB_GET_A_GLOBAL_SECURITY_ADVISORY: "Action"
    GITHUB_GET_A_GPG_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_JOB_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_GET_A_LABEL: "Action"
    GITHUB_GET_A_LICENSE: "Action"
    GITHUB_GET_A_MILESTONE: "Action"
    GITHUB_GET_A_PACKAGE_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_A_PACKAGE_FOR_A_USER: "Action"
    GITHUB_GET_A_PACKAGE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_PACKAGE_VERSION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_A_PACKAGE_VERSION_FOR_A_USER: "Action"
    GITHUB_GET_A_PACKAGE_VERSION_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_PROJECT: "Action"
    GITHUB_GET_A_PROJECT_CARD: "Action"
    GITHUB_GET_A_PROJECT_COLUMN: "Action"
    GITHUB_GET_A_PUBLIC_SSH_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_PULL_REQUEST: "Action"
    GITHUB_GET_A_REFERENCE: "Action"
    GITHUB_GET_A_RELEASE: "Action"
    GITHUB_GET_A_RELEASE_ASSET: "Action"
    GITHUB_GET_A_RELEASE_BY_TAG_NAME: "Action"
    GITHUB_GET_A_REPOSITORY: "Action"
    GITHUB_GET_A_REPOSITORY_INSTALLATION_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_GET_A_REPOSITORY_PUBLIC_KEY: "Action"
    GITHUB_GET_A_REPOSITORY_README: "Action"
    GITHUB_GET_A_REPOSITORY_README_FOR_A_DIRECTORY: "Action"
    GITHUB_GET_A_REPOSITORY_RULESET: "Action"
    GITHUB_GET_A_REPOSITORY_RULE_SUITE: "Action"
    GITHUB_GET_A_REPOSITORY_SECRET: "Action"
    GITHUB_GET_A_REPOSITORY_SECURITY_ADVISORY: "Action"
    GITHUB_GET_A_REPOSITORY_SUBSCRIPTION: "Action"
    GITHUB_GET_A_REPOSITORY_VARIABLE: "Action"
    GITHUB_GET_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_GET_A_REVIEW_COMMENT_FOR_A_PULL_REQUEST: "Action"
    GITHUB_GET_A_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_GET_A_SECRET_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_SECRET_SCANNING_ALERT: "Action"
    GITHUB_GET_A_SELF_HOSTED_RUNNER_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_A_SELF_HOSTED_RUNNER_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_A_SUBSCRIPTION_PLAN_FOR_AN_ACCOUNT: "Action"
    GITHUB_GET_A_SUBSCRIPTION_PLAN_FOR_AN_ACCOUNT_STUBBED: "Action"
    GITHUB_GET_A_TAG: "Action"
    GITHUB_GET_A_TEAM_BY_NAME: "Action"
    GITHUB_GET_A_TEAM_LEGACY: "Action"
    GITHUB_GET_A_THREAD: "Action"
    GITHUB_GET_A_THREAD_SUBSCRIPTION_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_A_TREE: "Action"
    GITHUB_GET_A_USER: "Action"
    GITHUB_GET_A_USER_INSTALLATION_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_GET_A_USER_MIGRATION_STATUS: "Action"
    GITHUB_GET_A_WEBHOOK_CONFIGURATION_FOR_AN_APP: "Action"
    GITHUB_GET_A_WEBHOOK_CONFIGURATION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_A_WEBHOOK_CONFIGURATION_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_A_WEBHOOK_DELIVERY_FOR_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_GET_A_WORKFLOW: "Action"
    GITHUB_GET_A_WORKFLOW_RUN: "Action"
    GITHUB_GET_A_WORKFLOW_RUN_ATTEMPT: "Action"
    GITHUB_GET_BRANCH_PROTECTION: "Action"
    GITHUB_GET_COMMIT_AUTHORS: "Action"
    GITHUB_GET_COMMIT_SIGNATURE_PROTECTION: "Action"
    GITHUB_GET_COMMUNITY_PROFILE_METRICS: "Action"
    GITHUB_GET_CONTEXTUAL_INFORMATION_FOR_A_USER: "Action"
    GITHUB_GET_COPILOT_SEAT_ASSIGNMENT_DETAILS_FOR_A_USER: "Action"
    GITHUB_GET_COPILOT_SEAT_INFORMATION_AND_SETTINGS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_DEFAULT_ATTRIBUTES_FOR_A_CODESPACE: "Action"
    GITHUB_GET_DEFAULT_WORKFLOW_PERMISSIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_DEFAULT_WORKFLOW_PERMISSIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_DETAILS_ABOUT_A_CODESPACE_EXPORT: "Action"
    GITHUB_GET_EMOJIS: "Action"
    GITHUB_GET_FEEDS: "Action"
    GITHUB_GET_GITHUB_ACTIONS_BILLING_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_GITHUB_ACTIONS_BILLING_FOR_A_USER: "Action"
    GITHUB_GET_GITHUB_ACTIONS_CACHE_USAGE_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_GITHUB_ACTIONS_CACHE_USAGE_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_GITHUB_ACTIONS_PERMISSIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_GITHUB_ACTIONS_PERMISSIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_GITHUB_META_INFORMATION: "Action"
    GITHUB_GET_GITHUB_PACKAGES_BILLING_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_GITHUB_PACKAGES_BILLING_FOR_A_USER: "Action"
    GITHUB_GET_GITHUB_PAGES_BUILD: "Action"
    GITHUB_GET_INFORMATION_ABOUT_A_SARIF_UPLOAD: "Action"
    GITHUB_GET_INTERACTION_RESTRICTIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_INTERACTION_RESTRICTIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_INTERACTION_RESTRICTIONS_FOR_YOUR_PUBLIC_REPOSITORIES: "Action"
    GITHUB_GET_LARGE_FILES: "Action"
    GITHUB_GET_LATEST_PAGES_BUILD: "Action"
    GITHUB_GET_OCTOCAT: "Action"
    GITHUB_GET_ORGANIZATION_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_GET_ORG_DEV_ENVIRONMENT_SECRET_SAFELY: "Action"
    GITHUB_GET_PAGE_VIEWS: "Action"
    GITHUB_GET_PENDING_DEPLOYMENTS_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_GET_PROJECT_PERMISSION_FOR_A_USER: "Action"
    GITHUB_GET_PUBLIC_KEY_FOR_SECRET_ENCRYPTION: "Action"
    GITHUB_GET_PUBLIC_KEY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_PULL_REQUEST_REVIEW_PROTECTION: "Action"
    GITHUB_GET_RATE_LIMIT_STATUS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_REPOSITORY_CLONES: "Action"
    GITHUB_GET_REPOSITORY_CONTENT: "Action"
    GITHUB_GET_REPOSITORY_PERMISSIONS_FOR_A_USER: "Action"
    GITHUB_GET_REPOSITORY_SECRET_SECURELY: "Action"
    GITHUB_GET_REPO_DEV_ENV_SECRET: "Action"
    GITHUB_GET_RULES_FOR_A_BRANCH: "Action"
    GITHUB_GET_SHARED_STORAGE_BILLING_FOR_AN_ORGANIZATION: "Action"
    GITHUB_GET_SHARED_STORAGE_BILLING_FOR_A_USER: "Action"
    GITHUB_GET_SINGLE_ORG_SECRET_WITHOUT_DECRYPTION: "Action"
    GITHUB_GET_STATUS_CHECKS_PROTECTION: "Action"
    GITHUB_GET_TEAMS_WITH_ACCESS_TO_THE_PROTECTED_BRANCH: "Action"
    GITHUB_GET_TEAM_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_GET_TEAM_MEMBERSHIP_FOR_A_USER_LEGACY: "Action"
    GITHUB_GET_TEAM_MEMBER_LEGACY: "Action"
    GITHUB_GET_THE_AUTHENTICATED_APP: "Action"
    GITHUB_GET_THE_AUTHENTICATED_USER: "Action"
    GITHUB_GET_THE_COMBINED_STATUS_FOR_A_SPECIFIC_REFERENCE: "Action"
    GITHUB_GET_THE_HOURLY_COMMIT_COUNT_FOR_EACH_DAY: "Action"
    GITHUB_GET_THE_LAST_YEAR_OF_COMMIT_ACTIVITY: "Action"
    GITHUB_GET_THE_LATEST_RELEASE: "Action"
    GITHUB_GET_THE_LEVEL_OF_ACCESS_FOR_WORKFLOWS_OUTSIDE_OF_THE_REPOSITORY: "Action"
    GITHUB_GET_THE_LICENSE_FOR_A_REPOSITORY: "Action"
    GITHUB_GET_THE_REVIEW_HISTORY_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_GET_THE_STATUS_OF_A_GITHUB_PAGES_DEPLOYMENT: "Action"
    GITHUB_GET_THE_WEEKLY_COMMIT_ACTIVITY: "Action"
    GITHUB_GET_THE_WEEKLY_COMMIT_COUNT: "Action"
    GITHUB_GET_THE_ZEN_OF_GITHUB: "Action"
    GITHUB_GET_TOP_REFERRAL_PATHS: "Action"
    GITHUB_GET_TOP_REFERRAL_SOURCES: "Action"
    GITHUB_GET_USERS_WITH_ACCESS_TO_THE_PROTECTED_BRANCH: "Action"
    GITHUB_GET_WORKFLOW_RUN_USAGE: "Action"
    GITHUB_GET_WORKFLOW_USAGE: "Action"
    GITHUB_GITHUB_API_ROOT: "Action"
    GITHUB_ISSUES_LIST_FOR_REPO: "Action"
    GITHUB_LIST_ACCEPTED_ASSIGNMENTS_FOR_AN_ASSIGNMENT: "Action"
    GITHUB_LIST_ACCOUNTS_FOR_A_PLAN: "Action"
    GITHUB_LIST_ACCOUNTS_FOR_A_PLAN_STUBBED: "Action"
    GITHUB_LIST_ALL_COPILOT_SEAT_ASSIGNMENTS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_APP_INSTALLATIONS_ACCESSIBLE_TO_THE_USER_ACCESS_TOKEN: "Action"
    GITHUB_LIST_APP_INSTALLATIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_ARTIFACTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_ASSIGNEES: "Action"
    GITHUB_LIST_ASSIGNMENTS_FOR_A_CLASSROOM: "Action"
    GITHUB_LIST_AVAILABLE_MACHINE_TYPES_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_BRANCHES: "Action"
    GITHUB_LIST_BRANCHES_FOR_HEAD_COMMIT: "Action"
    GITHUB_LIST_CHECK_RUNS_FOR_A_GIT_REFERENCE: "Action"
    GITHUB_LIST_CHECK_RUNS_IN_A_CHECK_SUITE: "Action"
    GITHUB_LIST_CHECK_RUN_ANNOTATIONS: "Action"
    GITHUB_LIST_CHECK_SUITES_FOR_A_GIT_REFERENCE: "Action"
    GITHUB_LIST_CHILD_TEAMS: "Action"
    GITHUB_LIST_CHILD_TEAMS_LEGACY: "Action"
    GITHUB_LIST_CLASSROOMS: "Action"
    GITHUB_LIST_CODEOWNERS_ERRORS: "Action"
    GITHUB_LIST_CODESPACES_FOR_A_USER_IN_ORGANIZATION: "Action"
    GITHUB_LIST_CODESPACES_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_CODESPACES_FOR_THE_ORGANIZATION: "Action"
    GITHUB_LIST_CODESPACES_IN_A_REPOSITORY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_CODE_QL_DATABASES_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_CODE_SCANNING_ALERTS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_CODE_SCANNING_ALERTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_CODE_SCANNING_ANALYSES_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_COMMENTS_FOR_A_PULL_REQUEST_REVIEW: "Action"
    GITHUB_LIST_COMMITS: "Action"
    GITHUB_LIST_COMMITS_ON_A_PULL_REQUEST: "Action"
    GITHUB_LIST_COMMIT_COMMENTS: "Action"
    GITHUB_LIST_COMMIT_COMMENTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_COMMIT_STATUSES_FOR_A_REFERENCE: "Action"
    GITHUB_LIST_CUSTOM_PROPERTY_VALUES_FOR_ORGANIZATION_REPOSITORIES: "Action"
    GITHUB_LIST_DELIVERIES_FOR_AN_APP_WEBHOOK: "Action"
    GITHUB_LIST_DELIVERIES_FOR_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_LIST_DELIVERIES_FOR_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_LIST_DEPENDABOT_ALERTS_FOR_AN_ENTERPRISE: "Action"
    GITHUB_LIST_DEPENDABOT_ALERTS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_DEPENDABOT_ALERTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_DEPLOYMENTS: "Action"
    GITHUB_LIST_DEPLOYMENT_BRANCH_POLICIES: "Action"
    GITHUB_LIST_DEPLOYMENT_STATUSES: "Action"
    GITHUB_LIST_DEPLOY_KEYS: "Action"
    GITHUB_LIST_DISCUSSIONS: "Action"
    GITHUB_LIST_DISCUSSIONS_LEGACY: "Action"
    GITHUB_LIST_DISCUSSION_COMMENTS: "Action"
    GITHUB_LIST_DISCUSSION_COMMENTS_LEGACY: "Action"
    GITHUB_LIST_DOCKER_MIGRATION_CONFLICTS: "Action"
    GITHUB_LIST_EMAIL_ADDRESSES_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ENVIRONMENTS: "Action"
    GITHUB_LIST_ENVIRONMENT_CUSTOM_DEPLOYMENT_RULES: "Action"
    GITHUB_LIST_ENVIRONMENT_SECRETS: "Action"
    GITHUB_LIST_ENVIRONMENT_VARIABLES: "Action"
    GITHUB_LIST_EVENTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_EVENTS_RECEIVED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_FAILED_ORGANIZATION_INVITATIONS: "Action"
    GITHUB_LIST_FOLLOWERS_OF_A_USER: "Action"
    GITHUB_LIST_FOLLOWERS_OF_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_FORKS: "Action"
    GITHUB_LIST_GISTS_FOR_A_USER: "Action"
    GITHUB_LIST_GISTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_GIST_COMMENTS: "Action"
    GITHUB_LIST_GIST_COMMITS: "Action"
    GITHUB_LIST_GIST_FORKS: "Action"
    GITHUB_LIST_GITHUB_ACTIONS_CACHES_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_GITHUB_PAGES_BUILDS: "Action"
    GITHUB_LIST_GLOBAL_SECURITY_ADVISORIES: "Action"
    GITHUB_LIST_GPG_KEYS_FOR_A_USER: "Action"
    GITHUB_LIST_GPG_KEYS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_INSTALLATIONS_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_LIST_INSTALLATION_REQUESTS_FOR_THE_AUTHENTICATED_APP: "Action"
    GITHUB_LIST_INSTANCES_OF_A_CODE_SCANNING_ALERT: "Action"
    GITHUB_LIST_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ISSUE_COMMENTS: "Action"
    GITHUB_LIST_ISSUE_COMMENTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_ISSUE_EVENTS: "Action"
    GITHUB_LIST_ISSUE_EVENTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_JOBS_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_LIST_JOBS_FOR_A_WORKFLOW_RUN_ATTEMPT: "Action"
    GITHUB_LIST_LABELS_FOR_AN_ISSUE: "Action"
    GITHUB_LIST_LABELS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_LABELS_FOR_A_SELF_HOSTED_RUNNER_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_LABELS_FOR_A_SELF_HOSTED_RUNNER_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_LABELS_FOR_ISSUES_IN_A_MILESTONE: "Action"
    GITHUB_LIST_LOCATIONS_FOR_A_SECRET_SCANNING_ALERT: "Action"
    GITHUB_LIST_MACHINE_TYPES_FOR_A_CODESPACE: "Action"
    GITHUB_LIST_MATCHING_REFERENCES: "Action"
    GITHUB_LIST_MILESTONES: "Action"
    GITHUB_LIST_NOTIFICATIONS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ORGANIZATIONS: "Action"
    GITHUB_LIST_ORGANIZATIONS_FOR_A_USER: "Action"
    GITHUB_LIST_ORGANIZATIONS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ORGANIZATION_EVENTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ORGANIZATION_FINE_GRAINED_PERMISSIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_ORGANIZATION_INVITATION_TEAMS: "Action"
    GITHUB_LIST_ORGANIZATION_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ORGANIZATION_MEMBERS: "Action"
    GITHUB_LIST_ORGANIZATION_MEMBERSHIPS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_ORGANIZATION_MIGRATIONS: "Action"
    GITHUB_LIST_ORGANIZATION_PROJECTS: "Action"
    GITHUB_LIST_ORGANIZATION_REPOSITORIES: "Action"
    GITHUB_LIST_ORGANIZATION_RULE_SUITES: "Action"
    GITHUB_LIST_ORGANIZATION_SECRETS: "Action"
    GITHUB_LIST_ORGANIZATION_VARIABLES: "Action"
    GITHUB_LIST_ORGANIZATION_WEBHOOKS: "Action"
    GITHUB_LIST_ORG_LEVEL_CODESPACES_SECRETS: "Action"
    GITHUB_LIST_ORG_REPOS_WITHGITHUB_ACTIONS_ENABLED: "Action"
    GITHUB_LIST_ORG_RESOURCES_WITH_PERSONAL_TOKENS: "Action"
    GITHUB_LIST_ORG_RESOURCE_ACCESS_TOKENS: "Action"
    GITHUB_LIST_ORG_SECRETS_WITHOUT_VALUES: "Action"
    GITHUB_LIST_OUTSIDE_COLLABORATORS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_OWNED_PACKAGE_VERSIONS: "Action"
    GITHUB_LIST_PACKAGES_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_PACKAGES_FOR_A_USER: "Action"
    GITHUB_LIST_PACKAGES_FOR_THE_AUTHENTICATED_USER_S_NAMESPACE: "Action"
    GITHUB_LIST_PACKAGE_VERSIONS_FOR_A_PACKAGE_OWNED_BY_AN_ORGANIZATION: "Action"
    GITHUB_LIST_PACKAGE_VERSIONS_FOR_A_PACKAGE_OWNED_BY_A_USER: "Action"
    GITHUB_LIST_PENDING_ORGANIZATION_INVITATIONS: "Action"
    GITHUB_LIST_PENDING_TEAM_INVITATIONS: "Action"
    GITHUB_LIST_PENDING_TEAM_INVITATIONS_LEGACY: "Action"
    GITHUB_LIST_PLANS: "Action"
    GITHUB_LIST_PLANS_STUBBED: "Action"
    GITHUB_LIST_PROJECT_CARDS: "Action"
    GITHUB_LIST_PROJECT_COLLABORATORS: "Action"
    GITHUB_LIST_PROJECT_COLUMNS: "Action"
    GITHUB_LIST_PUBLIC_EMAIL_ADDRESSES_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_PUBLIC_EVENTS: "Action"
    GITHUB_LIST_PUBLIC_EVENTS_FOR_A_NETWORK_OF_REPOSITORIES: "Action"
    GITHUB_LIST_PUBLIC_EVENTS_FOR_A_USER: "Action"
    GITHUB_LIST_PUBLIC_EVENTS_RECEIVED_BY_A_USER: "Action"
    GITHUB_LIST_PUBLIC_GISTS: "Action"
    GITHUB_LIST_PUBLIC_KEYS_FOR_A_USER: "Action"
    GITHUB_LIST_PUBLIC_ORGANIZATION_EVENTS: "Action"
    GITHUB_LIST_PUBLIC_ORGANIZATION_MEMBERS: "Action"
    GITHUB_LIST_PUBLIC_REPOSITORIES: "Action"
    GITHUB_LIST_PUBLIC_SSH_KEYS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_PULL_REQUESTS: "Action"
    GITHUB_LIST_PULL_REQUESTS_ASSOCIATED_WITH_A_COMMIT: "Action"
    GITHUB_LIST_PULL_REQUESTS_FILES: "Action"
    GITHUB_LIST_REACTIONS_FOR_AN_ISSUE: "Action"
    GITHUB_LIST_REACTIONS_FOR_AN_ISSUE_COMMENT: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_COMMIT_COMMENT: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_PULL_REQUEST_REVIEW_COMMENT: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_RELEASE: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_TEAM_DISCUSSION: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_TEAM_DISCUSSION_COMMENT: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_TEAM_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_LIST_REACTIONS_FOR_A_TEAM_DISCUSSION_LEGACY: "Action"
    GITHUB_LIST_RELEASES: "Action"
    GITHUB_LIST_RELEASE_ASSETS: "Action"
    GITHUB_LIST_REPOSITORIES_ACCESSIBLE_TO_THE_APP_INSTALLATION: "Action"
    GITHUB_LIST_REPOSITORIES_ACCESSIBLE_TO_THE_USER_ACCESS_TOKEN: "Action"
    GITHUB_LIST_REPOSITORIES_FOR_A_USER: "Action"
    GITHUB_LIST_REPOSITORIES_FOR_A_USER_MIGRATION: "Action"
    GITHUB_LIST_REPOSITORIES_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_REPOSITORIES_IN_AN_ORGANIZATION_MIGRATION: "Action"
    GITHUB_LIST_REPOSITORIES_STARRED_BY_A_USER: "Action"
    GITHUB_LIST_REPOSITORIES_STARRED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_REPOSITORIES_WATCHED_BY_A_USER: "Action"
    GITHUB_LIST_REPOSITORIES_WATCHED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_REPOSITORY_ACTIVITIES: "Action"
    GITHUB_LIST_REPOSITORY_COLLABORATORS: "Action"
    GITHUB_LIST_REPOSITORY_CONTRIBUTORS: "Action"
    GITHUB_LIST_REPOSITORY_EVENTS: "Action"
    GITHUB_LIST_REPOSITORY_INVITATIONS: "Action"
    GITHUB_LIST_REPOSITORY_INVITATIONS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_REPOSITORY_ISSUES: "Action"
    GITHUB_LIST_REPOSITORY_LANGUAGES: "Action"
    GITHUB_LIST_REPOSITORY_NOTIFICATIONS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_REPOSITORY_ORGANIZATION_SECRETS: "Action"
    GITHUB_LIST_REPOSITORY_ORGANIZATION_VARIABLES: "Action"
    GITHUB_LIST_REPOSITORY_PROJECTS: "Action"
    GITHUB_LIST_REPOSITORY_RULE_SUITES: "Action"
    GITHUB_LIST_REPOSITORY_SECRETS: "Action"
    GITHUB_LIST_REPOSITORY_SECRETS_WITHOUT_DECRYPTING: "Action"
    GITHUB_LIST_REPOSITORY_SECURITY_ADVISORIES: "Action"
    GITHUB_LIST_REPOSITORY_SECURITY_ADVISORIES_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_REPOSITORY_TAGS: "Action"
    GITHUB_LIST_REPOSITORY_TEAMS: "Action"
    GITHUB_LIST_REPOSITORY_VARIABLES: "Action"
    GITHUB_LIST_REPOSITORY_WEBHOOKS: "Action"
    GITHUB_LIST_REPOSITORY_WORKFLOWS: "Action"
    GITHUB_LIST_REPOS_WITH_GHACTIONS_CACHE_USAGE: "Action"
    GITHUB_LIST_REPO_ACCESS_BY_TOKEN: "Action"
    GITHUB_LIST_REPO_DEV_CONTAINER_CONFIGS_FOR_USER: "Action"
    GITHUB_LIST_REPO_SECRETS_WITHOUT_VALUES: "Action"
    GITHUB_LIST_REVIEWS_FOR_A_PULL_REQUEST: "Action"
    GITHUB_LIST_REVIEW_COMMENTS_IN_A_REPOSITORY: "Action"
    GITHUB_LIST_REVIEW_COMMENTS_ON_A_PULL_REQUEST: "Action"
    GITHUB_LIST_RUNNER_APPLICATIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_RUNNER_APPLICATIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_SECRETS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_SECRET_SCANNING_ALERTS_FOR_AN_ENTERPRISE: "Action"
    GITHUB_LIST_SECRET_SCANNING_ALERTS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_SECRET_SCANNING_ALERTS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_SECURITY_MANAGER_TEAMS: "Action"
    GITHUB_LIST_SELECTED_REPOSITORIES_FOR_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_LIST_SELECTED_REPOSITORIES_FOR_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_LIST_SELECTED_REPOSITORIES_FOR_A_USER_SECRET: "Action"
    GITHUB_LIST_SELECTED_REPOS_FOR_SECRET_ACCESS: "Action"
    GITHUB_LIST_SELF_HOSTED_RUNNERS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_LIST_SELF_HOSTED_RUNNERS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_SOCIAL_ACCOUNTS_FOR_A_USER: "Action"
    GITHUB_LIST_SOCIAL_ACCOUNTS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_SSH_SIGNING_KEYS_FOR_A_USER: "Action"
    GITHUB_LIST_SSH_SIGNING_KEYS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_STARGAZERS: "Action"
    GITHUB_LIST_STARRED_GISTS: "Action"
    GITHUB_LIST_SUBSCRIPTIONS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_SUBSCRIPTIONS_FOR_THE_AUTHENTICATED_USER_STUBBED: "Action"
    GITHUB_LIST_TAG_PROTECTION_STATES_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_TEAMS: "Action"
    GITHUB_LIST_TEAMS_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_TEAMS_THAT_ARE_ASSIGNED_TO_AN_ORGANIZATION_ROLE: "Action"
    GITHUB_LIST_TEAM_MEMBERS: "Action"
    GITHUB_LIST_TEAM_MEMBERS_LEGACY: "Action"
    GITHUB_LIST_TEAM_PROJECTS: "Action"
    GITHUB_LIST_TEAM_PROJECTS_LEGACY: "Action"
    GITHUB_LIST_TEAM_REPOSITORIES: "Action"
    GITHUB_LIST_TEAM_REPOSITORIES_LEGACY: "Action"
    GITHUB_LIST_THE_PEOPLE_A_USER_FOLLOWS: "Action"
    GITHUB_LIST_THE_PEOPLE_THE_AUTHENTICATED_USER_FOLLOWS: "Action"
    GITHUB_LIST_TIMELINE_EVENTS_FOR_AN_ISSUE: "Action"
    GITHUB_LIST_TOKEN_ACCESS_REPOSITORIES: "Action"
    GITHUB_LIST_USERS: "Action"
    GITHUB_LIST_USERS_BLOCKED_BY_AN_ORGANIZATION: "Action"
    GITHUB_LIST_USERS_BLOCKED_BY_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_USERS_THAT_ARE_ASSIGNED_TO_AN_ORGANIZATION_ROLE: "Action"
    GITHUB_LIST_USER_ACCOUNT_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER: "Action"
    GITHUB_LIST_USER_MIGRATIONS: "Action"
    GITHUB_LIST_USER_PROJECTS: "Action"
    GITHUB_LIST_WATCHERS: "Action"
    GITHUB_LIST_WORKFLOW_RUNS_FOR_A_REPOSITORY: "Action"
    GITHUB_LIST_WORKFLOW_RUNS_FOR_A_WORKFLOW: "Action"
    GITHUB_LIST_WORKFLOW_RUN_ARTIFACTS: "Action"
    GITHUB_LOCK_AN_ISSUE: "Action"
    GITHUB_MANAGE_ACCESS_CONTROL_FOR_ORGANIZATION_CODESPACES: "Action"
    GITHUB_MANAGE_CUSTOM_PROPERTIES_FOR_ORG_REPOS: "Action"
    GITHUB_MANAGE_SECRETS_IN_SELECTED_REPOSITORIES_WITH_PROPER_ACCESS: "Action"
    GITHUB_MAP_A_COMMIT_AUTHOR: "Action"
    GITHUB_MARK_A_THREAD_AS_DONE: "Action"
    GITHUB_MARK_A_THREAD_AS_READ: "Action"
    GITHUB_MARK_NOTIFICATIONS_AS_READ: "Action"
    GITHUB_MARK_REPOSITORY_NOTIFICATIONS_AS_READ: "Action"
    GITHUB_MERGE_A_BRANCH: "Action"
    GITHUB_MERGE_A_PULL_REQUEST: "Action"
    GITHUB_META_ROOT: "Action"
    GITHUB_MOVE_A_PROJECT_CARD: "Action"
    GITHUB_MOVE_A_PROJECT_COLUMN: "Action"
    GITHUB_PING_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_PING_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_PRIVATELY_REPORT_A_SECURITY_VULNERABILITY: "Action"
    GITHUB_PULLS_CREATE: "Action"
    GITHUB_PULLS_CREATE_REVIEW: "Action"
    GITHUB_PULLS_CREATE_REVIEW_COMMENT: "Action"
    GITHUB_PULLS_LIST: "Action"
    GITHUB_REDELIVER_A_DELIVERY_FOR_AN_APP_WEBHOOK: "Action"
    GITHUB_REDELIVER_A_DELIVERY_FOR_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_REDELIVER_A_DELIVERY_FOR_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_REMOVE_ALL_LABELS_FROM_AN_ISSUE: "Action"
    GITHUB_REMOVE_ALL_ORGANIZATION_ROLES_FOR_A_TEAM: "Action"
    GITHUB_REMOVE_ALL_ORGANIZATION_ROLES_FOR_A_USER: "Action"
    GITHUB_REMOVE_AN_ORGANIZATION_MEMBER: "Action"
    GITHUB_REMOVE_AN_ORGANIZATION_ROLE_FROM_A_TEAM: "Action"
    GITHUB_REMOVE_AN_ORGANIZATION_ROLE_FROM_A_USER: "Action"
    GITHUB_REMOVE_APP_ACCESS_RESTRICTIONS: "Action"
    GITHUB_REMOVE_ASSIGNEES_FROM_AN_ISSUE: "Action"
    GITHUB_REMOVE_A_CUSTOM_PROPERTY_FOR_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_A_LABEL_FROM_AN_ISSUE: "Action"
    GITHUB_REMOVE_A_PROJECT_FROM_A_TEAM: "Action"
    GITHUB_REMOVE_A_PROJECT_FROM_A_TEAM_LEGACY: "Action"
    GITHUB_REMOVE_A_REPOSITORY_COLLABORATOR: "Action"
    GITHUB_REMOVE_A_REPOSITORY_FROM_AN_APP_INSTALLATION: "Action"
    GITHUB_REMOVE_A_REPOSITORY_FROM_A_TEAM: "Action"
    GITHUB_REMOVE_A_REPOSITORY_FROM_A_TEAM_LEGACY: "Action"
    GITHUB_REMOVE_A_SECURITY_MANAGER_TEAM: "Action"
    GITHUB_REMOVE_A_SELECTED_REPOSITORY_FROM_A_USER_SECRET: "Action"
    GITHUB_REMOVE_CUSTOM_LABELS_FROM_SELF_HOSTED_REPOSITORY_RUNNER: "Action"
    GITHUB_REMOVE_CUSTOM_LABEL_FROM_REPO_RUNNER: "Action"
    GITHUB_REMOVE_CUSTOM_LABEL_FROM_SELF_HOSTED_RUNNER: "Action"
    GITHUB_REMOVE_INTERACTION_RESTRICTIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_INTERACTION_RESTRICTIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_REMOVE_INTERACTION_RESTRICTIONS_FROM_YOUR_PUBLIC_REPOSITORIES: "Action"
    GITHUB_REMOVE_ORGANIZATION_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_REMOVE_ORG_DEV_ENV_SECRET_BY_NAME: "Action"
    GITHUB_REMOVE_ORG_SECRET_BY_NAME: "Action"
    GITHUB_REMOVE_OUTSIDE_COLLABORATOR_FROM_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_PUBLIC_ORG_MEMBERSHIP: "Action"
    GITHUB_REMOVE_REPO_FROM_ORG_DEV_ENV_SECRET: "Action"
    GITHUB_REMOVE_REPO_FROM_ORG_SECRET_WITH_SELECTED_VISIBILITY: "Action"
    GITHUB_REMOVE_REQUESTED_REVIEWERS_FROM_A_PULL_REQUEST: "Action"
    GITHUB_REMOVE_SELECTED_REPOSITORY_FROM_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_REMOVE_SELECTED_REPOSITORY_FROM_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_REMOVE_STATUS_CHECK_CONTEXTS: "Action"
    GITHUB_REMOVE_STATUS_CHECK_PROTECTION: "Action"
    GITHUB_REMOVE_TEAMS_FROM_THE_COPILOT_SUBSCRIPTION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_TEAM_ACCESS_RESTRICTIONS: "Action"
    GITHUB_REMOVE_TEAM_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_REMOVE_TEAM_MEMBERSHIP_FOR_A_USER_LEGACY: "Action"
    GITHUB_REMOVE_TEAM_MEMBER_LEGACY: "Action"
    GITHUB_REMOVE_USERS_FROM_CODESPACES_ACCESS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_USERS_FROM_THE_COPILOT_SUBSCRIPTION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_REMOVE_USER_ACCESS_RESTRICTIONS: "Action"
    GITHUB_REMOVE_USER_AS_A_COLLABORATOR: "Action"
    GITHUB_RENAME_A_BRANCH: "Action"
    GITHUB_RENDER_A_MARKDOWN_DOCUMENT: "Action"
    GITHUB_RENDER_A_MARKDOWN_DOCUMENT_IN_RAW_MODE: "Action"
    GITHUB_REPLACE_ALL_REPOSITORY_TOPICS: "Action"
    GITHUB_REPLACE_ORG_SECRET_VISIBILITY_TO_SELECTED: "Action"
    GITHUB_REPLACE_REPO_ACCESS_ON_ORG_DEV_ENV_SECRET_SET: "Action"
    GITHUB_REPO_S_CREATE_FOR_AUTHENTICATED_USER: "Action"
    GITHUB_REPO_S_GET_COMMIT: "Action"
    GITHUB_REPO_S_GET_CONTENT: "Action"
    GITHUB_REPO_S_LIST_FOR_ORG: "Action"
    GITHUB_REQUEST_A_CVE_FOR_A_REPOSITORY_SECURITY_ADVISORY: "Action"
    GITHUB_REQUEST_A_GITHUB_PAGES_BUILD: "Action"
    GITHUB_REQUEST_REVIEWERS_FOR_A_PULL_REQUEST: "Action"
    GITHUB_REREQUEST_A_CHECK_RUN: "Action"
    GITHUB_REREQUEST_A_CHECK_SUITE: "Action"
    GITHUB_RESET_A_TOKEN: "Action"
    GITHUB_RESTORE_A_PACKAGE_FOR_AN_ORGANIZATION: "Action"
    GITHUB_RESTORE_A_PACKAGE_FOR_A_USER: "Action"
    GITHUB_RESTORE_A_PACKAGE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_RESTORE_A_PACKAGE_VERSION_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_RESTORE_PACKAGE_VERSION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_RESTORE_PACKAGE_VERSION_FOR_A_USER: "Action"
    GITHUB_RETRIEVE_REPO_PUBLIC_KEY_FOR_ENCRYPTION: "Action"
    GITHUB_REVIEW_ACCESS_WITH_PERSONAL_TOKEN: "Action"
    GITHUB_REVIEW_CUSTOM_DEPLOYMENT_PROTECTION_RULES_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_REVIEW_PENDING_DEPLOYMENTS_FOR_A_WORKFLOW_RUN: "Action"
    GITHUB_REVIEW_RESOURCE_REQUESTS_WITH_FINE_GRAINED_TOKENS: "Action"
    GITHUB_REVOKE_AN_INSTALLATION_ACCESS_TOKEN: "Action"
    GITHUB_RE_RUN_A_JOB_FROM_A_WORKFLOW_RUN: "Action"
    GITHUB_RE_RUN_A_WORKFLOW: "Action"
    GITHUB_RE_RUN_FAILED_JOBS_FROM_A_WORKFLOW_RUN: "Action"
    GITHUB_SEARCH_CODE: "Action"
    GITHUB_SEARCH_COMMITS: "Action"
    GITHUB_SEARCH_ISSUES_AND_PULL_REQUESTS: "Action"
    GITHUB_SEARCH_LABELS: "Action"
    GITHUB_SEARCH_REPOSITORIES: "Action"
    GITHUB_SEARCH_REPO_S: "Action"
    GITHUB_SEARCH_TOPICS: "Action"
    GITHUB_SEARCH_USERS: "Action"
    GITHUB_SET_ADMIN_BRANCH_PROTECTION: "Action"
    GITHUB_SET_ALLOWED_ACTIONS_AND_REUSABLE_WORKFLOWS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_SET_ALLOWED_ACTIONS_AND_REUSABLE_WORKFLOWS_FOR_A_REPOSITORY: "Action"
    GITHUB_SET_APP_ACCESS_RESTRICTIONS: "Action"
    GITHUB_SET_A_REPOSITORY_SUBSCRIPTION: "Action"
    GITHUB_SET_A_THREAD_SUBSCRIPTION: "Action"
    GITHUB_SET_CUSTOM_LABELS_FOR_A_SELF_HOSTED_RUNNER_FOR_AN_ORGANIZATION: "Action"
    GITHUB_SET_CUSTOM_LABELS_FOR_A_SELF_HOSTED_RUNNER_FOR_A_REPOSITORY: "Action"
    GITHUB_SET_DEFAULT_WORKFLOW_PERMISSIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_SET_DEFAULT_WORKFLOW_PERMISSIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_SET_GITHUB_ACTIONS_PERMISSIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_SET_GITHUB_ACTIONS_PERMISSIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_SET_INTERACTION_RESTRICTIONS_FOR_AN_ORGANIZATION: "Action"
    GITHUB_SET_INTERACTION_RESTRICTIONS_FOR_A_REPOSITORY: "Action"
    GITHUB_SET_INTERACTION_RESTRICTIONS_FOR_YOUR_PUBLIC_REPOSITORIES: "Action"
    GITHUB_SET_LABELS_FOR_AN_ISSUE: "Action"
    GITHUB_SET_ORGANIZATION_MEMBERSHIP_FOR_A_USER: "Action"
    GITHUB_SET_PRIMARY_EMAIL_VISIBILITY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_SET_PUBLIC_ORGANIZATION_MEMBERSHIP_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_SET_SELECTED_REPOSITORIES_FOR_AN_ORGANIZATION_SECRET: "Action"
    GITHUB_SET_SELECTED_REPOSITORIES_FOR_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_SET_SELECTED_REPOSITORIES_FOR_A_USER_SECRET: "Action"
    GITHUB_SET_STATUS_CHECK_CONTEXTS: "Action"
    GITHUB_SET_TEAM_ACCESS_RESTRICTIONS: "Action"
    GITHUB_SET_THE_LEVEL_OF_ACCESS_FOR_WORKFLOWS_OUTSIDE_OF_THE_REPOSITORY: "Action"
    GITHUB_SET_USER_ACCESS_RESTRICTIONS: "Action"
    GITHUB_START_AN_IMPORT: "Action"
    GITHUB_START_AN_ORGANIZATION_MIGRATION: "Action"
    GITHUB_START_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_START_A_USER_MIGRATION: "Action"
    GITHUB_STAR_A_GIST: "Action"
    GITHUB_STAR_A_REPOSITORY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_STOP_A_CODESPACE_FOR_AN_ORGANIZATION_USER: "Action"
    GITHUB_STOP_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_SUBMIT_A_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_SUSPEND_AN_APP_INSTALLATION: "Action"
    GITHUB_SYNC_A_FORK_BRANCH_WITH_THE_UPSTREAM_REPOSITORY: "Action"
    GITHUB_TEST_THE_PUSH_REPOSITORY_WEBHOOK: "Action"
    GITHUB_TRANSFER_A_REPOSITORY: "Action"
    GITHUB_UNBLOCK_A_USER: "Action"
    GITHUB_UNBLOCK_A_USER_FROM_AN_ORGANIZATION: "Action"
    GITHUB_UNFOLLOW_A_USER: "Action"
    GITHUB_UNLOCK_AN_ISSUE: "Action"
    GITHUB_UNLOCK_AN_ORGANIZATION_REPOSITORY: "Action"
    GITHUB_UNLOCK_A_USER_REPOSITORY: "Action"
    GITHUB_UNSTAR_A_GIST: "Action"
    GITHUB_UNSTAR_A_REPOSITORY_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_UNSUSPEND_AN_APP_INSTALLATION: "Action"
    GITHUB_UPDATE_AN_ENVIRONMENT_VARIABLE: "Action"
    GITHUB_UPDATE_AN_EXISTING_PROJECT_CARD: "Action"
    GITHUB_UPDATE_AN_EXISTING_PROJECT_COLUMN: "Action"
    GITHUB_UPDATE_AN_IMPORT: "Action"
    GITHUB_UPDATE_AN_ISSUE: "Action"
    GITHUB_UPDATE_AN_ISSUE_COMMENT: "Action"
    GITHUB_UPDATE_AN_ORGANIZATION: "Action"
    GITHUB_UPDATE_AN_ORGANIZATION_MEMBERSHIP_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_UPDATE_AN_ORGANIZATION_REPOSITORY_RULESET: "Action"
    GITHUB_UPDATE_AN_ORGANIZATION_VARIABLE: "Action"
    GITHUB_UPDATE_AN_ORGANIZATION_WEBHOOK: "Action"
    GITHUB_UPDATE_A_CHECK_RUN: "Action"
    GITHUB_UPDATE_A_CODESPACE_FOR_THE_AUTHENTICATED_USER: "Action"
    GITHUB_UPDATE_A_CODE_SCANNING_ALERT: "Action"
    GITHUB_UPDATE_A_CODE_SCANNING_DEFAULT_SETUP_CONFIGURATION: "Action"
    GITHUB_UPDATE_A_COMMIT_COMMENT: "Action"
    GITHUB_UPDATE_A_CUSTOM_ORGANIZATION_ROLE: "Action"
    GITHUB_UPDATE_A_DEPENDABOT_ALERT: "Action"
    GITHUB_UPDATE_A_DEPLOYMENT_BRANCH_POLICY: "Action"
    GITHUB_UPDATE_A_DISCUSSION: "Action"
    GITHUB_UPDATE_A_DISCUSSION_COMMENT: "Action"
    GITHUB_UPDATE_A_DISCUSSION_COMMENT_LEGACY: "Action"
    GITHUB_UPDATE_A_DISCUSSION_LEGACY: "Action"
    GITHUB_UPDATE_A_GIST: "Action"
    GITHUB_UPDATE_A_GIST_COMMENT: "Action"
    GITHUB_UPDATE_A_LABEL: "Action"
    GITHUB_UPDATE_A_MILESTONE: "Action"
    GITHUB_UPDATE_A_PROJECT: "Action"
    GITHUB_UPDATE_A_PULL_REQUEST: "Action"
    GITHUB_UPDATE_A_PULL_REQUEST_BRANCH: "Action"
    GITHUB_UPDATE_A_REFERENCE: "Action"
    GITHUB_UPDATE_A_RELEASE: "Action"
    GITHUB_UPDATE_A_RELEASE_ASSET: "Action"
    GITHUB_UPDATE_A_REPOSITORY: "Action"
    GITHUB_UPDATE_A_REPOSITORY_INVITATION: "Action"
    GITHUB_UPDATE_A_REPOSITORY_RULESET: "Action"
    GITHUB_UPDATE_A_REPOSITORY_SECURITY_ADVISORY: "Action"
    GITHUB_UPDATE_A_REPOSITORY_VARIABLE: "Action"
    GITHUB_UPDATE_A_REPOSITORY_WEBHOOK: "Action"
    GITHUB_UPDATE_A_REVIEW_COMMENT_FOR_A_PULL_REQUEST: "Action"
    GITHUB_UPDATE_A_REVIEW_FOR_A_PULL_REQUEST: "Action"
    GITHUB_UPDATE_A_SECRET_SCANNING_ALERT: "Action"
    GITHUB_UPDATE_A_TEAM: "Action"
    GITHUB_UPDATE_A_TEAM_LEGACY: "Action"
    GITHUB_UPDATE_A_WEBHOOK_CONFIGURATION_FOR_AN_APP: "Action"
    GITHUB_UPDATE_A_WEBHOOK_CONFIGURATION_FOR_AN_ORGANIZATION: "Action"
    GITHUB_UPDATE_A_WEBHOOK_CONFIGURATION_FOR_A_REPOSITORY: "Action"
    GITHUB_UPDATE_BRANCH_PROTECTION: "Action"
    GITHUB_UPDATE_GIT_LFS_PREFERENCE: "Action"
    GITHUB_UPDATE_INFORMATION_ABOUT_A_GITHUB_PAGES_SITE: "Action"
    GITHUB_UPDATE_PULL_REQUEST_REVIEW_PROTECTION: "Action"
    GITHUB_UPDATE_REPOSITORY_PREFERENCES_FOR_CHECK_SUITES: "Action"
    GITHUB_UPDATE_RESOURCE_ACCESS_WITH_TOKENS: "Action"
    GITHUB_UPDATE_STATUS_CHECK_PROTECTION: "Action"
    GITHUB_UPDATE_THE_AUTHENTICATED_USER: "Action"
    GITHUB_UPDATE_TOKEN_ORG_ACCESS: "Action"
    GITHUB_UPLOAD_AN_ANALYSIS_AS_SARIF_DATA: "Action"
    GITHUB_UPLOAD_A_RELEASE_ASSET: "Action"
    GITHUB_USERS_GET_AUTHENTICATED: "Action"
    GITHUB_USERS_GET_BY_USERNAME: "Action"
    GITHUB_USERS_LIST_PUBLIC_EMAILS_FOR_AUTHENTICATED_USER: "Action"
    GITHUB_USERS_LIST_SOCIAL_ACCOUNTS_FOR_USER: "Action"
    GITHUB_VERIFY_DEV_CONTAINER_PERMISSIONS_ACCEPTED: "Action"
    GMAIL_ADD_LABEL_TO_EMAIL: "Action"
    GMAIL_CREATE_EMAIL_DRAFT: "Action"
    GMAIL_CREATE_LABEL: "Action"
    GMAIL_FETCH_EMAILS: "Action"
    GMAIL_FETCH_MESSAGE_BY_THREAD_ID: "Action"
    GMAIL_LIST_LABELS: "Action"
    GMAIL_LIST_THREADS: "Action"
    GMAIL_REPLY_TO_THREAD: "Action"
    GMAIL_SEND_EMAIL: "Action"
    GOOGLECALENDAR_CREATE_EVENT: "Action"
    GOOGLECALENDAR_DELETE_EVENT: "Action"
    GOOGLECALENDAR_DUPLICATE_CALENDAR: "Action"
    GOOGLECALENDAR_FIND_EVENT: "Action"
    GOOGLECALENDAR_FIND_FREE_SLOTS: "Action"
    GOOGLECALENDAR_GET_CALENDAR: "Action"
    GOOGLECALENDAR_GET_CURRENT_DATE_TIME: "Action"
    GOOGLECALENDAR_LIST_CALENDARS: "Action"
    GOOGLECALENDAR_PATCH_CALENDAR: "Action"
    GOOGLECALENDAR_QUICK_ADD: "Action"
    GOOGLECALENDAR_REMOVE_ATTENDEE: "Action"
    GOOGLECALENDAR_UPDATE_EVENT: "Action"
    GOOGLEDOCS_CREATE_DOCUMENT: "Action"
    GOOGLEDOCS_GET_DOCUMENT_BY_ID: "Action"
    GOOGLEDOCS_UPDATE_EXISTING_DOCUMENT: "Action"
    GOOGLEDRIVE_ADD_FILE_SHARING_PREFERENCE: "Action"
    GOOGLEDRIVE_COPY_FILE: "Action"
    GOOGLEDRIVE_CREATE_FILE_FROM_TEXT: "Action"
    GOOGLEDRIVE_CREATE_FOLDER: "Action"
    GOOGLEDRIVE_DELETE_FOLDER_OR_FILE: "Action"
    GOOGLEDRIVE_EDIT_FILE: "Action"
    GOOGLEDRIVE_EXPORT_FILE: "Action"
    GOOGLEDRIVE_FIND_FILE: "Action"
    GOOGLEDRIVE_FIND_FOLDER: "Action"
    GOOGLEMEET_CREATE_MEET: "Action"
    GOOGLEMEET_GET_CONFERENCE_RECORD_FOR_MEET: "Action"
    GOOGLEMEET_GET_MEET: "Action"
    GOOGLEMEET_GET_RECORDINGS_BY_CONFERENCE_RECORD_ID: "Action"
    GOOGLEMEET_GET_TRANSCRIPTS_BY_CONFERENCE_RECORD_ID: "Action"
    GOOGLESHEETS_BATCH_GET: "Action"
    GOOGLESHEETS_BATCH_UPDATE: "Action"
    GOOGLESHEETS_CLEAR_VALUES: "Action"
    GOOGLESHEETS_CREATE_GOOGLE_SHEET1: "Action"
    GOOGLESHEETS_GET_SPREADSHEET_INFO: "Action"
    GOOGLESHEETS_LOOKUP_SPREADSHEET_ROW: "Action"
    GOOGLETASKS_CLEAR_TASKS: "Action"
    GOOGLETASKS_CREATE_TASK_LIST: "Action"
    GOOGLETASKS_DELETE_TASK: "Action"
    GOOGLETASKS_DELETE_TASK_LIST: "Action"
    GOOGLETASKS_GET_TASK: "Action"
    GOOGLETASKS_GET_TASK_LIST: "Action"
    GOOGLETASKS_INSERT_TASK: "Action"
    GOOGLETASKS_LIST_TASKS: "Action"
    GOOGLETASKS_LIST_TASK_LISTS: "Action"
    GOOGLETASKS_PATCH_TASK: "Action"
    GOOGLETASKS_PATCH_TASK_LIST: "Action"
    GREPTILE_CODE_QUERY: "Action"
    HACKERNEWS_GET_FRONTPAGE: "Action"
    HACKERNEWS_GET_TODAYS_POSTS: "Action"
    HEROKU_CREATE_HEROKU_APP: "Action"
    HEROKU_DELETE_HEROKU_APP: "Action"
    HEROKU_GET_ACCOUNT_DELINQUENCY_INFO: "Action"
    HEROKU_GET_ACCOUNT_FEATURE_INFO: "Action"
    HEROKU_GET_ACCOUNT_FEATURE_LIST: "Action"
    HEROKU_GET_ACCOUNT_INFO: "Action"
    HEROKU_GET_HEROKU_APP_INFO: "Action"
    HEROKU_GET_HEROKU_APP_LIST: "Action"
    HEROKU_UPDATE_ACCOUNT_FEATURE: "Action"
    HEROKU_UPDATE_ACCOUNT_INFO: "Action"
    HISTORYFETCHERTOOL_GET_WORKSPACE_HISTORY: "Action"
    HUBSPOT_ADDS_A_TOKEN_TO_AN_EXISTING_EVENT_TEMPLATE: "Action"
    HUBSPOT_ADVANCED_PRODUCT_SEARCH_WITH_FILTERS_AND_PAGINATION: "Action"
    HUBSPOT_ADVANCED_SEARCH_FOR_CONTACT_RECORDS_WITH_FILTERS: "Action"
    HUBSPOT_ARCHIVE: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_COMPANIES_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_CONTACTS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_DEALS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_FEEDBACK_SUBMISSIONS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_LINE_ITEMS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_OBJECTS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_PRODUCTS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_PROPERTIES: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_QUOTES_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_BATCH_OF_TICKETS_BY_ID: "Action"
    HUBSPOT_ARCHIVE_A_PROPERTY: "Action"
    HUBSPOT_ARCHIVE_A_PROPERTY_GROUP: "Action"
    HUBSPOT_BATCH_FETCH_CRM_OBJECTS_BY_ID_OR_PROPERTIES: "Action"
    HUBSPOT_BATCH_READ_CONTACTS_BY_IDS_OR_PROPERTIES: "Action"
    HUBSPOT_BATCH_READ_LINE_ITEMS_BY_ID_OR_ATTRIBUTES: "Action"
    HUBSPOT_BATCH_READ_QUOTES_BY_ID_OR_UNIQUE_PROPERTIES: "Action"
    HUBSPOT_BATCH_UPDATE_CRM_OBJECTS_BY_ID_OR_PROPERTIES: "Action"
    HUBSPOT_CANCEL_AN_ACTIVE_IMPORT: "Action"
    HUBSPOT_CONFIGURE_A_CALLING_EXTENSION: "Action"
    HUBSPOT_CONFIGURE_CALL_RECORDING_SETTINGS_BY_APP_ID: "Action"
    HUBSPOT_CONFIGURE_VIDEO_CONFERENCE_APP_SETTINGS: "Action"
    HUBSPOT_CREATE: "Action"
    HUBSPOT_CREATES_MULTIPLE_EVENTS: "Action"
    HUBSPOT_CREATE_AN_ASSOCIATION: "Action"
    HUBSPOT_CREATE_AN_EVENT_TEMPLATE_FOR_YOUR_APP: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_COMPANIES: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_CONTACTS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_DEALS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_FEEDBACK_SUBMISSIONS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_LINE_ITEMS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_OBJECTS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_PRODUCTS: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_PROPERTIES: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_QUOTES: "Action"
    HUBSPOT_CREATE_A_BATCH_OF_TICKETS: "Action"
    HUBSPOT_CREATE_A_NEW_SCHEMA: "Action"
    HUBSPOT_CREATE_A_PIPELINE: "Action"
    HUBSPOT_CREATE_A_PIPELINE_STAGE: "Action"
    HUBSPOT_CREATE_A_PROPERTY: "Action"
    HUBSPOT_CREATE_A_PROPERTY_GROUP: "Action"
    HUBSPOT_CREATE_A_SINGLE_EVENT: "Action"
    HUBSPOT_DELETES_AN_EVENT_TEMPLATE_FOR_THE_APP: "Action"
    HUBSPOT_DELETE_A_PIPELINE: "Action"
    HUBSPOT_DELETE_A_PIPELINE_STAGE: "Action"
    HUBSPOT_DELETE_A_SCHEMA: "Action"
    HUBSPOT_DELETE_CALLING_SETTINGS: "Action"
    HUBSPOT_DELETE_SETTINGS: "Action"
    HUBSPOT_ERASE_CONTACT_FOR_COMPLIANCE_USING_EMAIL: "Action"
    HUBSPOT_FETCH_BATCH_OF_TICKETS_BY_ID_OR_PROPERTIES: "Action"
    HUBSPOT_FETCH_BATCH_PRODUCT_DETAILS_BY_ID_OR_PROPERTIES: "Action"
    HUBSPOT_FETCH_COMPANY_OBJECT_BY_ID_OR_PROPERTY: "Action"
    HUBSPOT_FETCH_CONTACTS_PAGE_WITH_CUSTOMIZABLE_PROPERTIES: "Action"
    HUBSPOT_FETCH_FEEDBACK_SUBMISSIONS_WITH_CUSTOMIZABLE_PROPERTIES: "Action"
    HUBSPOT_FETCH_MULTIPLE_COMPANIES_BY_IDS_OR_ATTRIBUTES: "Action"
    HUBSPOT_FETCH_MULTIPLE_FEEDBACK_SUBMISSIONS_BY_ID_OR_ATTRIBUTES: "Action"
    HUBSPOT_FETCH_OBJECT_BY_ID_WITH_SELECTIVE_PROPERTY_CONTROL: "Action"
    HUBSPOT_FETCH_OBJECT_DETAILS_BY_ID_OR_SPECIFIED_PROPERTY: "Action"
    HUBSPOT_FETCH_OBJECT_DETAILS_USING_QUOTE_ID: "Action"
    HUBSPOT_FETCH_OBJECT_DETAILS_USING_UNIQUE_ID_OR_PROPERTY: "Action"
    HUBSPOT_FETCH_PAGEABLE_DEAL_DATA_WITH_CUSTOMIZABLE_FIELDS: "Action"
    HUBSPOT_FETCH_PAGED_COMPANIES_WITH_SELECTIVE_PROPERTIES: "Action"
    HUBSPOT_FETCH_PAGINATED_OBJECT_DETAILS_WITH_CUSTOMIZABLE_PROPERTIES: "Action"
    HUBSPOT_FETCH_PAGINATED_TICKETS_WITH_CONFIGURABLE_PROPERTIES: "Action"
    HUBSPOT_FETCH_QUOTES_PAGE_WITH_CUSTOMIZABLE_PROPERTIES: "Action"
    HUBSPOT_FETCH_RECORDING_SETTINGS_BY_APP_ID: "Action"
    HUBSPOT_FETCH_SPECIFIC_FEEDBACK_SUBMISSION_DETAILS: "Action"
    HUBSPOT_FETCH_SPECIFIC_OBJECT_DETAILS_WITH_CUSTOMIZATION_OPTIONS: "Action"
    HUBSPOT_FETCH_TICKET_DETAILS_WITH_OPTIONAL_FILTERS: "Action"
    HUBSPOT_GDPR_DELETE: "Action"
    HUBSPOT_GENERATE_AND_RETURN_A_NEW_DEAL_OBJECT_WITH_ID: "Action"
    HUBSPOT_GENERATE_AND_RETURN_CONTACT_WITH_ID_AND_PROPERTIES: "Action"
    HUBSPOT_GENERATE_AND_RETURN_LINE_ITEM_WITH_UNIQUE_ID: "Action"
    HUBSPOT_GENERATE_AND_RETURN_NEW_QUOTE_OBJECT_WITH_ID: "Action"
    HUBSPOT_GENERATE_AND_RETURN_TICKET_WITH_ID_AND_PROPERTIES: "Action"
    HUBSPOT_GENERATE_CRMOBJECT_WITH_PROPERTIES_AND_ID: "Action"
    HUBSPOT_GETS_A_SPECIFIC_EVENT_TEMPLATE_FOR_YOUR_APP: "Action"
    HUBSPOT_GETS_THE_DETAIL_TEMPLATE_AS_RENDERED: "Action"
    HUBSPOT_GETS_THE_EVENT: "Action"
    HUBSPOT_GET_ACTIVE_IMPORTS: "Action"
    HUBSPOT_GET_ALL_SCHEMAS: "Action"
    HUBSPOT_GET_AN_EXISTING_SCHEMA: "Action"
    HUBSPOT_GET_A_PAGE_OF_OWNERS: "Action"
    HUBSPOT_GET_CALLING_SETTINGS: "Action"
    HUBSPOT_GET_SETTINGS: "Action"
    HUBSPOT_GET_THE_INFORMATION_ON_ANY_IMPORT: "Action"
    HUBSPOT_INITIALIZE_NEW_COMPANY_AND_RETURN_WITH_ID: "Action"
    HUBSPOT_LIST: "Action"
    HUBSPOT_LIST_ALL_EVENT_TEMPLATES_FOR_YOUR_APP: "Action"
    HUBSPOT_MERGE_TWO_COMPANIES_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_CONTACTS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_DEALS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_FEEDBACK_SUBMISSIONS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_LINE_ITEMS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_OBJECTS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_PRODUCTS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_QUOTES_WITH_SAME_TYPE: "Action"
    HUBSPOT_MERGE_TWO_TICKETS_WITH_SAME_TYPE: "Action"
    HUBSPOT_MODIFY_AND_CLEAR_OBJECT_PROPERTIES_FOR_SPECIFIED_ID: "Action"
    HUBSPOT_MODIFY_EXISTING_OBJECT_FIELDS_WITH_OPTIONAL_CLEARING: "Action"
    HUBSPOT_MODIFY_OBJECT_PROPERTIES: "Action"
    HUBSPOT_MODIFY_OBJECT_PROPERTIES_USING_UNIQUE_IDENTIFIERS: "Action"
    HUBSPOT_MODIFY_SPECIFIC_DEAL_PROPERTIES_BY_UNIQUE_ID: "Action"
    HUBSPOT_MODIFY_SPECIFIC_OBJECT_PROPERTIES_BY_TICKET_ID: "Action"
    HUBSPOT_MODIFY_SPECIFIED_COMPANY_PROPERTIES: "Action"
    HUBSPOT_MOVE_COMPANY_TO_RECYCLING_BIN: "Action"
    HUBSPOT_MOVE_DEAL_OBJECT_TO_RECYCLE_BIN: "Action"
    HUBSPOT_MOVE_LINE_ITEM_TO_RECYCLE_BIN: "Action"
    HUBSPOT_MOVE_OBJECT_TO_RECYCLING_BIN: "Action"
    HUBSPOT_MOVE_QUOTE_TO_RECYCLING_BIN: "Action"
    HUBSPOT_PARTIALLY_MODIFY_CONTACT_FIELDS_BASED_ON_CONTACT_ID: "Action"
    HUBSPOT_PERMANENTLY_ERASE_CONTACT_BY_EMAIL_AND_BLOCK_IF_ABSENT: "Action"
    HUBSPOT_PERMANENTLY_ERASE_CONTACT_VIA_EMAIL_FOR_COMPLIANCE: "Action"
    HUBSPOT_PERMANENTLY_REMOVE_CONTACT_BY_EMAIL_FOR_COMPLIANCE: "Action"
    HUBSPOT_PERMANENTLY_REMOVE_CONTACT_BY_EMAIL_FOR_GDPR_COMPLIANCE: "Action"
    HUBSPOT_PERMANENTLY_REMOVE_CONTACT_BY_EMAIL_WITH_BLOCKLIST: "Action"
    HUBSPOT_PERMANENTLY_REMOVE_CONTACT_BY_EMAIL_WITH_BLOCKLIST_ADDITION: "Action"
    HUBSPOT_PERMANENTLY_REMOVE_CONTACT_BY_EMAIL_WITH_BLOCKLIST_FALLBACK: "Action"
    HUBSPOT_PURGE_CRM_OBJECT_SCHEMA_BY_TYPE: "Action"
    HUBSPOT_READ: "Action"
    HUBSPOT_READ_ALL_PROPERTIES: "Action"
    HUBSPOT_READ_ALL_PROPERTY_GROUPS: "Action"
    HUBSPOT_READ_AND_CUSTOMIZE_LINE_ITEMS_WITH_SPECIFIED_PROPERTIES: "Action"
    HUBSPOT_READ_AN_OWNER_BY_GIVEN_ID_OR_USER_ID: "Action"
    HUBSPOT_READ_A_BATCH_OF_DEALS_BY_INTERNAL_ID_OR_UNIQUE_PROPERTY_VALUES: "Action"
    HUBSPOT_READ_A_BATCH_OF_PROPERTIES: "Action"
    HUBSPOT_READ_A_PROPERTY: "Action"
    HUBSPOT_READ_A_PROPERTY_GROUP: "Action"
    HUBSPOT_RECYCLE_CONTACT_BY_ID: "Action"
    HUBSPOT_RECYCLE_FEEDBACK_SUBMISSION_OBJECT: "Action"
    HUBSPOT_RECYCLE_TICKET_BY_ID: "Action"
    HUBSPOT_REMOVES_A_TOKEN_FROM_THE_EVENT_TEMPLATE: "Action"
    HUBSPOT_REMOVE_AN_ASSOCIATION: "Action"
    HUBSPOT_RENDERS_THE_HEADER_OR_DETAIL_AS_HTML: "Action"
    HUBSPOT_REPLACE_A_PIPELINE: "Action"
    HUBSPOT_REPLACE_A_PIPELINE_STAGE: "Action"
    HUBSPOT_RETRIEVE_ALL_PIPELINES: "Action"
    HUBSPOT_RETRIEVE_CRM_IMPORT_ERROR_DETAILS_WITH_PAGINATION: "Action"
    HUBSPOT_RETURN_ALL_STAGES_OF_A_PIPELINE: "Action"
    HUBSPOT_RETURN_AN_AUDIT_OF_ALL_CHANGES_TO_THE_PIPELINE: "Action"
    HUBSPOT_RETURN_AN_AUDIT_OF_ALL_CHANGES_TO_THE_PIPELINE_STAGE: "Action"
    HUBSPOT_RETURN_A_PIPELINE_BY_ID: "Action"
    HUBSPOT_RETURN_A_PIPELINE_STAGE_BY_ID: "Action"
    HUBSPOT_SEARCH_COMPANY_RECORDS_WITH_FILTERS_AND_PAGINATION: "Action"
    HUBSPOT_SEARCH_CRM_FEEDBACK_SUBMISSIONS_WITH_FILTERS: "Action"
    HUBSPOT_SEARCH_CRM_OBJECTS_BY_CRITERIA_WITH_PAGINATION: "Action"
    HUBSPOT_SEARCH_CRM_TICKETS_WITH_FILTERS_SORTING_AND_PAGINATION: "Action"
    HUBSPOT_SEARCH_DEALS_WITH_FILTERS_SORTING_AND_LIMITS: "Action"
    HUBSPOT_SEARCH_LINE_ITEMS_WITH_SPECIFIED_CRITERIA: "Action"
    HUBSPOT_SEARCH_QUOTES_WITH_FILTERS_SORTING_AND_PAGINATION: "Action"
    HUBSPOT_START_A_NEW_IMPORT: "Action"
    HUBSPOT_SUBMIT_FEEDBACK_WITH_PROPERTIES_AND_RETRIEVE_COPY: "Action"
    HUBSPOT_UPDATE: "Action"
    HUBSPOT_UPDATES_AN_EXISTING_TOKEN_ON_AN_EVENT_TEMPLATE: "Action"
    HUBSPOT_UPDATE_AN_EXISTING_EVENT_TEMPLATE: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_COMPANIES: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_CONTACTS: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_DEALS: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_FEEDBACK_SUBMISSIONS: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_LINE_ITEMS: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_PRODUCTS: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_QUOTES: "Action"
    HUBSPOT_UPDATE_A_BATCH_OF_TICKETS: "Action"
    HUBSPOT_UPDATE_A_PIPELINE: "Action"
    HUBSPOT_UPDATE_A_PIPELINE_STAGE: "Action"
    HUBSPOT_UPDATE_A_PROPERTY: "Action"
    HUBSPOT_UPDATE_A_PROPERTY_GROUP: "Action"
    HUBSPOT_UPDATE_A_SCHEMA: "Action"
    HUBSPOT_UPDATE_CALLING_SETTINGS_WITH_RECORDING_URL: "Action"
    HUBSPOT_UPDATE_SETTINGS: "Action"
    IMAGEANALYSER_IMAGE_ANALYSER: "Action"
    INDUCEDAI_EXTRACT_DATA: "Action"
    INDUCEDAI_GET_AUTONOMOUS_TASK_STATUS: "Action"
    INDUCEDAI_GET_DATA_EXTRACTION_STATUS: "Action"
    INDUCEDAI_PERFORM_AUTONOMOUS_TASK: "Action"
    INDUCEDAI_STOP_AUTONOMOUS_TASK: "Action"
    LINEAR_CREATE_LINEAR_ISSUE: "Action"
    LINEAR_LIST_LINEAR_PROJECTS: "Action"
    LINEAR_LIST_LINEAR_TEAMS: "Action"
    LISTENNOTES_BATCH_FETCH_BASIC_META_DATA_FOR_EPISODES: "Action"
    LISTENNOTES_BATCH_FETCH_BASIC_META_DATA_FOR_PODCASTS: "Action"
    LISTENNOTES_FETCH_AUDIENCE_DEMOGRAPHICS_FOR_A_PODCAST: "Action"
    LISTENNOTES_FETCH_A_CURATED_LIST_OF_PODCASTS_BY_ID: "Action"
    LISTENNOTES_FETCH_A_LIST_OF_BEST_PODCASTS_BY_GENRE: "Action"
    LISTENNOTES_FETCH_A_LIST_OF_PODCAST_GENRES: "Action"
    LISTENNOTES_FETCH_A_LIST_OF_SUPPORTED_COUNTRIES_REGIONS_FOR_BEST_PODCASTS: "Action"
    LISTENNOTES_FETCH_A_LIST_OF_SUPPORTED_LANGUAGES_FOR_PODCASTS: "Action"
    LISTENNOTES_FETCH_A_LIST_OF_YOUR_PLAYLISTS: "Action"
    LISTENNOTES_FETCH_A_PLAYLIST_S_INFO_AND_ITEMS_IE_EPISODES_OR_PODCASTS: "Action"
    LISTENNOTES_FETCH_A_RANDOM_PODCAST_EPISODE: "Action"
    LISTENNOTES_FETCH_CURATED_LISTS_OF_PODCASTS: "Action"
    LISTENNOTES_FETCH_DETAILED_META_DATA_AND_EPISODES_FOR_A_PODCAST_BY_ID: "Action"
    LISTENNOTES_FETCH_DETAILED_META_DATA_FOR_AN_EPISODE_BY_ID: "Action"
    LISTENNOTES_FETCH_PODCASTS_BY_A_PUBLISHER_S_DOMAIN_NAME: "Action"
    LISTENNOTES_FETCH_RECOMMENDATIONS_FOR_AN_EPISODE: "Action"
    LISTENNOTES_FETCH_RECOMMENDATIONS_FOR_A_PODCAST: "Action"
    LISTENNOTES_FETCH_RELATED_SEARCH_TERMS: "Action"
    LISTENNOTES_FETCH_TRENDING_SEARCH_TERMS: "Action"
    LISTENNOTES_FIND_INDIVIDUAL_EPISODES_BY_SEARCHING_FOR_THEIR_TITLES: "Action"
    LISTENNOTES_FULL_TEXT_SEARCH: "Action"
    LISTENNOTES_REFRESH_RSS_FEED_OF_A_PODCAST: "Action"
    LISTENNOTES_REQUEST_TO_DELETE_A_PODCAST: "Action"
    LISTENNOTES_SPELL_CHECK_ON_A_SEARCH_TERM: "Action"
    LISTENNOTES_SUBMIT_A_PODCAST_TO_LISTEN_NOTES_DATABASE: "Action"
    LISTENNOTES_TYPEAHEAD_SEARCH: "Action"
    MATHEMATICAL_CALCULATOR: "Action"
    MULTIONAI_CREATE_SESSION: "Action"
    MULTIONAI_DELETE_SESSION: "Action"
    MULTIONAI_LIST_SESSIONS: "Action"
    MULTIONAI_RETRIEVE_DATA: "Action"
    MULTIONAI_SCREENSHOT: "Action"
    MULTIONAI_STEP_SESSION: "Action"
    MULTIONAI_WEB_BROWSE: "Action"
    NASA_FETCH_API_SWAGGER_SPECIFICATION: "Action"
    NASA_FETCH_PROJECT_INFO_INCLUDING_STAKEHOLDERS_AND_LIBRARY_ITEMS: "Action"
    NASA_FIND_PROJECTS_MATCHING_SEARCH_TERMS: "Action"
    NASA_GET_ORGANIZATION_DETAILS_AND_INFO: "Action"
    NASA_LIST_AVAILABLE_ORGANIZATION_TYPES: "Action"
    NASA_LIST_AVAILABLE_TECHNOLOGY_PROJECT_IDS: "Action"
    NASA_LIST_ORGANIZATIONS_BY_NAME: "Action"
    NASA_ORGANIZATION_GET_LIST_BY_NAME: "Action"
    NASA_PROJECT_GET_INFO: "Action"
    NOTION_ADD_PAGE_CONTENT: "Action"
    NOTION_ARCHIVE_NOTION_PAGE: "Action"
    NOTION_CREATE_COMMENT: "Action"
    NOTION_CREATE_DATABASE: "Action"
    NOTION_CREATE_NOTION_PAGE: "Action"
    NOTION_DELETE_BLOCK: "Action"
    NOTION_FETCH_COMMENTS: "Action"
    NOTION_FETCH_DATABASE: "Action"
    NOTION_FETCH_NOTION_BLOCK: "Action"
    NOTION_FETCH_NOTION_CHILD_BLOCK: "Action"
    NOTION_FETCH_ROW: "Action"
    NOTION_GET_ABOUT_ME: "Action"
    NOTION_GET_ABOUT_USER: "Action"
    NOTION_INSERT_ROW_DATABASE: "Action"
    NOTION_LIST_USERS: "Action"
    NOTION_QUERY_DATABASE: "Action"
    NOTION_SEARCH_NOTION_PAGE: "Action"
    NOTION_UPDATE_ROW_DATABASE: "Action"
    NOTION_UPDATE_SCHEMA_DATABASE: "Action"
    OKTA_ACTIVATE_AN_AUTHENTICATOR: "Action"
    OKTA_ACTIVATE_APPLICATION: "Action"
    OKTA_ACTIVATE_AUTHORIZATION_SERVER_LIFECYCLE: "Action"
    OKTA_ACTIVATE_AUTHORIZATION_SERVER_POLICY: "Action"
    OKTA_ACTIVATE_AUTH_SERVER_POLICY_RULE: "Action"
    OKTA_ACTIVATE_A_CLIENT_SECRET: "Action"
    OKTA_ACTIVATE_A_GROUP_RULE: "Action"
    OKTA_ACTIVATE_A_POLICY_BY_ID: "Action"
    OKTA_ACTIVATE_A_SPECIFIED_INLINE_HOOK: "Action"
    OKTA_ACTIVATE_DEFAULT_PROVISIONING_CONNECTION_FOR_APPLICATION: "Action"
    OKTA_ACTIVATE_EVENT_HOOK_LIFECYCLE: "Action"
    OKTA_ACTIVATE_FACTOR: "Action"
    OKTA_ACTIVATE_IDENTITY_PROVIDER: "Action"
    OKTA_ACTIVATE_NETWORK_ZONE: "Action"
    OKTA_ACTIVATE_POLICY_RULE: "Action"
    OKTA_ACTIVATE_TRUSTED_ORIGIN_LIFECYCLE: "Action"
    OKTA_ACTIVATE_USER: "Action"
    OKTA_ADD_APPLICATION: "Action"
    OKTA_ADD_GROUP: "Action"
    OKTA_ADD_IDENTITY_PROVIDER: "Action"
    OKTA_ADD_INSTANCE_TO_GROUP_ADMIN_ROLE: "Action"
    OKTA_ADD_NETWORK_ZONE: "Action"
    OKTA_ADD_NEW_CLIENT_SECRET: "Action"
    OKTA_ADD_SMS_TEMPLATE: "Action"
    OKTA_ADD_USER_TO_GROUP: "Action"
    OKTA_ADD_X509_CERTIFICATE_PUBLIC_KEY: "Action"
    OKTA_ASSIGN_A_ROLE_TO_A_GROUP: "Action"
    OKTA_ASSIGN_A_ROLE_TO_A_SPECIFIC_USER: "Action"
    OKTA_ASSIGN_GROUP_TO_APPLICATION: "Action"
    OKTA_ASSIGN_ROLE_TO_APP_FOR_A_GROUP: "Action"
    OKTA_ASSIGN_USER_TO_APPLICATION_FOR_SSO_PROVISIONING: "Action"
    OKTA_CHANGE_PASSWORD: "Action"
    OKTA_CHANGE_RECOVERY_QUESTION: "Action"
    OKTA_CLONE_APPLICATION_KEY_CREDENTIAL: "Action"
    OKTA_CLONE_SIGNING_KEY_CREDENTIAL_FOR_ID_P: "Action"
    OKTA_CLOSE_SESSION: "Action"
    OKTA_CREATES_AND_MANAGES_POLICY_RULES: "Action"
    OKTA_CREATE_AND_MANAGE_EVENT_HOOKS: "Action"
    OKTA_CREATE_AND_MANAGE_POLICY_CONFIGURATIONS: "Action"
    OKTA_CREATE_AN_AUTHENTICATOR: "Action"
    OKTA_CREATE_AUTHORIZATION_SERVER_CLAIMS: "Action"
    OKTA_CREATE_AUTHORIZATION_SERVER_POLICY: "Action"
    OKTA_CREATE_AUTHORIZATION_SERVER_SCOPE: "Action"
    OKTA_CREATE_A_NEW_AUTHORIZATION_SERVER: "Action"
    OKTA_CREATE_CERTIFICATE: "Action"
    OKTA_CREATE_CUSTOM_AUTH_SERVER_POLICY_RULE: "Action"
    OKTA_CREATE_DOMAIN: "Action"
    OKTA_CREATE_EMAIL_TEMPLATE_CUSTOMIZATION: "Action"
    OKTA_CREATE_FEATURE_LIFECYCLE_SUCCESS: "Action"
    OKTA_CREATE_GROUP_RULE: "Action"
    OKTA_CREATE_INLINE_HOOK_CONFIGURATION: "Action"
    OKTA_CREATE_LINKED_OBJECT_ASSOCIATION: "Action"
    OKTA_CREATE_OR_MANAGE_CUSTOM_USER_TYPES: "Action"
    OKTA_CREATE_SESSION_WITH_SESSION_TOKEN: "Action"
    OKTA_CREATE_TRUSTED_ORIGIN_CONFIGURATION: "Action"
    OKTA_CREATE_USER: "Action"
    OKTA_DEACTIVATE_AN_EVENT_HOOK_LIFECYCLE: "Action"
    OKTA_DEACTIVATE_AN_INLINE_HOOK_BY_ID: "Action"
    OKTA_DEACTIVATE_APPLICATION: "Action"
    OKTA_DEACTIVATE_AUTHENTICATOR_LIFECYCLE: "Action"
    OKTA_DEACTIVATE_AUTHORIZATION_SERVER: "Action"
    OKTA_DEACTIVATE_AUTH_SERVER_POLICY: "Action"
    OKTA_DEACTIVATE_AUTH_SERVER_POLICY_RULE: "Action"
    OKTA_DEACTIVATE_A_CLIENT_SECRET: "Action"
    OKTA_DEACTIVATE_A_GROUP_RULE: "Action"
    OKTA_DEACTIVATE_DEFAULT_PROVISIONING_CONNECTION_FOR_APPLICATION: "Action"
    OKTA_DEACTIVATE_IDENTITY_PROVIDER: "Action"
    OKTA_DEACTIVATE_NETWORK_ZONE: "Action"
    OKTA_DEACTIVATE_POLICY: "Action"
    OKTA_DEACTIVATE_POLICY_RULE: "Action"
    OKTA_DEACTIVATE_TRUSTED_ORIGIN: "Action"
    OKTA_DEACTIVATE_USER: "Action"
    OKTA_DELETES_A_THEME_BACKGROUND_IMAGE: "Action"
    OKTA_DELETES_A_THEME_LOGO_THE_ORG_THEN_USES_THE_OKTA_DEFAULT_LOGO: "Action"
    OKTA_DELETE_AN_AUTHORIZATION_SERVER_S_AUTH_TOKEN: "Action"
    OKTA_DELETE_AN_ORIGIN_BY_ITS_ID: "Action"
    OKTA_DELETE_APPLICATION: "Action"
    OKTA_DELETE_AUTHORIZATION_SERVER_BY_ID: "Action"
    OKTA_DELETE_AUTHORIZATION_SERVER_CLAIM: "Action"
    OKTA_DELETE_A_GROUP_RULE: "Action"
    OKTA_DELETE_CLIENT_TOKEN_FROM_AUTH_SERVER: "Action"
    OKTA_DELETE_CSR_BY_ID_FOR_APPLICATION: "Action"
    OKTA_DELETE_CUSTOM_AUTH_SERVER_POLICY_RULE: "Action"
    OKTA_DELETE_DOMAIN: "Action"
    OKTA_DELETE_EMAIL_CUSTOMIZATION: "Action"
    OKTA_DELETE_EMAIL_TEMPLATE_CUSTOMIZATION: "Action"
    OKTA_DELETE_IDENTITY_PROVIDER: "Action"
    OKTA_DELETE_INLINE_HOOK_BY_ID_IF_INACTIVE: "Action"
    OKTA_DELETE_KEY: "Action"
    OKTA_DELETE_NETWORK_ZONE: "Action"
    OKTA_DELETE_POLICY_BY_ID_IN_AUTHORIZATION_SERVER: "Action"
    OKTA_DELETE_SCOPE_FROM_AUTHORIZATION_SERVER: "Action"
    OKTA_DELETE_THEME_FAVICON_TO_DEFAULT: "Action"
    OKTA_DELETE_USER: "Action"
    OKTA_DELETE_USER_LINKED_OBJECT: "Action"
    OKTA_DELETE_USER_LINKED_OBJECTS_BY_RELATIONSHIP: "Action"
    OKTA_DETACH_APP_ADMIN_ROLE_FROM_USER: "Action"
    OKTA_ENROLL_FACTOR: "Action"
    OKTA_ENUMERATE_ALL_POLICY_RULES_FOR_A_POLICY: "Action"
    OKTA_ENUMERATE_CUSTOM_AUTH_SERVER_POLICY_RULES: "Action"
    OKTA_ENUMERATE_ENROLLED_USER_FACTORS: "Action"
    OKTA_ENUMERATE_SUPPORTED_USER_ENROLLMENT_FACTORS: "Action"
    OKTA_EXECUTE_INLINE_HOOK_WITH_INPUT_FOR_TESTING: "Action"
    OKTA_EXPIRE_PASSWORD: "Action"
    OKTA_EXPIRE_TEMPORARY_PASSWORD: "Action"
    OKTA_EXTEND_OKTA_SUPPORT: "Action"
    OKTA_FETCHES_A_FEATURE_OBJECT_FOR_AN_APPLICATION: "Action"
    OKTA_FETCHES_THE_DEFAULT_PROVISIONING_CONNECTION_FOR_AN_APPLICATION: "Action"
    OKTA_FETCHES_THE_FEATURE_OBJECTS_FOR_AN_APPLICATION: "Action"
    OKTA_FETCHES_THE_GROUP_SCHEMA: "Action"
    OKTA_FETCHES_THE_SCHEMA_FOR_AN_APP_USER: "Action"
    OKTA_FETCHES_THE_SCHEMA_FOR_A_SCHEMA_ID: "Action"
    OKTA_FETCH_ALL_USER_TYPES_IN_ORG: "Action"
    OKTA_FETCH_AUTHORIZATION_SERVER_DETAILS: "Action"
    OKTA_FETCH_AUTHORIZATION_SERVER_POLICIES: "Action"
    OKTA_FETCH_AUTHORIZATION_SERVER_SCOPES: "Action"
    OKTA_FETCH_AUTH_SERVER_CLAIMS: "Action"
    OKTA_FETCH_A_LIST_OF_EVENTS_FROM_YOUR_OKTA_ORGANIZATION_SYSTEM_LOG: "Action"
    OKTA_FETCH_CSR_DETAILS_FOR_APP_CREDENTIAL: "Action"
    OKTA_FETCH_CUSTOM_AUTH_SERVER_POLICY_RULE_BY_ID: "Action"
    OKTA_FETCH_GROUP_ROLE_DETAILS: "Action"
    OKTA_FETCH_INLINE_HOOK_DETAILS_BY_TYPE: "Action"
    OKTA_FETCH_LINKED_ID_P_USER_BY_ID: "Action"
    OKTA_FETCH_SINGLE_APPLICATION_CONSENT_GRANT: "Action"
    OKTA_FETCH_SPECIFIC_EVENT_HOOK_DETAILS: "Action"
    OKTA_FETCH_SPECIFIC_USER_FACTOR: "Action"
    OKTA_FETCH_USER_LINKED_OBJECTS: "Action"
    OKTA_FETCH_USER_LINKED_OBJECTS_DETAILS: "Action"
    OKTA_FETCH_USER_TYPE_BY_ID: "Action"
    OKTA_FIND_USERS: "Action"
    OKTA_FORGOT_PASSWORD: "Action"
    OKTA_GENERATE_CERTIFICATE_SIGNING_REQUEST_FOR_APPLICATION: "Action"
    OKTA_GENERATE_CERTIFICATE_SIGNING_REQUEST_FOR_ID_P: "Action"
    OKTA_GENERATE_NEW_ID_P_SIGNING_KEY_CREDENTIAL: "Action"
    OKTA_GENERATE_X509_CERTIFICATE_FOR_APP_KEY: "Action"
    OKTA_GET_APPLICATION: "Action"
    OKTA_GET_ASSIGNED_APP_LINKS: "Action"
    OKTA_GET_ASSIGNED_GROUP_FOR_APPLICATION: "Action"
    OKTA_GET_ASSIGNED_ROLE_DETAILS_FOR_USER: "Action"
    OKTA_GET_ASSIGNED_USER_FOR_APPLICATION: "Action"
    OKTA_GET_AUTHENTICATOR_DETAILS: "Action"
    OKTA_GET_A_SPECIFIC_CLAIM_FROM_AN_AUTHORIZATION_SERVER: "Action"
    OKTA_GET_A_THEME_FOR_A_BRAND: "Action"
    OKTA_GET_BRAND: "Action"
    OKTA_GET_BRAND_THEMES: "Action"
    OKTA_GET_CERTIFICATE_SIGNING_REQUEST_DETAILS: "Action"
    OKTA_GET_CLIENT_AUTH_TOKEN_DETAILS: "Action"
    OKTA_GET_CLIENT_SECRET: "Action"
    OKTA_GET_CURRENT_THREAT_INSIGHT_CONFIG: "Action"
    OKTA_GET_DEFAULT_CONTENT_OF_EMAIL_TEMPLATE: "Action"
    OKTA_GET_DOMAIN: "Action"
    OKTA_GET_EMAIL_TEMPLATE: "Action"
    OKTA_GET_EMAIL_TEMPLATE_CUSTOMIZATION: "Action"
    OKTA_GET_GROUP_RULE: "Action"
    OKTA_GET_IDENTITY_PROVIDER: "Action"
    OKTA_GET_KEY: "Action"
    OKTA_GET_KEY_CREDENTIAL_FOR_APPLICATION: "Action"
    OKTA_GET_MEMBER_GROUPS: "Action"
    OKTA_GET_NETWORK_ZONE: "Action"
    OKTA_GET_OKTA_COMMUNICATION_SETTINGS: "Action"
    OKTA_GET_OKTA_SUPPORT_SETTINGS: "Action"
    OKTA_GET_ORG_CONTACT_TYPES: "Action"
    OKTA_GET_ORG_CONTACT_USER: "Action"
    OKTA_GET_ORG_PREFERENCES: "Action"
    OKTA_GET_ORG_SETTINGS: "Action"
    OKTA_GET_PREVIEW_CONTENT_OF_EMAIL_CUSTOMIZATION: "Action"
    OKTA_GET_PREVIEW_OF_EMAIL_TEMPLATE_DEFAULT_CONTENT: "Action"
    OKTA_GET_PROFILE_MAPPING: "Action"
    OKTA_GET_ROLE_SUBSCRIPTIONS_BY_NOTIFICATION_TYPE: "Action"
    OKTA_GET_SCOPE_DETAILS_FOR_AUTHORIZATION_SERVER: "Action"
    OKTA_GET_SESSION_DETAILS: "Action"
    OKTA_GET_SIGNING_KEY_CREDENTIAL_FOR_ID_P: "Action"
    OKTA_GET_SMS_TEMPLATE: "Action"
    OKTA_GET_SPECIFIC_APPLICATION_TOKEN_DETAILS: "Action"
    OKTA_GET_SPECIFIC_USER_CLIENT_REFRESH_TOKEN: "Action"
    OKTA_GET_SPECIFIC_USER_GRANT_DETAILS: "Action"
    OKTA_GET_TRUSTED_ORIGIN_DETAILS_BY_ID: "Action"
    OKTA_GET_USER: "Action"
    OKTA_GET_USER_LINKED_OBJECTS: "Action"
    OKTA_GET_USER_SUBSCRIPTION_BY_NOTIFICATION_TYPE: "Action"
    OKTA_GRANT_OAUTH20_SCOPE_CONSENT_FOR_APP: "Action"
    OKTA_GRANT_OKTA_SUPPORT: "Action"
    OKTA_HIDE_OKTA_UI_FOOTER: "Action"
    OKTA_IMAGE_FILE_REQUIREMENTS: "Action"
    OKTA_LINK_A_USER_TO_A_SOCIAL_ID_P_WITHOUT_A_TRANSACTION: "Action"
    OKTA_LISTING_ID_PS_ASSOCIATED_WITH_A_USER: "Action"
    OKTA_LISTS_ALL_AVAILABLE_AUTHENTICATORS: "Action"
    OKTA_LIST_ALL_SUBSCRIPTIONS_OF_A_CUSTOM_ROLE: "Action"
    OKTA_LIST_AND_MANAGE_AUTHORIZATION_SERVERS: "Action"
    OKTA_LIST_AND_MANAGE_FEATURE_DETAILS: "Action"
    OKTA_LIST_AND_MANAGE_TRUSTED_ORIGINS: "Action"
    OKTA_LIST_APPLICATIONS: "Action"
    OKTA_LIST_APPLICATION_SCOPE_CONSENT_GRANTS: "Action"
    OKTA_LIST_APPLICATION_TOKENS: "Action"
    OKTA_LIST_APP_TARGETS_FOR_GROUP_APP_ADMIN_ROLE: "Action"
    OKTA_LIST_ASSIGNED_APPLICATIONS: "Action"
    OKTA_LIST_ASSIGNED_ROLES_FOR_A_GROUP: "Action"
    OKTA_LIST_ASSIGNED_ROLES_FOR_A_USER: "Action"
    OKTA_LIST_AUTHORIZATION_SERVER_CLIENTS: "Action"
    OKTA_LIST_AUTHORIZATION_SERVER_CREDENTIAL_KEYS: "Action"
    OKTA_LIST_BRANDS: "Action"
    OKTA_LIST_CERTIFICATE_SIGNING_REQUESTS_FOR_APPLICATION: "Action"
    OKTA_LIST_CERTIFICATE_SIGNING_REQUESTS_FOR_ID_P: "Action"
    OKTA_LIST_CLIENT_SECRETS: "Action"
    OKTA_LIST_CLIENT_TOKENS_FOR_AN_AUTHORIZATION_SERVER: "Action"
    OKTA_LIST_DOMAINS: "Action"
    OKTA_LIST_EMAIL_TEMPLATES: "Action"
    OKTA_LIST_EMAIL_TEMPLATE_CUSTOMIZATION: "Action"
    OKTA_LIST_FEATURE_DEPENDENCIES: "Action"
    OKTA_LIST_FEATURE_DEPENDENTS: "Action"
    OKTA_LIST_GROUPS: "Action"
    OKTA_LIST_GROUPS_ASSIGNED_TO_APPLICATION: "Action"
    OKTA_LIST_GROUP_MEMBERS: "Action"
    OKTA_LIST_GROUP_RULES: "Action"
    OKTA_LIST_GROUP_RULES_BY_GROUP_ID: "Action"
    OKTA_LIST_IDENTITY_PROVIDERS: "Action"
    OKTA_LIST_KEYS: "Action"
    OKTA_LIST_KEY_CREDENTIALS_FOR_APPLICATION: "Action"
    OKTA_LIST_NETWORK_ZONES: "Action"
    OKTA_LIST_OR_MANAGE_EVENT_HOOKS: "Action"
    OKTA_LIST_PAGINATED_PROFILE_MAPPINGS: "Action"
    OKTA_LIST_REFRESH_TOKENS_FOR_SPECIFIC_USER_AND_CLIENT: "Action"
    OKTA_LIST_ROLE_TARGETS_FOR_GROUPS: "Action"
    OKTA_LIST_ROLE_TARGET_GROUPS_FOR_USER: "Action"
    OKTA_LIST_SIGNING_KEY_CREDENTIALS_FOR_ID_P: "Action"
    OKTA_LIST_SMS_TEMPLATES: "Action"
    OKTA_LIST_SPECIFIED_USER_GRANTS: "Action"
    OKTA_LIST_SUBSCRIPTIONS_OF_A_USER: "Action"
    OKTA_LIST_USERS: "Action"
    OKTA_LIST_USERS_ASSIGNED_TO_APPLICATION: "Action"
    OKTA_LIST_USER_ASSIGNED_APP_TARGETS_BY_ROLE: "Action"
    OKTA_LIST_USER_CLIENTS: "Action"
    OKTA_LIST_USER_CLIENT_GRANTS: "Action"
    OKTA_LIST_USER_SECURITY_QUESTIONS: "Action"
    OKTA_OPT_IN_ALL_USERS_TO_OKTA_COMMUNICATION_EMAILS: "Action"
    OKTA_OPT_OUT_ALL_USERS_FROM_OKTA_COMMUNICATION_EMAILS: "Action"
    OKTA_PARTIALLY_UPDATE_USER_SCHEMA_PROFILE_PROPERTIES: "Action"
    OKTA_PARTIAL_SMS_TEMPLATE_UPDATE: "Action"
    OKTA_PARTIAL_UPDATE_ORG_SETTING: "Action"
    OKTA_PARTIAL_USER_PROFILE_UPDATE: "Action"
    OKTA_PERMANENTLY_DELETES_A_SPECIFIED_USER_TYPE: "Action"
    OKTA_POLL_FACTOR_VERIFICATION_TRANSACTION_STATUS: "Action"
    OKTA_PREVIEW_SAML_APP_METADATA_BY_KEY_CREDENTIAL: "Action"
    OKTA_PUBLISH_CSR_LIFECYCLE_FOR_APP_WITH_CERTIFICATE_DETAILS: "Action"
    OKTA_PUBLISH_SIGNED_CSR_AS_ID_P_SIGNING_CREDENTIAL: "Action"
    OKTA_REACTIVATE_USER: "Action"
    OKTA_REFRESH_SESSION: "Action"
    OKTA_REMOVE_APPLICATION_SECRET: "Action"
    OKTA_REMOVE_APP_TARGET_FROM_GROUP_ROLE: "Action"
    OKTA_REMOVE_A_SPECIFIC_POLICY: "Action"
    OKTA_REMOVE_A_SPECIFIC_POLICY_RULE: "Action"
    OKTA_REMOVE_EVENT_HOOK_BY_ID: "Action"
    OKTA_REMOVE_GROUP: "Action"
    OKTA_REMOVE_GROUP_FROM_APPLICATION: "Action"
    OKTA_REMOVE_SMS_TEMPLATE: "Action"
    OKTA_REMOVE_TARGET_FROM_GROUP_ADMIN_ROLE: "Action"
    OKTA_REMOVE_TARGET_GROUP_FROM_ROLE: "Action"
    OKTA_REMOVE_USER_FROM_APPLICATION: "Action"
    OKTA_REMOVE_USER_FROM_GROUP: "Action"
    OKTA_REMOVE_USER_ROLE_TARGET_APP: "Action"
    OKTA_REMOVE_USER_TARGET_GROUP: "Action"
    OKTA_REPLACE_EXISTING_USER_TYPE: "Action"
    OKTA_RESET_FACTORS: "Action"
    OKTA_RESET_PASSWORD: "Action"
    OKTA_RETRIEVE_AUTHORIZATION_SERVER_POLICY_DETAILS: "Action"
    OKTA_RETRIEVE_A_SPECIFIC_POLICY_RULE: "Action"
    OKTA_RETRIEVE_FEATURE_DETAILS_BY_ID: "Action"
    OKTA_RETRIEVE_INLINE_HOOK_DETAILS_BY_ID: "Action"
    OKTA_RETRIEVE_POLICIES_BY_TYPE_WITH_OPTIONAL_STATUS_AND_EXPANSION: "Action"
    OKTA_RETRIEVE_POLICY_DETAILS_BY_ID: "Action"
    OKTA_REVOKE_ALL_APPLICATION_TOKENS: "Action"
    OKTA_REVOKE_ALL_USER_CLIENT_TOKENS: "Action"
    OKTA_REVOKE_ALL_USER_GRANTS: "Action"
    OKTA_REVOKE_ALL_USER_SESSIONS: "Action"
    OKTA_REVOKE_AND_DELETE_CSR_FOR_ID_P: "Action"
    OKTA_REVOKE_APPLICATION_PERMISSION: "Action"
    OKTA_REVOKE_APPLICATION_TOKEN: "Action"
    OKTA_REVOKE_OKTA_SUPPORT: "Action"
    OKTA_REVOKE_REFRESH_TOKEN: "Action"
    OKTA_REVOKE_USER_CLIENT_GRANTS: "Action"
    OKTA_REVOKE_USER_GRANT: "Action"
    OKTA_ROTATE_AUTHORIZATION_SERVER_KEY_LIFECYCLE: "Action"
    OKTA_SETS_THE_DEFAULT_PROVISIONING_CONNECTION_FOR_AN_APPLICATION: "Action"
    OKTA_SHOW_OKTA_UI_FOOTER: "Action"
    OKTA_SOCIAL_AUTHENTICATION_TOKEN_OPERATION: "Action"
    OKTA_SUBSCRIBE_A_CUSTOM_ROLE_TO_A_SPECIFIC_NOTIFICATION_TYPE: "Action"
    OKTA_SUBSCRIBE_TO_A_SPECIFIC_NOTIFICATION_TYPE: "Action"
    OKTA_SUSPEND_USER: "Action"
    OKTA_TARGET_APP_INSTANCE_FOR_ADMIN_ROLE_ASSIGNMENT: "Action"
    OKTA_TEST_PREVIEW_OF_EMAIL_TEMPLATE_DEFAULT_CONTENT: "Action"
    OKTA_UNASSIGN_ROLE_FROM_GROUP: "Action"
    OKTA_UNASSIGN_ROLE_FROM_USER: "Action"
    OKTA_UNENROLL_USER_S_SPECIFIC_FACTOR: "Action"
    OKTA_UNLINK_USER_FROM_ID_P: "Action"
    OKTA_UNLOCK_USER: "Action"
    OKTA_UNSUBSCRIBE_A_CUSTOM_ROLE_FROM_A_SPECIFIC_NOTIFICATION_TYPE: "Action"
    OKTA_UNSUBSCRIBE_FROM_A_SPECIFIC_NOTIFICATION_TYPE: "Action"
    OKTA_UNSUSPEND_USER: "Action"
    OKTA_UPDATES_A_FEATURE_OBJECT_FOR_AN_APPLICATION: "Action"
    OKTA_UPDATES_POLICY_DETAILS_AND_CONFIGURATIONS: "Action"
    OKTA_UPDATES_THE_BACKGROUND_IMAGE_FOR_YOUR_THEME: "Action"
    OKTA_UPDATES_THE_FAVICON_FOR_YOUR_THEME: "Action"
    OKTA_UPDATE_APPLICATION: "Action"
    OKTA_UPDATE_APPLICATION_POLICY: "Action"
    OKTA_UPDATE_APPLICATION_PROFILE_FOR_ASSIGNED_USER: "Action"
    OKTA_UPDATE_AUTHENTICATOR: "Action"
    OKTA_UPDATE_AUTHORIZATION_SERVER_CLAIM_SETTINGS: "Action"
    OKTA_UPDATE_AUTHORIZATION_SERVER_DETAILS: "Action"
    OKTA_UPDATE_AUTHORIZATION_SERVER_POLICY: "Action"
    OKTA_UPDATE_AUTHORIZATION_SERVER_SCOPE_DETAILS: "Action"
    OKTA_UPDATE_A_THEMES_LOGO: "Action"
    OKTA_UPDATE_A_THEME_FOR_A_BRAND: "Action"
    OKTA_UPDATE_BRAND: "Action"
    OKTA_UPDATE_CUSTOM_AUTH_SERVER_POLICY_RULE_CONFIG: "Action"
    OKTA_UPDATE_EMAIL_CUSTOMIZATION: "Action"
    OKTA_UPDATE_EVENT_HOOK_CONFIGURATION: "Action"
    OKTA_UPDATE_EXISTING_USER_TYPE: "Action"
    OKTA_UPDATE_GROUP: "Action"
    OKTA_UPDATE_GROUP_PROFILE_PROPERTIES: "Action"
    OKTA_UPDATE_IDENTITY_PROVIDER: "Action"
    OKTA_UPDATE_INACTIVE_GROUP_RULE: "Action"
    OKTA_UPDATE_INLINE_HOOK_DETAILS_BY_ID: "Action"
    OKTA_UPDATE_NETWORK_ZONE: "Action"
    OKTA_UPDATE_ORG_CONTACT_USER: "Action"
    OKTA_UPDATE_ORG_LOGO: "Action"
    OKTA_UPDATE_ORG_SETTING: "Action"
    OKTA_UPDATE_OR_DELETE_POLICY_RULE: "Action"
    OKTA_UPDATE_PARTIAL_USER_PROFILE_AND_CREDENTIALS: "Action"
    OKTA_UPDATE_PROFILE_MAPPING: "Action"
    OKTA_UPDATE_ROLE_IN_TARGET_GROUP: "Action"
    OKTA_UPDATE_SMS_TEMPLATE: "Action"
    OKTA_UPDATE_THREAT_INSIGHT_CONFIGURATION: "Action"
    OKTA_UPDATE_TRUSTED_ORIGIN_DETAILS: "Action"
    OKTA_UPDATE_USER: "Action"
    OKTA_UPDATE_USER_LINKED_OBJECT_BY_RELATIONSHIP: "Action"
    OKTA_UPDATE_USER_ROLES_FOR_CATALOG_APPS: "Action"
    OKTA_UPDATE_USER_ROLE_CATALOG_APPS_FOR_GROUP: "Action"
    OKTA_UPDATE_USER_ROLE_FOR_APP_CATALOG: "Action"
    OKTA_VERIFY_DOMAIN: "Action"
    OKTA_VERIFY_EVENT_HOOK_LIFECYCLE_SUCCESS: "Action"
    OKTA_VERIFY_MFA_FACTOR: "Action"
    PAGERDUTY_ADD_AN_ESCALATION_POLICY_TO_A_TEAM: "Action"
    PAGERDUTY_ADD_A_USER_TO_A_TEAM: "Action"
    PAGERDUTY_ADD_NOTIFICATION_SUBSCRIBERS: "Action"
    PAGERDUTY_ASSIGN_TAGS: "Action"
    PAGERDUTY_ASSOCIATE_AN_AUTOMATION_ACTION_WITH_A_SERVICE: "Action"
    PAGERDUTY_ASSOCIATE_AN_AUTOMATION_ACTION_WITH_A_TEAM: "Action"
    PAGERDUTY_ASSOCIATE_A_RUNNER_WITH_A_TEAM: "Action"
    PAGERDUTY_ASSOCIATE_A_TRIGGER_AND_SERVICE: "Action"
    PAGERDUTY_ASSOCIATE_SERVICE_DEPENDENCIES: "Action"
    PAGERDUTY_CONVERT_A_SERVICE_S_EVENT_RULES_INTO_EVENT_ORCHESTRATION_RULES: "Action"
    PAGERDUTY_CREATE_AN_ALERT_GROUPING_SETTING: "Action"
    PAGERDUTY_CREATE_AN_AUTOMATION_ACTION_RUNNER: "Action"
    PAGERDUTY_CREATE_AN_ESCALATION_POLICY: "Action"
    PAGERDUTY_CREATE_AN_EVENT_RULE: "Action"
    PAGERDUTY_CREATE_AN_EVENT_RULE_ON_A_SERVICE: "Action"
    PAGERDUTY_CREATE_AN_EXTENSION: "Action"
    PAGERDUTY_CREATE_AN_INCIDENT: "Action"
    PAGERDUTY_CREATE_AN_INCIDENT_WORKFLOW: "Action"
    PAGERDUTY_CREATE_AN_INTEGRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_CREATE_AN_INVOCATION: "Action"
    PAGERDUTY_CREATE_AN_ORCHESTRATION: "Action"
    PAGERDUTY_CREATE_A_BUSINESS_SERVICE: "Action"
    PAGERDUTY_CREATE_A_CACHE_VARIABLE_FOR_A_GLOBAL_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_CREATE_A_CACHE_VARIABLE_FOR_A_SERVICE_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_CREATE_A_CHANGE_EVENT: "Action"
    PAGERDUTY_CREATE_A_FIELD: "Action"
    PAGERDUTY_CREATE_A_FIELD_OPTION: "Action"
    PAGERDUTY_CREATE_A_MAINTENANCE_WINDOW: "Action"
    PAGERDUTY_CREATE_A_NEW_INTEGRATION: "Action"
    PAGERDUTY_CREATE_A_NOTE_ON_AN_INCIDENT: "Action"
    PAGERDUTY_CREATE_A_POST_POSTMORTEM: "Action"
    PAGERDUTY_CREATE_A_RESPONDER_REQUEST_FOR_AN_INCIDENT: "Action"
    PAGERDUTY_CREATE_A_RESPONSE_PLAY: "Action"
    PAGERDUTY_CREATE_A_RULESET: "Action"
    PAGERDUTY_CREATE_A_SCHEDULE: "Action"
    PAGERDUTY_CREATE_A_SERVICE: "Action"
    PAGERDUTY_CREATE_A_STATUS_PAGE_POST: "Action"
    PAGERDUTY_CREATE_A_STATUS_PAGE_POST_UPDATE: "Action"
    PAGERDUTY_CREATE_A_STATUS_PAGE_SUBSCRIPTION: "Action"
    PAGERDUTY_CREATE_A_STATUS_UPDATE_ON_AN_INCIDENT: "Action"
    PAGERDUTY_CREATE_A_TAG: "Action"
    PAGERDUTY_CREATE_A_TEAM: "Action"
    PAGERDUTY_CREATE_A_TEMPLATE: "Action"
    PAGERDUTY_CREATE_A_TRIGGER: "Action"
    PAGERDUTY_CREATE_A_USER: "Action"
    PAGERDUTY_CREATE_A_USER_HANDOFF_NOTIFICATION_RULE: "Action"
    PAGERDUTY_CREATE_A_USER_NOTIFICATION_RULE: "Action"
    PAGERDUTY_CREATE_A_USER_STATUS_UPDATE_NOTIFICATION_RULE: "Action"
    PAGERDUTY_CREATE_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_CREATE_BUSINESS_SERVICE_ACCOUNT_SUBSCRIPTION: "Action"
    PAGERDUTY_CREATE_BUSINESS_SERVICE_SUBSCRIBERS: "Action"
    PAGERDUTY_CREATE_NOTIFICATION_SUBCRIPTIONS: "Action"
    PAGERDUTY_CREATE_ONE_OR_MORE_OVERRIDES: "Action"
    PAGERDUTY_CREATE_TEAM_NOTIFICATION_SUBSCRIPTIONS: "Action"
    PAGERDUTY_DELETE_ACCOUNT_LEVEL_PRIORITY_THRESHOLD: "Action"
    PAGERDUTY_DELETE_ALL_USER_SESSIONS: "Action"
    PAGERDUTY_DELETE_AN_ADD_ON: "Action"
    PAGERDUTY_DELETE_AN_ALERT_GROUPING_SETTING: "Action"
    PAGERDUTY_DELETE_AN_AUTOMATION_ACTION: "Action"
    PAGERDUTY_DELETE_AN_AUTOMATION_ACTION_RUNNER: "Action"
    PAGERDUTY_DELETE_AN_ESCALATION_POLICY: "Action"
    PAGERDUTY_DELETE_AN_EVENT_RULE: "Action"
    PAGERDUTY_DELETE_AN_EVENT_RULE_FROM_A_SERVICE: "Action"
    PAGERDUTY_DELETE_AN_EXTENSION: "Action"
    PAGERDUTY_DELETE_AN_INCIDENT_WORKFLOW: "Action"
    PAGERDUTY_DELETE_AN_INTEGRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_DELETE_AN_ORCHESTRATION: "Action"
    PAGERDUTY_DELETE_AN_OVERRIDE: "Action"
    PAGERDUTY_DELETE_A_BUSINESS_SERVICE: "Action"
    PAGERDUTY_DELETE_A_CACHE_VARIABLE_FOR_A_GLOBAL_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_DELETE_A_CACHE_VARIABLE_FOR_A_SERVICE_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_DELETE_A_FIELD: "Action"
    PAGERDUTY_DELETE_A_FIELD_OPTION: "Action"
    PAGERDUTY_DELETE_A_POST_POSTMORTEM: "Action"
    PAGERDUTY_DELETE_A_RESPONSE_PLAY: "Action"
    PAGERDUTY_DELETE_A_RULESET: "Action"
    PAGERDUTY_DELETE_A_SCHEDULE: "Action"
    PAGERDUTY_DELETE_A_SERVICE: "Action"
    PAGERDUTY_DELETE_A_STATUS_PAGE_POST: "Action"
    PAGERDUTY_DELETE_A_STATUS_PAGE_POST_UPDATE: "Action"
    PAGERDUTY_DELETE_A_STATUS_PAGE_SUBSCRIPTION: "Action"
    PAGERDUTY_DELETE_A_TAG: "Action"
    PAGERDUTY_DELETE_A_TEAM: "Action"
    PAGERDUTY_DELETE_A_TEMPLATE: "Action"
    PAGERDUTY_DELETE_A_TRIGGER: "Action"
    PAGERDUTY_DELETE_A_USER: "Action"
    PAGERDUTY_DELETE_A_USER_S_CONTACT_METHOD: "Action"
    PAGERDUTY_DELETE_A_USER_S_HANDOFF_NOTIFICATION_RULE: "Action"
    PAGERDUTY_DELETE_A_USER_S_NOTIFICATION_RULE: "Action"
    PAGERDUTY_DELETE_A_USER_S_SESSION: "Action"
    PAGERDUTY_DELETE_A_USER_S_STATUS_UPDATE_NOTIFICATION_RULE: "Action"
    PAGERDUTY_DELETE_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_DELETE_BUSINESS_SERVICE_ACCOUNT_SUBSCRIPTION: "Action"
    PAGERDUTY_DELETE_OR_END_A_MAINTENANCE_WINDOW: "Action"
    PAGERDUTY_DISASSOCIATE_AN_AUTOMATION_ACTION_FROM_A_SERVICE: "Action"
    PAGERDUTY_DISASSOCIATE_AN_AUTOMATION_ACTION_FROM_A_TEAM: "Action"
    PAGERDUTY_DISASSOCIATE_A_RUNNER_FROM_A_TEAM: "Action"
    PAGERDUTY_DISASSOCIATE_SERVICE_DEPENDENCIES: "Action"
    PAGERDUTY_DISSOCIATE_A_TRIGGER_AND_SERVICE: "Action"
    PAGERDUTY_ENABLE_AN_EXTENSION: "Action"
    PAGERDUTY_ENABLE_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_GET_AGGREGATED_ESCALATION_POLICY_DATA: "Action"
    PAGERDUTY_GET_AGGREGATED_INCIDENT_DATA: "Action"
    PAGERDUTY_GET_AGGREGATED_METRICS_FOR_ALL_ESCALATION_POLICIES: "Action"
    PAGERDUTY_GET_AGGREGATED_METRICS_FOR_ALL_RESPONDERS: "Action"
    PAGERDUTY_GET_AGGREGATED_METRICS_FOR_ALL_SERVICES: "Action"
    PAGERDUTY_GET_AGGREGATED_METRICS_FOR_ALL_TEAMS: "Action"
    PAGERDUTY_GET_AGGREGATED_SERVICE_DATA: "Action"
    PAGERDUTY_GET_AGGREGATED_TEAM_DATA: "Action"
    PAGERDUTY_GET_ALL_SERVICE_REFERENCES_ASSOCIATED_WITH_AN_AUTOMATION_ACTION: "Action"
    PAGERDUTY_GET_ALL_TEAM_REFERENCES_ASSOCIATED_WITH_AN_AUTOMATION_ACTION: "Action"
    PAGERDUTY_GET_ALL_TEAM_REFERENCES_ASSOCIATED_WITH_A_RUNNER: "Action"
    PAGERDUTY_GET_AN_ACTION: "Action"
    PAGERDUTY_GET_AN_ADD_ON: "Action"
    PAGERDUTY_GET_AN_ALERT: "Action"
    PAGERDUTY_GET_AN_ALERT_GROUPING_SETTING: "Action"
    PAGERDUTY_GET_AN_AUTOMATION_ACTION: "Action"
    PAGERDUTY_GET_AN_AUTOMATION_ACTION_RUNNER: "Action"
    PAGERDUTY_GET_AN_ESCALATION_POLICY: "Action"
    PAGERDUTY_GET_AN_EVENT_RULE: "Action"
    PAGERDUTY_GET_AN_EVENT_RULE_FROM_A_SERVICE: "Action"
    PAGERDUTY_GET_AN_EXTENSION: "Action"
    PAGERDUTY_GET_AN_EXTENSION_VENDOR: "Action"
    PAGERDUTY_GET_AN_INCIDENT: "Action"
    PAGERDUTY_GET_AN_INCIDENT_WORKFLOW: "Action"
    PAGERDUTY_GET_AN_INTEGRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GET_AN_INVOCATION: "Action"
    PAGERDUTY_GET_AN_ORCHESTRATION: "Action"
    PAGERDUTY_GET_A_BUSINESS_SERVICE: "Action"
    PAGERDUTY_GET_A_CACHE_VARIABLE_FOR_A_GLOBAL_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GET_A_CACHE_VARIABLE_FOR_A_SERVICE_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GET_A_CHANGE_EVENT: "Action"
    PAGERDUTY_GET_A_FIELD: "Action"
    PAGERDUTY_GET_A_LOG_ENTRY: "Action"
    PAGERDUTY_GET_A_MAINTENANCE_WINDOW: "Action"
    PAGERDUTY_GET_A_POST_POSTMORTEM: "Action"
    PAGERDUTY_GET_A_RESPONSE_PLAY: "Action"
    PAGERDUTY_GET_A_RULESET: "Action"
    PAGERDUTY_GET_A_SCHEDULE: "Action"
    PAGERDUTY_GET_A_SERVICE: "Action"
    PAGERDUTY_GET_A_SINGLE_STATUS_DASHBOARD_BY_ID: "Action"
    PAGERDUTY_GET_A_SINGLE_STATUS_DASHBOARD_BY_URL_SLUG: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_IMPACT: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_POST: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_POST_UPDATE: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_SERVICE: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_SEVERITY: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_STATUS: "Action"
    PAGERDUTY_GET_A_STATUS_PAGE_SUBSCRIPTION: "Action"
    PAGERDUTY_GET_A_TAG: "Action"
    PAGERDUTY_GET_A_TEAM: "Action"
    PAGERDUTY_GET_A_TEMPLATE: "Action"
    PAGERDUTY_GET_A_TRIGGER: "Action"
    PAGERDUTY_GET_A_USER: "Action"
    PAGERDUTY_GET_A_USER_S_CONTACT_METHOD: "Action"
    PAGERDUTY_GET_A_USER_S_HANDOFF_NOTIFICATION_RULE: "Action"
    PAGERDUTY_GET_A_USER_S_NOTIFICATION_RULE: "Action"
    PAGERDUTY_GET_A_USER_S_SESSION: "Action"
    PAGERDUTY_GET_A_USER_S_STATUS_UPDATE_NOTIFICATION_RULE: "Action"
    PAGERDUTY_GET_A_VENDOR: "Action"
    PAGERDUTY_GET_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_GET_BUSINESS_SERVICE_DEPENDENCIES: "Action"
    PAGERDUTY_GET_CONNECTED_ENTITIES: "Action"
    PAGERDUTY_GET_CUSTOM_FIELD_VALUES: "Action"
    PAGERDUTY_GET_IMPACTED_BUSINESS_SERVICES_FOR_A_STATUS_DASHBOARD_BY_ID: "Action"
    PAGERDUTY_GET_IMPACTED_SERVICES_BY_SLUG: "Action"
    PAGERDUTY_GET_OUTLIER_INCIDENT: "Action"
    PAGERDUTY_GET_PAST_INCIDENTS: "Action"
    PAGERDUTY_GET_PAUSED_INCIDENT_REPORTING_COUNTS: "Action"
    PAGERDUTY_GET_PAUSED_INCIDENT_REPORTING_ON_ALERTS: "Action"
    PAGERDUTY_GET_RAW_DATA_MULTIPLE_INCIDENTS: "Action"
    PAGERDUTY_GET_RAW_DATA_SINGLE_INCIDENT: "Action"
    PAGERDUTY_GET_RAW_INCIDENTS_FOR_A_SINGLE_RESPONDER_ID: "Action"
    PAGERDUTY_GET_RAW_RESPONSES_FROM_A_SINGLE_INCIDENT: "Action"
    PAGERDUTY_GET_RELATED_INCIDENTS: "Action"
    PAGERDUTY_GET_RESPONDER_DATA_AGGREGATED_BY_TEAM: "Action"
    PAGERDUTY_GET_TAGS_FOR_ENTITIES: "Action"
    PAGERDUTY_GET_TECHNICAL_SERVICE_DEPENDENCIES: "Action"
    PAGERDUTY_GET_THE_CURRENT_USER: "Action"
    PAGERDUTY_GET_THE_DETAILS_OF_AN_AUTOMATION_ACTION_SERVICE_RELATION: "Action"
    PAGERDUTY_GET_THE_DETAILS_OF_AN_AUTOMATION_ACTION_TEAM_RELATION: "Action"
    PAGERDUTY_GET_THE_DETAILS_OF_A_RUNNER_TEAM_RELATION: "Action"
    PAGERDUTY_GET_THE_GLOBAL_ORCHESTRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GET_THE_LICENSE_ALLOCATED_TO_A_USER: "Action"
    PAGERDUTY_GET_THE_ROUTER_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GET_THE_SERVICE_ORCHESTRATION_ACTIVE_STATUS_FOR_A_SERVICE: "Action"
    PAGERDUTY_GET_THE_SERVICE_ORCHESTRATION_FOR_A_SERVICE: "Action"
    PAGERDUTY_GET_THE_UNROUTED_ORCHESTRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_GLOBAL_PRIORITY_THRESHOLD_FOR_IMPACTED_BUSINESS_SERVICE: "Action"
    PAGERDUTY_INSTALL_AN_ADD_ON: "Action"
    PAGERDUTY_LIST_ABILITIES: "Action"
    PAGERDUTY_LIST_ACTIONS: "Action"
    PAGERDUTY_LIST_ALERTS_FOR_AN_INCIDENT: "Action"
    PAGERDUTY_LIST_ALERT_GROUPING_SETTINGS: "Action"
    PAGERDUTY_LIST_ALL_OF_THE_ON_CALLS: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS_FOR_AN_ESCALATION_POLICY: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS_FOR_A_SCHEDULE: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS_FOR_A_SERVICE: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS_FOR_A_TEAM: "Action"
    PAGERDUTY_LIST_AUDIT_RECORDS_FOR_A_USER: "Action"
    PAGERDUTY_LIST_AUTOMATION_ACTIONS: "Action"
    PAGERDUTY_LIST_AUTOMATION_ACTION_RUNNERS: "Action"
    PAGERDUTY_LIST_A_RESOURCE_S_STANDARDS_SCORES: "Action"
    PAGERDUTY_LIST_A_USER_S_ACTIVE_SESSIONS: "Action"
    PAGERDUTY_LIST_A_USER_S_CONTACT_METHODS: "Action"
    PAGERDUTY_LIST_A_USER_S_HANDOFF_NOTIFICATION_RULES: "Action"
    PAGERDUTY_LIST_A_USER_S_NOTIFICATION_RULES: "Action"
    PAGERDUTY_LIST_A_USER_S_STATUS_UPDATE_NOTIFICATION_RULES: "Action"
    PAGERDUTY_LIST_BUSINESS_SERVICES: "Action"
    PAGERDUTY_LIST_BUSINESS_SERVICES_IMPACTED_BY_THE_GIVEN_INCIDENT: "Action"
    PAGERDUTY_LIST_BUSINESS_SERVICES_SORTED_BY_IMPACTED_STATUS: "Action"
    PAGERDUTY_LIST_BUSINESS_SERVICE_SUBSCRIBERS: "Action"
    PAGERDUTY_LIST_CACHE_VARIABLES_FOR_A_GLOBAL_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_LIST_CACHE_VARIABLES_FOR_A_SERVICE_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_LIST_CHANGE_EVENTS: "Action"
    PAGERDUTY_LIST_CHANGE_EVENTS_FOR_A_SERVICE: "Action"
    PAGERDUTY_LIST_ESCALATION_POLICIES: "Action"
    PAGERDUTY_LIST_EVENT_ORCHESTRATIONS: "Action"
    PAGERDUTY_LIST_EVENT_RULES: "Action"
    PAGERDUTY_LIST_EXTENSIONS: "Action"
    PAGERDUTY_LIST_EXTENSION_SCHEMAS: "Action"
    PAGERDUTY_LIST_FIELDS: "Action"
    PAGERDUTY_LIST_FIELD_OPTIONS: "Action"
    PAGERDUTY_LIST_IMPACTORS_AFFECTING_BUSINESS_SERVICES: "Action"
    PAGERDUTY_LIST_INCIDENTS: "Action"
    PAGERDUTY_LIST_INCIDENT_WORKFLOWS: "Action"
    PAGERDUTY_LIST_INSTALLED_ADD_ONS: "Action"
    PAGERDUTY_LIST_INTEGRATIONS_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_LIST_INVOCATIONS: "Action"
    PAGERDUTY_LIST_LICENSES: "Action"
    PAGERDUTY_LIST_LICENSE_ALLOCATIONS: "Action"
    PAGERDUTY_LIST_LOG_ENTRIES: "Action"
    PAGERDUTY_LIST_LOG_ENTRIES_FOR_AN_INCIDENT: "Action"
    PAGERDUTY_LIST_MAINTENANCE_WINDOWS: "Action"
    PAGERDUTY_LIST_MEMBERS_OF_A_TEAM: "Action"
    PAGERDUTY_LIST_NOTES_FOR_AN_INCIDENT: "Action"
    PAGERDUTY_LIST_NOTIFICATIONS: "Action"
    PAGERDUTY_LIST_NOTIFICATION_SUBSCRIBERS: "Action"
    PAGERDUTY_LIST_NOTIFICATION_SUBSCRIPTIONS: "Action"
    PAGERDUTY_LIST_OVERRIDES: "Action"
    PAGERDUTY_LIST_PRIORITIES: "Action"
    PAGERDUTY_LIST_RELATED_CHANGE_EVENTS_FOR_AN_INCIDENT: "Action"
    PAGERDUTY_LIST_RESOURCES_STANDARDS_SCORES: "Action"
    PAGERDUTY_LIST_RESPONSE_PLAYS: "Action"
    PAGERDUTY_LIST_RULESETS: "Action"
    PAGERDUTY_LIST_SCHEDULES: "Action"
    PAGERDUTY_LIST_SERVICES: "Action"
    PAGERDUTY_LIST_SERVICE_S_EVENT_RULES: "Action"
    PAGERDUTY_LIST_STANDARDS: "Action"
    PAGERDUTY_LIST_STATUS_DASHBOARDS: "Action"
    PAGERDUTY_LIST_STATUS_PAGES: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_IMPACTS: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_POSTS: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_POST_UPDATES: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_SERVICES: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_SEVERITIES: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_STATUSES: "Action"
    PAGERDUTY_LIST_STATUS_PAGE_SUBSCRIPTIONS: "Action"
    PAGERDUTY_LIST_SUPPORTING_SERVICES_BY_IMPACT_STATUS: "Action"
    PAGERDUTY_LIST_TAGS: "Action"
    PAGERDUTY_LIST_TEAMS: "Action"
    PAGERDUTY_LIST_TEAM_NOTIFICATION_SUBSCRIPTIONS: "Action"
    PAGERDUTY_LIST_TEMPLATES: "Action"
    PAGERDUTY_LIST_TEMPLATE_FIELDS: "Action"
    PAGERDUTY_LIST_TRIGGERS: "Action"
    PAGERDUTY_LIST_USERS: "Action"
    PAGERDUTY_LIST_USERS_ON_CALL: "Action"
    PAGERDUTY_LIST_VENDORS: "Action"
    PAGERDUTY_LIST_WEBHOOK_SUBSCRIPTIONS: "Action"
    PAGERDUTY_MANAGE_ALERTS: "Action"
    PAGERDUTY_MANAGE_INCIDENTS: "Action"
    PAGERDUTY_MANUALLY_CHANGE_AN_INCIDENT_S_IMPACT_ON_A_BUSINESS_SERVICE: "Action"
    PAGERDUTY_MERGE_INCIDENTS: "Action"
    PAGERDUTY_MIGRATE_AN_INTEGRATION_FROM_ONE_EVENT_ORCHESTRATION_TO_ANOTHER: "Action"
    PAGERDUTY_PREVIEW_A_SCHEDULE: "Action"
    PAGERDUTY_REMOVE_AN_ESCALATION_POLICY_FROM_A_TEAM: "Action"
    PAGERDUTY_REMOVE_A_USER_FROM_A_TEAM: "Action"
    PAGERDUTY_REMOVE_BUSINESS_SERVICE_SUBSCRIBERS: "Action"
    PAGERDUTY_REMOVE_NOTIFICATION_SUBSCRIBER: "Action"
    PAGERDUTY_REMOVE_NOTIFICATION_SUBSCRIPTIONS: "Action"
    PAGERDUTY_RENDER_A_TEMPLATE: "Action"
    PAGERDUTY_RUN_A_RESPONSE_PLAY: "Action"
    PAGERDUTY_SET_ACCOUNT_PRIORITY_THRESHOLD: "Action"
    PAGERDUTY_SNOOZE_AN_INCIDENT: "Action"
    PAGERDUTY_START_AN_INCIDENT_WORKFLOW_INSTANCE: "Action"
    PAGERDUTY_TEST_AN_ABILITY: "Action"
    PAGERDUTY_TEST_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_UNSUBSCRIBE_TEAM_FROM_NOTIFICATION_SUBSCRIPTIONS: "Action"
    PAGERDUTY_UPDATE_AN_ADD_ON: "Action"
    PAGERDUTY_UPDATE_AN_ALERT: "Action"
    PAGERDUTY_UPDATE_AN_ALERT_GROUPING_SETTING: "Action"
    PAGERDUTY_UPDATE_AN_AUTOMATION_ACTION_RUNNER: "Action"
    PAGERDUTY_UPDATE_AN_ESCALATION_POLICY: "Action"
    PAGERDUTY_UPDATE_AN_EVENT_RULE: "Action"
    PAGERDUTY_UPDATE_AN_EVENT_RULE_ON_A_SERVICE: "Action"
    PAGERDUTY_UPDATE_AN_EXISTING_INTEGRATION: "Action"
    PAGERDUTY_UPDATE_AN_EXTENSION: "Action"
    PAGERDUTY_UPDATE_AN_INCIDENT: "Action"
    PAGERDUTY_UPDATE_AN_INCIDENT_WORKFLOW: "Action"
    PAGERDUTY_UPDATE_AN_INTEGRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_AN_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_A_BUSINESS_SERVICE: "Action"
    PAGERDUTY_UPDATE_A_CACHE_VARIABLE_FOR_A_GLOBAL_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_A_CACHE_VARIABLE_FOR_A_SERVICE_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_A_CHANGE_EVENT: "Action"
    PAGERDUTY_UPDATE_A_FIELD: "Action"
    PAGERDUTY_UPDATE_A_FIELD_OPTION: "Action"
    PAGERDUTY_UPDATE_A_MAINTENANCE_WINDOW: "Action"
    PAGERDUTY_UPDATE_A_POST_POSTMORTEM: "Action"
    PAGERDUTY_UPDATE_A_RESPONSE_PLAY: "Action"
    PAGERDUTY_UPDATE_A_RULESET: "Action"
    PAGERDUTY_UPDATE_A_SCHEDULE: "Action"
    PAGERDUTY_UPDATE_A_SERVICE: "Action"
    PAGERDUTY_UPDATE_A_STANDARD: "Action"
    PAGERDUTY_UPDATE_A_STATUS_PAGE_POST: "Action"
    PAGERDUTY_UPDATE_A_STATUS_PAGE_POST_UPDATE: "Action"
    PAGERDUTY_UPDATE_A_TEAM: "Action"
    PAGERDUTY_UPDATE_A_TEMPLATE: "Action"
    PAGERDUTY_UPDATE_A_TRIGGER: "Action"
    PAGERDUTY_UPDATE_A_USER: "Action"
    PAGERDUTY_UPDATE_A_USER_S_HANDOFF_NOTIFICATION_RULE: "Action"
    PAGERDUTY_UPDATE_A_USER_S_NOTIFICATION_RULE: "Action"
    PAGERDUTY_UPDATE_A_USER_S_STATUS_UPDATE_NOTIFICATION_RULE: "Action"
    PAGERDUTY_UPDATE_A_WEBHOOK_SUBSCRIPTION: "Action"
    PAGERDUTY_UPDATE_CUSTOM_FIELD_VALUES: "Action"
    PAGERDUTY_UPDATE_LOG_ENTRY_CHANNEL_INFORMATION: "Action"
    PAGERDUTY_UPDATE_THE_GLOBAL_ORCHESTRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_THE_ROUTER_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_UPDATE_THE_SERVICE_ORCHESTRATION_ACTIVE_STATUS_FOR_A_SERVICE: "Action"
    PAGERDUTY_UPDATE_THE_SERVICE_ORCHESTRATION_FOR_A_SERVICE: "Action"
    PAGERDUTY_UPDATE_THE_UNROUTED_ORCHESTRATION_FOR_AN_EVENT_ORCHESTRATION: "Action"
    PAGERDUTY_VIEW_AN_INTEGRATION: "Action"
    PERPLEXITYAI_PERPLEXITY_AI_SEARCH: "Action"
    RAGTOOL_ADD_CONTENT_TO_RAG_TOOL: "Action"
    RAGTOOL_RAG_TOOL_QUERY: "Action"
    SCHEDULER_SCHEDULE_JOB_ACTION: "Action"
    SEARCHTOOL_FIND_FILE_CMD: "Action"
    SEARCHTOOL_SEARCH_DIR_CMD: "Action"
    SEARCHTOOL_SEARCH_FILE_CMD: "Action"
    SERPAPI_DUCK_DUCK_GO_SEARCH: "Action"
    SERPAPI_EVENT_SEARCH: "Action"
    SERPAPI_FINANCE_SEARCH: "Action"
    SERPAPI_IMAGE_SEARCH: "Action"
    SERPAPI_NEWS_SEARCH: "Action"
    SERPAPI_SCHOLAR_SEARCH: "Action"
    SERPAPI_SEARCH: "Action"
    SERPAPI_SHOPPING_SEARCH: "Action"
    SERPAPI_TRENDS_SEARCH: "Action"
    SHELL_CREATE_SHELL: "Action"
    SHELL_EXEC_COMMAND: "Action"
    SHELL_SPAWN_PROCESS: "Action"
    SLACKBOT_ACTIVATE_OR_MODIFY_DO_NOT_DISTURB_DURATION: "Action"
    SLACKBOT_ADD_AN_EMOJI_ALIAS_IN_SLACK: "Action"
    SLACKBOT_ADD_A_CUSTOM_EMOJI_TO_A_SLACK_TEAM: "Action"
    SLACKBOT_ADD_A_REMOTE_FILE_FROM_A_SERVICE: "Action"
    SLACKBOT_ADD_A_STAR_TO_AN_ITEM: "Action"
    SLACKBOT_ADD_DEFAULT_CHANNELS_TO_IDP_GROUP: "Action"
    SLACKBOT_ADD_ENTERPRISE_USER_TO_WORKSPACE: "Action"
    SLACKBOT_ADD_IDP_GROUP_ALLOWLIST_TO_CHANNEL: "Action"
    SLACKBOT_ADD_REACTION_TO_AN_ITEM: "Action"
    SLACKBOT_APPROVE_AN_APP_INSTALLATION_IN_A_WORKSPACE: "Action"
    SLACKBOT_APPROVE_WORKSPACE_INVITE_REQUEST: "Action"
    SLACKBOT_ARCHIVE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACKBOT_ARCHIVE_A_SLACK_CONVERSATION: "Action"
    SLACKBOT_ASSOCIATE_DEFAULT_WORKSPACES_WITH_IDP_GROUP: "Action"
    SLACKBOT_CHECKS_API_CALL_AND_RETURNS_SUCCESS_OR_ERROR: "Action"
    SLACKBOT_CHECKS_AUTHENTICATION_AND_IDENTITY: "Action"
    SLACKBOT_CLOSE_DM_OR_MULTI_PERSON_DM: "Action"
    SLACKBOT_CONVERSATIONS_HISTORY: "Action"
    SLACKBOT_CONVERT_PUBLIC_CHANNEL_TO_PRIVATE: "Action"
    SLACKBOT_CREATE_AN_ENTERPRISE_TEAM: "Action"
    SLACKBOT_CREATE_A_REMINDER: "Action"
    SLACKBOT_CREATE_A_SLACK_USER_GROUP: "Action"
    SLACKBOT_CREATE_CHANNEL_BASED_CONVERSATION: "Action"
    SLACKBOT_CUSTOMIZE_URL_UNFURLING_IN_MESSAGES: "Action"
    SLACKBOT_DELETES_A_MESSAGE_FROM_A_CHAT: "Action"
    SLACKBOT_DELETE_A_COMMENT_ON_A_FILE: "Action"
    SLACKBOT_DELETE_A_FILE_BY_ID: "Action"
    SLACKBOT_DELETE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACKBOT_DELETE_A_SCHEDULED_MESSAGE_IN_A_CHAT: "Action"
    SLACKBOT_DELETE_A_SLACK_REMINDER: "Action"
    SLACKBOT_DELETE_USER_PROFILE_PHOTO: "Action"
    SLACKBOT_DENY_WORKSPACE_INVITE_REQUEST: "Action"
    SLACKBOT_DISABLE_AN_EXISTING_SLACK_USER_GROUP: "Action"
    SLACKBOT_DISCONNECT_CHANNEL_FROM_WORKSPACES: "Action"
    SLACKBOT_ENABLE_A_SPECIFIED_USER_GROUP: "Action"
    SLACKBOT_ENABLE_PUBLIC_SHARING_OF_A_FILE: "Action"
    SLACKBOT_END_A_CALL_WITH_DURATION_AND_ID: "Action"
    SLACKBOT_END_USER_DO_NOT_DISTURB_SESSION: "Action"
    SLACKBOT_END_USER_SNOOZE_MODE_IMMEDIATELY: "Action"
    SLACKBOT_EXCHANGE_OAUTH_CODE_FOR_ACCESS_TOKEN: "Action"
    SLACKBOT_EXCHANGE_OAUTH_CODE_FOR_WORKSPACE_TOKEN: "Action"
    SLACKBOT_EXCHANGE_OAUTH_VERIFIER_FOR_ACCESS_TOKEN: "Action"
    SLACKBOT_FETCH_BOT_USER_INFORMATION: "Action"
    SLACKBOT_FETCH_CONVERSATION_HISTORY: "Action"
    SLACKBOT_FETCH_CURRENT_TEAM_INFO_WITH_OPTIONAL_TEAM_SCOPE: "Action"
    SLACKBOT_FETCH_DND_STATUS_FOR_MULTIPLE_TEAM_MEMBERS: "Action"
    SLACKBOT_FETCH_ITEM_REACTIONS: "Action"
    SLACKBOT_FETCH_MESSAGE_THREAD_FROM_A_CONVERSATION: "Action"
    SLACKBOT_FETCH_WORKSPACE_SETTINGS_INFORMATION: "Action"
    SLACKBOT_FIND_USER_BY_EMAIL_ADDRESS: "Action"
    SLACKBOT_GET_BILLABLE_TEAM_USER_INFO: "Action"
    SLACKBOT_GET_CHANNEL_CONVERSATION_PREFERENCES: "Action"
    SLACKBOT_GET_CHANNEL_S_CONNECTED_WORKSPACES_IN_ENTERPRISE: "Action"
    SLACKBOT_GET_CURRENT_TEAM_INTEGRATION_LOGS: "Action"
    SLACKBOT_GET_CURRENT_TEAM_S_ACCESS_LOGS: "Action"
    SLACKBOT_GET_REMINDER_INFORMATION: "Action"
    SLACKBOT_GET_USER_PRESENCE_INFO: "Action"
    SLACKBOT_INDICATE_WORKFLOW_STEP_FAILURE: "Action"
    SLACKBOT_INITIATES_CHANNEL_BASED_CONVERSATIONS: "Action"
    SLACKBOT_INVALIDATE_A_USER_SESSION_BY_ID: "Action"
    SLACKBOT_INVITE_USERS_TO_A_SLACK_CHANNEL: "Action"
    SLACKBOT_INVITE_USER_TO_CHANNEL: "Action"
    SLACKBOT_INVITE_USER_TO_WORKSPACE_WITH_OPTIONAL_CHANNEL_INVITES: "Action"
    SLACKBOT_JOIN_AN_EXISTING_CONVERSATION: "Action"
    SLACKBOT_LEAVE_A_CONVERSATION: "Action"
    SLACKBOT_LISTS_PINNED_ITEMS_IN_A_CHANNEL: "Action"
    SLACKBOT_LISTS_USER_S_STARRED_ITEMS_WITH_PAGINATION: "Action"
    SLACKBOT_LIST_ACCESSIBLE_CONVERSATIONS_FOR_A_USER: "Action"
    SLACKBOT_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS: "Action"
    SLACKBOT_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION: "Action"
    SLACKBOT_LIST_ALL_TEAMS_IN_AN_ENTERPRISE_ORGANIZATION: "Action"
    SLACKBOT_LIST_ALL_USERS_IN_A_USER_GROUP: "Action"
    SLACKBOT_LIST_APPROVED_APPS_FOR_ORG_OR_WORKSPACE: "Action"
    SLACKBOT_LIST_APPROVED_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACKBOT_LIST_APP_PERMISSIONS_ON_A_TEAM: "Action"
    SLACKBOT_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM: "Action"
    SLACKBOT_LIST_APP_RESOURCE_GRANTS_ON_A_TEAM: "Action"
    SLACKBOT_LIST_APP_USER_GRANTS_AND_SCOPES_ON_TEAM: "Action"
    SLACKBOT_LIST_DENIED_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACKBOT_LIST_DISCONNECTED_CHANNELS_WITH_ORIGINAL_IDS_FOR_EKM: "Action"
    SLACKBOT_LIST_ENTERPRISE_GRID_ORGANIZATION_EMOJIS: "Action"
    SLACKBOT_LIST_EVENT_AUTHORIZATIONS_FOR_APPS: "Action"
    SLACKBOT_LIST_FILES_WITH_FILTERS_IN_SLACK: "Action"
    SLACKBOT_LIST_IDP_GROUPS_LINKED_TO_A_CHANNEL: "Action"
    SLACKBOT_LIST_ORG_LEVEL_IDP_GROUP_CHANNELS: "Action"
    SLACKBOT_LIST_PENDING_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACKBOT_LIST_RESTRICTED_APPS_FOR_AN_ORG_OR_WORKSPACE: "Action"
    SLACKBOT_LIST_SCHEDULED_MESSAGES_IN_A_CHANNEL: "Action"
    SLACKBOT_LIST_SLACK_S_REMOTE_FILES_WITH_FILTERS: "Action"
    SLACKBOT_LIST_TEAM_CUSTOM_EMOJIS: "Action"
    SLACKBOT_LIST_TEAM_WORKSPACE_APP_REQUESTS: "Action"
    SLACKBOT_LIST_USER_GROUPS_FOR_TEAM_WITH_OPTIONS: "Action"
    SLACKBOT_LIST_USER_REACTIONS: "Action"
    SLACKBOT_LIST_USER_REMINDERS_WITH_DETAILS: "Action"
    SLACKBOT_LIST_WORKSPACE_ADMINS: "Action"
    SLACKBOT_LIST_WORKSPACE_OWNERS: "Action"
    SLACKBOT_LIST_WORKSPACE_USERS: "Action"
    SLACKBOT_MANUALLY_SET_USER_PRESENCE: "Action"
    SLACKBOT_MAP_USER_IDS_FOR_ENTERPRISE_GRID_WORKSPACES: "Action"
    SLACKBOT_MARK_A_USER_AS_ACTIVE_DEPRECATED: "Action"
    SLACKBOT_MARK_REMINDER_AS_COMPLETE: "Action"
    SLACKBOT_MARK_WORKFLOW_STEP_AS_COMPLETED: "Action"
    SLACKBOT_OPEN_A_VIEW_FOR_A_SLACK_USER: "Action"
    SLACKBOT_OPEN_OR_RESUME_DIRECT_OR_MULTI_PERSON_MESSAGES: "Action"
    SLACKBOT_OPEN_USER_DIALOG_WITH_JSON_DEFINED_UI: "Action"
    SLACKBOT_PINS_AN_ITEM_TO_A_CHANNEL: "Action"
    SLACKBOT_PROMOTE_USER_TO_ADMIN_STATUS: "Action"
    SLACKBOT_PROMOTE_USER_TO_WORKSPACE_OWNER: "Action"
    SLACKBOT_PUBLISH_STATIC_VIEW_FOR_USER: "Action"
    SLACKBOT_PUSH_VIEW_TO_ROOT_VIEW_STACK: "Action"
    SLACKBOT_REGISTERS_A_NEW_CALL_WITH_PARTICIPANTS: "Action"
    SLACKBOT_REGISTERS_NEW_CALL_PARTICIPANTS: "Action"
    SLACKBOT_REGISTER_CALL_PARTICIPANTS_REMOVAL: "Action"
    SLACKBOT_REMOVE_A_REMOTE_FILE: "Action"
    SLACKBOT_REMOVE_A_STAR_FROM_AN_ITEM: "Action"
    SLACKBOT_REMOVE_A_USER_FROM_A_CONVERSATION: "Action"
    SLACKBOT_REMOVE_CHANNELS_FROM_IDP_GROUP: "Action"
    SLACKBOT_REMOVE_ENTERPRISE_GRID_ORG_EMOJI: "Action"
    SLACKBOT_REMOVE_IDP_GROUP_FROM_PRIVATE_CHANNEL: "Action"
    SLACKBOT_REMOVE_REACTION_FROM_ITEM: "Action"
    SLACKBOT_REMOVE_USER_FROM_WORKSPACE: "Action"
    SLACKBOT_RENAME_AN_EMOJI: "Action"
    SLACKBOT_RENAME_A_CONVERSATION: "Action"
    SLACKBOT_RENAME_A_SLACK_CHANNEL: "Action"
    SLACKBOT_REQUEST_ADDITIONAL_APP_PERMISSIONS: "Action"
    SLACKBOT_RESTRICT_APP_INSTALLATION_ON_WORKSPACE: "Action"
    SLACKBOT_RETRIEVE_A_USER_S_IDENTITY_DETAILS: "Action"
    SLACKBOT_RETRIEVE_CALL_INFORMATION: "Action"
    SLACKBOT_RETRIEVE_CONVERSATION_INFORMATION: "Action"
    SLACKBOT_RETRIEVE_CONVERSATION_MEMBERS_LIST: "Action"
    SLACKBOT_RETRIEVE_CURRENT_USER_DND_STATUS: "Action"
    SLACKBOT_RETRIEVE_DETAILED_INFORMATION_ABOUT_A_FILE: "Action"
    SLACKBOT_RETRIEVE_DETAILED_USER_INFORMATION: "Action"
    SLACKBOT_RETRIEVE_MESSAGE_PERMALINK_URL: "Action"
    SLACKBOT_RETRIEVE_REMOTE_FILE_INFO_IN_SLACK: "Action"
    SLACKBOT_RETRIEVE_TEAM_PROFILE_DETAILS: "Action"
    SLACKBOT_RETRIEVE_USER_PROFILE_INFORMATION: "Action"
    SLACKBOT_REVERSE_A_CONVERSATION_S_ARCHIVAL_STATUS: "Action"
    SLACKBOT_REVOKES_A_TOKEN_WITH_OPTIONAL_TEST_MODE: "Action"
    SLACKBOT_REVOKE_PUBLIC_SHARING_ACCESS_FOR_A_FILE: "Action"
    SLACKBOT_SCHEDULES_A_MESSAGE_TO_A_CHANNEL_AT_A_SPECIFIED_TIME: "Action"
    SLACKBOT_SEARCH_CHANNELS_IN_AN_ENTERPRISE_ORGANIZATION: "Action"
    SLACKBOT_SEARCH_FOR_MESSAGES_WITH_QUERY: "Action"
    SLACKBOT_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL: "Action"
    SLACKBOT_SENDS_EPHEMERAL_MESSAGES_TO_CHANNEL_USERS: "Action"
    SLACKBOT_SET_A_CONVERSATION_S_PURPOSE: "Action"
    SLACKBOT_SET_CHANNEL_POSTING_PERMISSIONS: "Action"
    SLACKBOT_SET_EXPIRATION_FOR_A_GUEST_USER: "Action"
    SLACKBOT_SET_READ_CURSOR_IN_A_CONVERSATION: "Action"
    SLACKBOT_SET_SLACK_USER_PROFILE_INFORMATION: "Action"
    SLACKBOT_SET_THE_TOPIC_OF_A_CONVERSATION: "Action"
    SLACKBOT_SET_USER_PROFILE_PHOTO_WITH_CROPPING_OPTIONS: "Action"
    SLACKBOT_SET_USER_TO_REGULAR_STATUS: "Action"
    SLACKBOT_SET_WORKSPACE_CONNECTIONS_FOR_A_CHANNEL: "Action"
    SLACKBOT_SET_WORKSPACE_DEFAULT_CHANNELS: "Action"
    SLACKBOT_SET_WORKSPACE_DESCRIPTION: "Action"
    SLACKBOT_SET_WORKSPACE_DISCOVERABILITY_SETTINGS: "Action"
    SLACKBOT_SET_WORKSPACE_ICON: "Action"
    SLACKBOT_SET_WORKSPACE_NAME: "Action"
    SLACKBOT_SHARE_A_ME_MESSAGE_IN_A_CHANNEL: "Action"
    SLACKBOT_SHARE_REMOTE_FILE_IN_CHANNELS: "Action"
    SLACKBOT_START_REAL_TIME_MESSAGING_SESSION: "Action"
    SLACKBOT_TRIGGER_USER_PERMISSIONS_MODAL: "Action"
    SLACKBOT_UNARCHIVE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACKBOT_UNINSTALL_APP_FROM_WORKSPACE: "Action"
    SLACKBOT_UNPIN_ITEM_FROM_CHANNEL: "Action"
    SLACKBOT_UPDATES_AN_EXISTING_REMOTE_FILE: "Action"
    SLACKBOT_UPDATES_A_SLACK_MESSAGE: "Action"
    SLACKBOT_UPDATE_AN_EXISTING_SLACK_USER_GROUP: "Action"
    SLACKBOT_UPDATE_AN_EXISTING_SLACK_VIEW: "Action"
    SLACKBOT_UPDATE_SLACK_CALL_INFORMATION: "Action"
    SLACKBOT_UPDATE_USER_GROUP_MEMBERS: "Action"
    SLACKBOT_UPDATE_WORKFLOW_EXTENSION_STEP_CONFIGURATION: "Action"
    SLACKBOT_UPLOAD_OR_CREATE_A_FILE_IN_SLACK: "Action"
    SLACKBOT_WIPE_USER_SESSIONS_ACROSS_DEVICES: "Action"
    SLACK_ACTIVATE_OR_MODIFY_DO_NOT_DISTURB_DURATION: "Action"
    SLACK_ADD_AN_EMOJI_ALIAS_IN_SLACK: "Action"
    SLACK_ADD_A_CUSTOM_EMOJI_TO_A_SLACK_TEAM: "Action"
    SLACK_ADD_A_REMOTE_FILE_FROM_A_SERVICE: "Action"
    SLACK_ADD_A_STAR_TO_AN_ITEM: "Action"
    SLACK_ADD_DEFAULT_CHANNELS_TO_IDP_GROUP: "Action"
    SLACK_ADD_ENTERPRISE_USER_TO_WORKSPACE: "Action"
    SLACK_ADD_IDP_GROUP_ALLOWLIST_TO_CHANNEL: "Action"
    SLACK_ADD_REACTION_TO_AN_ITEM: "Action"
    SLACK_APPROVE_AN_APP_INSTALLATION_IN_A_WORKSPACE: "Action"
    SLACK_APPROVE_WORKSPACE_INVITE_REQUEST: "Action"
    SLACK_ARCHIVE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACK_ARCHIVE_A_SLACK_CONVERSATION: "Action"
    SLACK_ASSOCIATE_DEFAULT_WORKSPACES_WITH_IDP_GROUP: "Action"
    SLACK_CHECKS_API_CALL_AND_RETURNS_SUCCESS_OR_ERROR: "Action"
    SLACK_CHECKS_AUTHENTICATION_AND_IDENTITY: "Action"
    SLACK_CLOSE_DM_OR_MULTI_PERSON_DM: "Action"
    SLACK_CONVERSATIONS_HISTORY: "Action"
    SLACK_CONVERT_PUBLIC_CHANNEL_TO_PRIVATE: "Action"
    SLACK_CREATE_AN_ENTERPRISE_TEAM: "Action"
    SLACK_CREATE_A_REMINDER: "Action"
    SLACK_CREATE_A_SLACK_USER_GROUP: "Action"
    SLACK_CREATE_CHANNEL_BASED_CONVERSATION: "Action"
    SLACK_CUSTOMIZE_URL_UNFURLING_IN_MESSAGES: "Action"
    SLACK_DELETES_A_MESSAGE_FROM_A_CHAT: "Action"
    SLACK_DELETE_A_COMMENT_ON_A_FILE: "Action"
    SLACK_DELETE_A_FILE_BY_ID: "Action"
    SLACK_DELETE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACK_DELETE_A_SCHEDULED_MESSAGE_IN_A_CHAT: "Action"
    SLACK_DELETE_A_SLACK_REMINDER: "Action"
    SLACK_DELETE_USER_PROFILE_PHOTO: "Action"
    SLACK_DENY_WORKSPACE_INVITE_REQUEST: "Action"
    SLACK_DISABLE_AN_EXISTING_SLACK_USER_GROUP: "Action"
    SLACK_DISCONNECT_CHANNEL_FROM_WORKSPACES: "Action"
    SLACK_ENABLE_A_SPECIFIED_USER_GROUP: "Action"
    SLACK_ENABLE_PUBLIC_SHARING_OF_A_FILE: "Action"
    SLACK_END_A_CALL_WITH_DURATION_AND_ID: "Action"
    SLACK_END_USER_DO_NOT_DISTURB_SESSION: "Action"
    SLACK_END_USER_SNOOZE_MODE_IMMEDIATELY: "Action"
    SLACK_EXCHANGE_OAUTH_CODE_FOR_ACCESS_TOKEN: "Action"
    SLACK_EXCHANGE_OAUTH_CODE_FOR_WORKSPACE_TOKEN: "Action"
    SLACK_EXCHANGE_OAUTH_VERIFIER_FOR_ACCESS_TOKEN: "Action"
    SLACK_FETCH_BOT_USER_INFORMATION: "Action"
    SLACK_FETCH_CONVERSATION_HISTORY: "Action"
    SLACK_FETCH_CURRENT_TEAM_INFO_WITH_OPTIONAL_TEAM_SCOPE: "Action"
    SLACK_FETCH_DND_STATUS_FOR_MULTIPLE_TEAM_MEMBERS: "Action"
    SLACK_FETCH_ITEM_REACTIONS: "Action"
    SLACK_FETCH_MESSAGE_THREAD_FROM_A_CONVERSATION: "Action"
    SLACK_FETCH_WORKSPACE_SETTINGS_INFORMATION: "Action"
    SLACK_FIND_USER_BY_EMAIL_ADDRESS: "Action"
    SLACK_GET_BILLABLE_TEAM_USER_INFO: "Action"
    SLACK_GET_CHANNEL_CONVERSATION_PREFERENCES: "Action"
    SLACK_GET_CHANNEL_S_CONNECTED_WORKSPACES_IN_ENTERPRISE: "Action"
    SLACK_GET_CURRENT_TEAM_INTEGRATION_LOGS: "Action"
    SLACK_GET_CURRENT_TEAM_S_ACCESS_LOGS: "Action"
    SLACK_GET_REMINDER_INFORMATION: "Action"
    SLACK_GET_USER_PRESENCE_INFO: "Action"
    SLACK_INDICATE_WORKFLOW_STEP_FAILURE: "Action"
    SLACK_INITIATES_CHANNEL_BASED_CONVERSATIONS: "Action"
    SLACK_INVALIDATE_A_USER_SESSION_BY_ID: "Action"
    SLACK_INVITE_USERS_TO_A_SLACK_CHANNEL: "Action"
    SLACK_INVITE_USER_TO_CHANNEL: "Action"
    SLACK_INVITE_USER_TO_WORKSPACE_WITH_OPTIONAL_CHANNEL_INVITES: "Action"
    SLACK_JOIN_AN_EXISTING_CONVERSATION: "Action"
    SLACK_LEAVE_A_CONVERSATION: "Action"
    SLACK_LISTS_PINNED_ITEMS_IN_A_CHANNEL: "Action"
    SLACK_LISTS_USER_S_STARRED_ITEMS_WITH_PAGINATION: "Action"
    SLACK_LIST_ACCESSIBLE_CONVERSATIONS_FOR_A_USER: "Action"
    SLACK_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS: "Action"
    SLACK_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION: "Action"
    SLACK_LIST_ALL_TEAMS_IN_AN_ENTERPRISE_ORGANIZATION: "Action"
    SLACK_LIST_ALL_USERS_IN_A_USER_GROUP: "Action"
    SLACK_LIST_APPROVED_APPS_FOR_ORG_OR_WORKSPACE: "Action"
    SLACK_LIST_APPROVED_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACK_LIST_APP_PERMISSIONS_ON_A_TEAM: "Action"
    SLACK_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM: "Action"
    SLACK_LIST_APP_RESOURCE_GRANTS_ON_A_TEAM: "Action"
    SLACK_LIST_APP_USER_GRANTS_AND_SCOPES_ON_TEAM: "Action"
    SLACK_LIST_DENIED_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACK_LIST_DISCONNECTED_CHANNELS_WITH_ORIGINAL_IDS_FOR_EKM: "Action"
    SLACK_LIST_ENTERPRISE_GRID_ORGANIZATION_EMOJIS: "Action"
    SLACK_LIST_EVENT_AUTHORIZATIONS_FOR_APPS: "Action"
    SLACK_LIST_FILES_WITH_FILTERS_IN_SLACK: "Action"
    SLACK_LIST_IDP_GROUPS_LINKED_TO_A_CHANNEL: "Action"
    SLACK_LIST_ORG_LEVEL_IDP_GROUP_CHANNELS: "Action"
    SLACK_LIST_PENDING_WORKSPACE_INVITE_REQUESTS: "Action"
    SLACK_LIST_RESTRICTED_APPS_FOR_AN_ORG_OR_WORKSPACE: "Action"
    SLACK_LIST_SCHEDULED_MESSAGES_IN_A_CHANNEL: "Action"
    SLACK_LIST_SLACK_S_REMOTE_FILES_WITH_FILTERS: "Action"
    SLACK_LIST_TEAM_CUSTOM_EMOJIS: "Action"
    SLACK_LIST_TEAM_WORKSPACE_APP_REQUESTS: "Action"
    SLACK_LIST_USER_GROUPS_FOR_TEAM_WITH_OPTIONS: "Action"
    SLACK_LIST_USER_REACTIONS: "Action"
    SLACK_LIST_USER_REMINDERS_WITH_DETAILS: "Action"
    SLACK_LIST_WORKSPACE_ADMINS: "Action"
    SLACK_LIST_WORKSPACE_OWNERS: "Action"
    SLACK_LIST_WORKSPACE_USERS: "Action"
    SLACK_MANUALLY_SET_USER_PRESENCE: "Action"
    SLACK_MAP_USER_IDS_FOR_ENTERPRISE_GRID_WORKSPACES: "Action"
    SLACK_MARK_A_USER_AS_ACTIVE_DEPRECATED: "Action"
    SLACK_MARK_REMINDER_AS_COMPLETE: "Action"
    SLACK_MARK_WORKFLOW_STEP_AS_COMPLETED: "Action"
    SLACK_OPEN_A_VIEW_FOR_A_SLACK_USER: "Action"
    SLACK_OPEN_OR_RESUME_DIRECT_OR_MULTI_PERSON_MESSAGES: "Action"
    SLACK_OPEN_USER_DIALOG_WITH_JSON_DEFINED_UI: "Action"
    SLACK_PINS_AN_ITEM_TO_A_CHANNEL: "Action"
    SLACK_PROMOTE_USER_TO_ADMIN_STATUS: "Action"
    SLACK_PROMOTE_USER_TO_WORKSPACE_OWNER: "Action"
    SLACK_PUBLISH_STATIC_VIEW_FOR_USER: "Action"
    SLACK_PUSH_VIEW_TO_ROOT_VIEW_STACK: "Action"
    SLACK_REGISTERS_A_NEW_CALL_WITH_PARTICIPANTS: "Action"
    SLACK_REGISTERS_NEW_CALL_PARTICIPANTS: "Action"
    SLACK_REGISTER_CALL_PARTICIPANTS_REMOVAL: "Action"
    SLACK_REMOVE_A_REMOTE_FILE: "Action"
    SLACK_REMOVE_A_STAR_FROM_AN_ITEM: "Action"
    SLACK_REMOVE_A_USER_FROM_A_CONVERSATION: "Action"
    SLACK_REMOVE_CHANNELS_FROM_IDP_GROUP: "Action"
    SLACK_REMOVE_ENTERPRISE_GRID_ORG_EMOJI: "Action"
    SLACK_REMOVE_IDP_GROUP_FROM_PRIVATE_CHANNEL: "Action"
    SLACK_REMOVE_REACTION_FROM_ITEM: "Action"
    SLACK_REMOVE_USER_FROM_WORKSPACE: "Action"
    SLACK_RENAME_AN_EMOJI: "Action"
    SLACK_RENAME_A_CONVERSATION: "Action"
    SLACK_RENAME_A_SLACK_CHANNEL: "Action"
    SLACK_REQUEST_ADDITIONAL_APP_PERMISSIONS: "Action"
    SLACK_RESTRICT_APP_INSTALLATION_ON_WORKSPACE: "Action"
    SLACK_RETRIEVE_A_USER_S_IDENTITY_DETAILS: "Action"
    SLACK_RETRIEVE_CALL_INFORMATION: "Action"
    SLACK_RETRIEVE_CONVERSATION_INFORMATION: "Action"
    SLACK_RETRIEVE_CONVERSATION_MEMBERS_LIST: "Action"
    SLACK_RETRIEVE_CURRENT_USER_DND_STATUS: "Action"
    SLACK_RETRIEVE_DETAILED_INFORMATION_ABOUT_A_FILE: "Action"
    SLACK_RETRIEVE_DETAILED_USER_INFORMATION: "Action"
    SLACK_RETRIEVE_MESSAGE_PERMALINK_URL: "Action"
    SLACK_RETRIEVE_REMOTE_FILE_INFO_IN_SLACK: "Action"
    SLACK_RETRIEVE_TEAM_PROFILE_DETAILS: "Action"
    SLACK_RETRIEVE_USER_PROFILE_INFORMATION: "Action"
    SLACK_REVERSE_A_CONVERSATION_S_ARCHIVAL_STATUS: "Action"
    SLACK_REVOKES_A_TOKEN_WITH_OPTIONAL_TEST_MODE: "Action"
    SLACK_REVOKE_PUBLIC_SHARING_ACCESS_FOR_A_FILE: "Action"
    SLACK_SCHEDULES_A_MESSAGE_TO_A_CHANNEL_AT_A_SPECIFIED_TIME: "Action"
    SLACK_SEARCH_CHANNELS_IN_AN_ENTERPRISE_ORGANIZATION: "Action"
    SLACK_SEARCH_FOR_MESSAGES_WITH_QUERY: "Action"
    SLACK_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL: "Action"
    SLACK_SENDS_EPHEMERAL_MESSAGES_TO_CHANNEL_USERS: "Action"
    SLACK_SET_A_CONVERSATION_S_PURPOSE: "Action"
    SLACK_SET_CHANNEL_POSTING_PERMISSIONS: "Action"
    SLACK_SET_EXPIRATION_FOR_A_GUEST_USER: "Action"
    SLACK_SET_READ_CURSOR_IN_A_CONVERSATION: "Action"
    SLACK_SET_SLACK_USER_PROFILE_INFORMATION: "Action"
    SLACK_SET_THE_TOPIC_OF_A_CONVERSATION: "Action"
    SLACK_SET_USER_PROFILE_PHOTO_WITH_CROPPING_OPTIONS: "Action"
    SLACK_SET_USER_TO_REGULAR_STATUS: "Action"
    SLACK_SET_WORKSPACE_CONNECTIONS_FOR_A_CHANNEL: "Action"
    SLACK_SET_WORKSPACE_DEFAULT_CHANNELS: "Action"
    SLACK_SET_WORKSPACE_DESCRIPTION: "Action"
    SLACK_SET_WORKSPACE_DISCOVERABILITY_SETTINGS: "Action"
    SLACK_SET_WORKSPACE_ICON: "Action"
    SLACK_SET_WORKSPACE_NAME: "Action"
    SLACK_SHARE_A_ME_MESSAGE_IN_A_CHANNEL: "Action"
    SLACK_SHARE_REMOTE_FILE_IN_CHANNELS: "Action"
    SLACK_START_REAL_TIME_MESSAGING_SESSION: "Action"
    SLACK_TRIGGER_USER_PERMISSIONS_MODAL: "Action"
    SLACK_UNARCHIVE_A_PUBLIC_OR_PRIVATE_CHANNEL: "Action"
    SLACK_UNINSTALL_APP_FROM_WORKSPACE: "Action"
    SLACK_UNPIN_ITEM_FROM_CHANNEL: "Action"
    SLACK_UPDATES_AN_EXISTING_REMOTE_FILE: "Action"
    SLACK_UPDATES_A_SLACK_MESSAGE: "Action"
    SLACK_UPDATE_AN_EXISTING_SLACK_USER_GROUP: "Action"
    SLACK_UPDATE_AN_EXISTING_SLACK_VIEW: "Action"
    SLACK_UPDATE_SLACK_CALL_INFORMATION: "Action"
    SLACK_UPDATE_USER_GROUP_MEMBERS: "Action"
    SLACK_UPDATE_WORKFLOW_EXTENSION_STEP_CONFIGURATION: "Action"
    SLACK_UPLOAD_OR_CREATE_A_FILE_IN_SLACK: "Action"
    SLACK_WIPE_USER_SESSIONS_ACROSS_DEVICES: "Action"
    SNOWFLAKE_DESCRIBE_TABLE: "Action"
    SNOWFLAKE_EXPLORE_COLUMNS: "Action"
    SNOWFLAKE_RUN_QUERY: "Action"
    SNOWFLAKE_SHOW_TABLES: "Action"
    SOUNDCLOUD_CREATES_A_PLAYLIST: "Action"
    SOUNDCLOUD_DELETES_A_PLAYLIST: "Action"
    SOUNDCLOUD_DELETES_A_TRACK: "Action"
    SOUNDCLOUD_DELETES_A_USER_WHO_IS_FOLLOWED_BY_THE_AUTHENTICATED_USER: "Action"
    SOUNDCLOUD_FETCH_SOUND_CLOUD_FOLLOWER_PROFILE_DETAILS: "Action"
    SOUNDCLOUD_FETCH_USER_FAVORITED_TRACKS: "Action"
    SOUNDCLOUD_FETCH_USER_FAVORITES: "Action"
    SOUNDCLOUD_FETCH_USER_FOLLOWING_DETAILS: "Action"
    SOUNDCLOUD_FETCH_USER_PROFILES_LINKS: "Action"
    SOUNDCLOUD_FOLLOWS_A_USER: "Action"
    SOUNDCLOUD_GET_FOLLOWER_USER_DETAILS: "Action"
    SOUNDCLOUD_LIKES_A_PLAYLIST: "Action"
    SOUNDCLOUD_LIKES_A_TRACK: "Action"
    SOUNDCLOUD_LIST_AUTHENTICATED_USER_FOLLOWERS: "Action"
    SOUNDCLOUD_LIST_FOLLOWED_BY_USER: "Action"
    SOUNDCLOUD_LIST_USER_FAVORITES: "Action"
    SOUNDCLOUD_OAUTH2_AUTHORIZATION_REDIRECT_HANDLER: "Action"
    SOUNDCLOUD_PERFORMS_A_PLAYLIST_SEARCH_BASED_ON_A_QUERY: "Action"
    SOUNDCLOUD_PERFORMS_A_USER_SEARCH_BASED_ON_A_QUERY: "Action"
    SOUNDCLOUD_PROVISION_ACCESS_TOKENS_POST_AUTHORIZATION: "Action"
    SOUNDCLOUD_RECENT_THE_AUTHENTICATED_USER_S_ACTIVITIES: "Action"
    SOUNDCLOUD_RECENT_TRACKS_FROM_FOLLOWED_USERS: "Action"
    SOUNDCLOUD_REMOVES_A_REPOST_ON_A_PLAYLIST_AS_THE_AUTHENTICATED_USER: "Action"
    SOUNDCLOUD_REMOVES_A_REPOST_ON_A_TRACK_AS_THE_AUTHENTICATED_USER: "Action"
    SOUNDCLOUD_REPOSTS_A_PLAYLIST_AS_THE_AUTHENTICATED_USER: "Action"
    SOUNDCLOUD_REPOSTS_A_TRACK_AS_THE_AUTHENTICATED_USER: "Action"
    SOUNDCLOUD_RESOLVE_SOUND_CLOUD_URLS_TO_API_RESOURCE_URLS: "Action"
    SOUNDCLOUD_RETURNS_ALL_RELATED_TRACKS_OF_TRACK_ON_SOUND_CLOUD: "Action"
    SOUNDCLOUD_RETURNS_A_COLLECTION_OF_PLAYLIST_S_REPOSTERS: "Action"
    SOUNDCLOUD_RETURNS_A_COLLECTION_OF_TRACK_S_REPOSTERS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_THE_CURRENT_USER_S_TRACKS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USERS_WHO_HAVE_FAVORITED_OR_LIKED_THE_TRACK: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_FOLLOWERS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_FOLLOWINGS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_LIKED_PLAYLISTS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_LIKED_TRACKS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_PLAYLISTS: "Action"
    SOUNDCLOUD_RETURNS_A_LIST_OF_USER_S_TRACKS: "Action"
    SOUNDCLOUD_RETURNS_A_PLAYLIST: "Action"
    SOUNDCLOUD_RETURNS_A_TRACK: "Action"
    SOUNDCLOUD_RETURNS_A_TRACK_S_STREAMABLE_URLS: "Action"
    SOUNDCLOUD_RETURNS_A_USER: "Action"
    SOUNDCLOUD_RETURNS_THE_AUTHENTICATED_USER_S_ACTIVITIES: "Action"
    SOUNDCLOUD_RETURNS_THE_AUTHENTICATED_USER_S_INFORMATION: "Action"
    SOUNDCLOUD_RETURNS_THE_COMMENTS_POSTED_ON_THE_TRACK_TRACK_ID: "Action"
    SOUNDCLOUD_RETURNS_THE_NEWLY_CREATED_COMMENT_ON_SUCCESS: "Action"
    SOUNDCLOUD_RETURNS_TRACKS_UNDER_A_PLAYLIST: "Action"
    SOUNDCLOUD_RETURNS_USER_S_PLAYLISTS_SETS: "Action"
    SOUNDCLOUD_UNLIKES_A_PLAYLIST: "Action"
    SOUNDCLOUD_UNLIKES_A_TRACK: "Action"
    SOUNDCLOUD_UPDATES_A_PLAYLIST: "Action"
    SOUNDCLOUD_UPDATES_A_TRACK_S_INFORMATION: "Action"
    SOUNDCLOUD_UPLOADS_A_NEW_TRACK: "Action"
    SOUNDCLOUD_USER_RECENT_TRACK_ACTIVITIES: "Action"
    SPIDERTOOL_CRAWL: "Action"
    SPIDERTOOL_SCRAPE: "Action"
    SPLITWISE_ADD_USER_TO_GROUP: "Action"
    SPLITWISE_DELETE_GROUP: "Action"
    SPLITWISE_GET_CURRENT_USER_INFO: "Action"
    SPLITWISE_GET_GROUP: "Action"
    SPLITWISE_GET_USER_INFO: "Action"
    SPLITWISE_REMOVE_USER_FROM_GROUP: "Action"
    SPLITWISE_RESTORE_GROUP: "Action"
    SPOTIFY_ADD_CUSTOM_PLAYLIST_COVER_IMAGE: "Action"
    SPOTIFY_ADD_ITEMS_TO_PLAYLIST: "Action"
    SPOTIFY_ADD_ITEM_TO_PLAYBACK_QUEUE: "Action"
    SPOTIFY_CHANGE_PLAYLIST_DETAILS: "Action"
    SPOTIFY_CHECK_IF_USERS_FOLLOW_PLAYLIST: "Action"
    SPOTIFY_CHECK_IF_USER_FOLLOWS_ARTISTS_OR_USERS: "Action"
    SPOTIFY_CHECK_USER_S_SAVED_ALBUMS: "Action"
    SPOTIFY_CHECK_USER_S_SAVED_AUDIOBOOKS: "Action"
    SPOTIFY_CHECK_USER_S_SAVED_EPISODES: "Action"
    SPOTIFY_CHECK_USER_S_SAVED_SHOWS: "Action"
    SPOTIFY_CHECK_USER_S_SAVED_TRACKS: "Action"
    SPOTIFY_CREATE_PLAYLIST: "Action"
    SPOTIFY_FOLLOW_ARTISTS_OR_USERS: "Action"
    SPOTIFY_FOLLOW_PLAYLIST: "Action"
    SPOTIFY_GET_ALBUM: "Action"
    SPOTIFY_GET_ALBUM_TRACKS: "Action"
    SPOTIFY_GET_AN_ARTISTS_ALBUMS: "Action"
    SPOTIFY_GET_AN_AUDIOBOOK: "Action"
    SPOTIFY_GET_ARTIST: "Action"
    SPOTIFY_GET_ARTIST_S_ALBUMS: "Action"
    SPOTIFY_GET_ARTIST_S_RELATED_ARTISTS: "Action"
    SPOTIFY_GET_ARTIST_S_TOP_TRACKS: "Action"
    SPOTIFY_GET_AUDIOBOOK_CHAPTERS: "Action"
    SPOTIFY_GET_AVAILABLE_DEVICES: "Action"
    SPOTIFY_GET_AVAILABLE_GENRE_SEEDS: "Action"
    SPOTIFY_GET_AVAILABLE_MARKETS: "Action"
    SPOTIFY_GET_A_CHAPTER: "Action"
    SPOTIFY_GET_A_USERS_AVAILABLE_DEVICES: "Action"
    SPOTIFY_GET_CATEGORY_S_PLAYLISTS: "Action"
    SPOTIFY_GET_CURRENTLY_PLAYING_TRACK: "Action"
    SPOTIFY_GET_CURRENT_USER_S_PLAYLISTS: "Action"
    SPOTIFY_GET_CURRENT_USER_S_PROFILE: "Action"
    SPOTIFY_GET_EPISODE: "Action"
    SPOTIFY_GET_FEATURED_PLAYLISTS: "Action"
    SPOTIFY_GET_FOLLOWED_ARTISTS: "Action"
    SPOTIFY_GET_LIST_USERS_PLAYLISTS: "Action"
    SPOTIFY_GET_NEW_RELEASES: "Action"
    SPOTIFY_GET_PLAYBACK_STATE: "Action"
    SPOTIFY_GET_PLAYLIST: "Action"
    SPOTIFY_GET_PLAYLIST_COVER_IMAGE: "Action"
    SPOTIFY_GET_PLAYLIST_ITEMS: "Action"
    SPOTIFY_GET_QUEUE: "Action"
    SPOTIFY_GET_RECENTLY_PLAYED_TRACKS: "Action"
    SPOTIFY_GET_RECOMMENDATIONS: "Action"
    SPOTIFY_GET_SEVERAL_ALBUMS: "Action"
    SPOTIFY_GET_SEVERAL_ARTISTS: "Action"
    SPOTIFY_GET_SEVERAL_AUDIOBOOKS: "Action"
    SPOTIFY_GET_SEVERAL_BROWSE_CATEGORIES: "Action"
    SPOTIFY_GET_SEVERAL_CHAPTERS: "Action"
    SPOTIFY_GET_SEVERAL_EPISODES: "Action"
    SPOTIFY_GET_SEVERAL_SHOWS: "Action"
    SPOTIFY_GET_SEVERAL_TRACKS: "Action"
    SPOTIFY_GET_SEVERAL_TRACKS_AUDIO_FEATURES: "Action"
    SPOTIFY_GET_SHOW: "Action"
    SPOTIFY_GET_SHOW_EPISODES: "Action"
    SPOTIFY_GET_SINGLE_BROWSE_CATEGORY: "Action"
    SPOTIFY_GET_THE_USERS_CURRENTLY_PLAYING_TRACK: "Action"
    SPOTIFY_GET_THE_USER_S_QUEUE: "Action"
    SPOTIFY_GET_TRACK: "Action"
    SPOTIFY_GET_TRACK_S_AUDIO_ANALYSIS: "Action"
    SPOTIFY_GET_TRACK_S_AUDIO_FEATURES: "Action"
    SPOTIFY_GET_USERS_TOP_ARTISTS: "Action"
    SPOTIFY_GET_USERS_TOP_TRACKS: "Action"
    SPOTIFY_GET_USER_S_PLAYLISTS: "Action"
    SPOTIFY_GET_USER_S_PROFILE: "Action"
    SPOTIFY_GET_USER_S_SAVED_ALBUMS: "Action"
    SPOTIFY_GET_USER_S_SAVED_AUDIOBOOKS: "Action"
    SPOTIFY_GET_USER_S_SAVED_EPISODES: "Action"
    SPOTIFY_GET_USER_S_SAVED_SHOWS: "Action"
    SPOTIFY_GET_USER_S_SAVED_TRACKS: "Action"
    SPOTIFY_GET_USER_S_TOP_ARTISTS: "Action"
    SPOTIFY_GET_USER_S_TOP_TRACKS: "Action"
    SPOTIFY_PAUSE_PLAYBACK: "Action"
    SPOTIFY_REMOVE_PLAYLIST_ITEMS: "Action"
    SPOTIFY_REMOVE_USERS_SAVED_ALBUMS: "Action"
    SPOTIFY_REMOVE_USER_S_SAVED_AUDIOBOOKS: "Action"
    SPOTIFY_REMOVE_USER_S_SAVED_EPISODES: "Action"
    SPOTIFY_REMOVE_USER_S_SAVED_SHOWS: "Action"
    SPOTIFY_REMOVE_USER_S_SAVED_TRACKS: "Action"
    SPOTIFY_SAVE_ALBUMS_FOR_CURRENT_USER: "Action"
    SPOTIFY_SAVE_ALBUMS_USER: "Action"
    SPOTIFY_SAVE_AUDIOBOOKS_FOR_CURRENT_USER: "Action"
    SPOTIFY_SAVE_EPISODES_FOR_CURRENT_USER: "Action"
    SPOTIFY_SAVE_SHOWS_FOR_CURRENT_USER: "Action"
    SPOTIFY_SAVE_TRACKS_FOR_CURRENT_USER: "Action"
    SPOTIFY_SEARCH_FOR_ITEM: "Action"
    SPOTIFY_SEEK_TO_POSITION: "Action"
    SPOTIFY_SET_PLAYBACK_VOLUME: "Action"
    SPOTIFY_SET_REPEAT_MODE: "Action"
    SPOTIFY_SKIP_TO_NEXT: "Action"
    SPOTIFY_SKIP_TO_PREVIOUS: "Action"
    SPOTIFY_START_RESUME_PLAYBACK: "Action"
    SPOTIFY_TOGGLE_PLAYBACK_SHUFFLE: "Action"
    SPOTIFY_TRANSFER_PLAYBACK: "Action"
    SPOTIFY_UNFOLLOW_ARTISTS_OR_USERS: "Action"
    SPOTIFY_UNFOLLOW_PLAYLIST: "Action"
    SPOTIFY_UPDATE_PLAYLIST_ITEMS: "Action"
    SQLTOOL_SQL_QUERY: "Action"
    STRAVA_CREATE_AN_ACTIVITY: "Action"
    STRAVA_EXPLORE_SEGMENTS: "Action"
    STRAVA_EXPORT_ROUTE_GPX: "Action"
    STRAVA_EXPORT_ROUTE_TCX: "Action"
    STRAVA_GET_ACTIVITY: "Action"
    STRAVA_GET_ACTIVITY_STREAMS: "Action"
    STRAVA_GET_ACTIVITY_ZONES: "Action"
    STRAVA_GET_ATHLETE_STATS: "Action"
    STRAVA_GET_AUTHENTICATED_ATHLETE: "Action"
    STRAVA_GET_CLUB: "Action"
    STRAVA_GET_EQUIPMENT: "Action"
    STRAVA_GET_ROUTE: "Action"
    STRAVA_GET_ROUTE_STREAMS: "Action"
    STRAVA_GET_SEGMENT: "Action"
    STRAVA_GET_SEGMENT_EFFORT: "Action"
    STRAVA_GET_SEGMENT_EFFORT_STREAMS: "Action"
    STRAVA_GET_SEGMENT_STREAMS: "Action"
    STRAVA_GET_UPLOAD: "Action"
    STRAVA_GET_ZONES: "Action"
    STRAVA_LIST_ACTIVITY_COMMENTS: "Action"
    STRAVA_LIST_ACTIVITY_KUDOERS: "Action"
    STRAVA_LIST_ACTIVITY_LAPS: "Action"
    STRAVA_LIST_ATHLETE_ACTIVITIES: "Action"
    STRAVA_LIST_ATHLETE_CLUBS: "Action"
    STRAVA_LIST_ATHLETE_ROUTES: "Action"
    STRAVA_LIST_CLUB_ACTIVITIES: "Action"
    STRAVA_LIST_CLUB_ADMINISTRATORS: "Action"
    STRAVA_LIST_CLUB_MEMBERS: "Action"
    STRAVA_LIST_SEGMENT_EFFORTS: "Action"
    STRAVA_LIST_STARRED_SEGMENTS: "Action"
    STRAVA_STAR_SEGMENT: "Action"
    STRAVA_UPDATE_ACTIVITY: "Action"
    STRAVA_UPDATE_ATHLETE: "Action"
    STRAVA_UPLOAD_ACTIVITY: "Action"
    SYSTEM_NOTIFY: "Action"
    SYSTEM_SCREEN_CAPTURE: "Action"
    TASKADE_ASSIGN_HANDLES_TO_TASK: "Action"
    TASKADE_COMPLETE_A_PROJECT_TASK: "Action"
    TASKADE_COPY_PROJECT_TO_SPECIFIED_FOLDER: "Action"
    TASKADE_CREATE_AGENT_IN_FOLDER_WITH_CUSTOMIZABLE_DATA_AND_PERSONA: "Action"
    TASKADE_CREATE_OR_UPDATE_TASK_DATE: "Action"
    TASKADE_CREATE_PROJECT_IN_FOLDER: "Action"
    TASKADE_CREATE_PROJECT_IN_WORKSPACE: "Action"
    TASKADE_CREATE_PROJECT_TASKS_WITH_DETAILED_OPTIONS: "Action"
    TASKADE_DELETE_PROJECT_TASK: "Action"
    TASKADE_DELETE_TASK_DATE: "Action"
    TASKADE_ENABLE_AGENT_PUBLIC_ACCESS: "Action"
    TASKADE_ENABLE_PROJECT_SHARE_LINK: "Action"
    TASKADE_GET_ALL_PROJECTS_WITHIN_A_SPECIFIED_FOLDER: "Action"
    TASKADE_GET_MY_PROJECTS_WITH_SORTING_AND_PAGINATION: "Action"
    TASKADE_GET_PROJECT_S_SHARE_LINK_INFO: "Action"
    TASKADE_GET_WORKSPACE_FOLDERS: "Action"
    TASKADE_REMOVE_TASK_ASSIGNEE: "Action"
    TASKADE_RETRIEVE_DETAILED_TASK_INFORMATION: "Action"
    TASKADE_RETRIEVE_PROJECT_TASKS_WITH_PAGINATION_OPTIONS: "Action"
    TASKADE_RETRIEVE_USER_S_WORKSPACES: "Action"
    TAVILY_TAVILY_SEARCH: "Action"
    TEST_ASANA_CREATE_SUBTASK: "Action"
    TEST_ASANA_GET_SUBTASKS: "Action"
    TRELLO_ACTION_GET_BY_ID: "Action"
    TRELLO_ACTION_GET_LIST_BY_ID_ACTION: "Action"
    TRELLO_ADD_BOARDS: "Action"
    TRELLO_ADD_BOARDS_CALENDAR_KEY_GENERATE_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_CHECKLISTS_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_EMAIL_KEY_GENERATE_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_LABELS_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_LISTS_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_MARK_AS_VIEWED_BY_ID_BOARD: "Action"
    TRELLO_ADD_BOARDS_POWER_UPS_BY_ID_BOARD: "Action"
    TRELLO_ADD_CARDS: "Action"
    TRELLO_ADD_CARDS_ACTIONS_COMMENTS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_ATTACHMENTS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_CHECKLISTS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_CHECKLIST_CHECK_ITEM_BY_ID_CARD_BY_ID_CHECKLIST: "Action"
    TRELLO_ADD_CARDS_ID_LABELS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_ID_MEMBERS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_LABELS_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_MARK_ASSOCIATED_NOTIFICATIONS_READ_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_MEMBERS_VOTED_BY_ID_CARD: "Action"
    TRELLO_ADD_CARDS_STICKERS_BY_ID_CARD: "Action"
    TRELLO_ADD_CHECKLISTS: "Action"
    TRELLO_ADD_CHECKLISTS_CHECK_ITEMS_BY_ID_CHECKLIST: "Action"
    TRELLO_ADD_LABELS: "Action"
    TRELLO_ADD_LISTS: "Action"
    TRELLO_ADD_LISTS_ARCHIVE_ALL_CARDS_BY_ID_LIST: "Action"
    TRELLO_ADD_LISTS_CARDS_BY_ID_LIST: "Action"
    TRELLO_ADD_LISTS_MOVE_ALL_CARDS_BY_ID_LIST: "Action"
    TRELLO_ADD_MEMBERS_AVATAR_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_BOARD_BACKGROUNDS_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_BOARD_STARS_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_CUSTOM_BOARD_BACKGROUNDS_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_CUSTOM_EMOJI_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_CUSTOM_STICKERS_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_ONE_TIME_MESSAGES_DISMISSED_BY_ID_MEMBER: "Action"
    TRELLO_ADD_MEMBERS_SAVED_SEARCHES_BY_ID_MEMBER: "Action"
    TRELLO_ADD_NOTIFICATIONS_ALL_READ: "Action"
    TRELLO_ADD_ORGANIZATIONS: "Action"
    TRELLO_ADD_ORGANIZATIONS_LOGO_BY_ID_ORG: "Action"
    TRELLO_ADD_SESSIONS: "Action"
    TRELLO_ADD_TOKENS_WEBHOOKS_BY_TOKEN: "Action"
    TRELLO_BOARD_GET_LISTS_BY_ID_BOARD: "Action"
    TRELLO_CARD_GET_BY_ID: "Action"
    TRELLO_CARD_UPDATE_ID_LIST_BY_ID_CARD: "Action"
    TRELLO_CARD_UPDATE_POS_BY_ID_CARD: "Action"
    TRELLO_CONVERT_CHECKLIST_ITEM_TO_CARD: "Action"
    TRELLO_DELETE_ACTIONS_BY_ID_ACTION: "Action"
    TRELLO_DELETE_BOARDS_MEMBERS_BY_ID_BOARD_BY_ID_MEMBER: "Action"
    TRELLO_DELETE_BOARDS_POWER_UPS_BY_ID_BOARD_BY_POWER_UP: "Action"
    TRELLO_DELETE_CARDS_ACTIONS_COMMENTS_BY_ID_CARD_BY_ID_ACTION: "Action"
    TRELLO_DELETE_CARDS_ATTACHMENTS_BY_ID_CARD_BY_ID_ATTACHMENT: "Action"
    TRELLO_DELETE_CARDS_BY_ID_CARD: "Action"
    TRELLO_DELETE_CARDS_CHECKLISTS_BY_ID_CARD_BY_ID_CHECKLIST: "Action"
    TRELLO_DELETE_CARDS_ID_LABELS_BY_ID_CARD_BY_ID_LABEL: "Action"
    TRELLO_DELETE_CARDS_ID_MEMBERS_BY_ID_CARD_BY_ID_MEMBER: "Action"
    TRELLO_DELETE_CARDS_LABELS_BY_ID_CARD_BY_COLOR: "Action"
    TRELLO_DELETE_CARDS_MEMBERS_VOTED_BY_ID_CARD_BY_ID_MEMBER: "Action"
    TRELLO_DELETE_CARDS_STICKERS_BY_ID_CARD_BY_ID_STICKER: "Action"
    TRELLO_DELETE_CHECKLISTS_BY_ID_CHECKLIST: "Action"
    TRELLO_DELETE_CHECKLISTS_CHECK_ITEMS_BY_ID_CHECKLIST_BY_ID_CHECK_ITEM: "Action"
    TRELLO_DELETE_LABELS_BY_ID_LABEL: "Action"
    TRELLO_DELETE_MEMBERS_BOARD_BACKGROUNDS_BY_ID_MEMBER_BY_ID_BOARD_BACKGROUND: "Action"
    TRELLO_DELETE_MEMBERS_BOARD_STARS_BY_ID_MEMBER_BY_ID_BOARD_STAR: "Action"
    TRELLO_DELETE_MEMBERS_CUSTOM_STICKERS_BY_ID_MEMBER_BY_ID_CUSTOM_STICKER: "Action"
    TRELLO_DELETE_MEMBERS_SAVED_SEARCHES_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_DELETE_ORGANIZATIONS_BY_ID_ORG: "Action"
    TRELLO_DELETE_ORGANIZATIONS_LOGO_BY_ID_ORG: "Action"
    TRELLO_DELETE_ORGANIZATIONS_MEMBERS_ALL_BY_ID_ORG_BY_ID_MEMBER: "Action"
    TRELLO_DELETE_ORGANIZATIONS_MEMBERS_BY_ID_ORG_BY_ID_MEMBER: "Action"
    TRELLO_DELETE_ORGANIZATIONS_PREFS_ASSOCIATED_DOMAIN_BY_ID_ORG: "Action"
    TRELLO_DELETE_ORGANIZATIONS_PREFS_ORG_INVITE_RESTRICT_BY_ID_ORG: "Action"
    TRELLO_DELETE_TOKENS_BY_TOKEN: "Action"
    TRELLO_DELETE_TOKENS_WEBHOOKS_BY_TOKEN_BY_ID_WEBHOOK: "Action"
    TRELLO_DELETE_WEBHOOKS_BY_ID_WEBHOOK: "Action"
    TRELLO_GET_ACTIONS_BOARD_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_BOARD_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_CARD_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_CARD_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_DISPLAY_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_ENTITIES_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_LIST_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_LIST_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_MEMBER_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_MEMBER_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_MEMBER_CREATOR_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_MEMBER_CREATOR_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_ACTIONS_ORGANIZATION_BY_ID_ACTION: "Action"
    TRELLO_GET_ACTIONS_ORGANIZATION_BY_ID_ACTION_BY_FIELD: "Action"
    TRELLO_GET_BATCH: "Action"
    TRELLO_GET_BOARDS_ACTIONS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_BOARD_STARS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_BY_ID_BOARD_BY_FIELD: "Action"
    TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD_BY_FILTER: "Action"
    TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD_BY_ID_CARD: "Action"
    TRELLO_GET_BOARDS_CHECKLISTS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_DELTAS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_LABELS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_LABELS_BY_ID_BOARD_BY_ID_LABEL: "Action"
    TRELLO_GET_BOARDS_LISTS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_LISTS_BY_ID_BOARD_BY_FILTER: "Action"
    TRELLO_GET_BOARDS_MEMBERSHIPS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_MEMBERSHIPS_BY_ID_BOARD_BY_ID_MEMBERSHIP: "Action"
    TRELLO_GET_BOARDS_MEMBERS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_MEMBERS_BY_ID_BOARD_BY_FILTER: "Action"
    TRELLO_GET_BOARDS_MEMBERS_CARDS_BY_ID_BOARD_BY_ID_MEMBER: "Action"
    TRELLO_GET_BOARDS_MEMBERS_INVITED_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_MEMBERS_INVITED_BY_ID_BOARD_BY_FIELD: "Action"
    TRELLO_GET_BOARDS_MY_PREFS_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_ORGANIZATION_BY_ID_BOARD: "Action"
    TRELLO_GET_BOARDS_ORGANIZATION_BY_ID_BOARD_BY_FIELD: "Action"
    TRELLO_GET_CARDS_ACTIONS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_ATTACHMENTS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_ATTACHMENTS_BY_ID_CARD_BY_ID_ATTACHMENT: "Action"
    TRELLO_GET_CARDS_BOARD_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_BOARD_BY_ID_CARD_BY_FIELD: "Action"
    TRELLO_GET_CARDS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_BY_ID_CARD_BY_FIELD: "Action"
    TRELLO_GET_CARDS_CHECKLISTS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_CHECK_ITEM_STATES_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_LIST_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_LIST_BY_ID_CARD_BY_FIELD: "Action"
    TRELLO_GET_CARDS_MEMBERS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_MEMBERS_VOTED_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_STICKERS_BY_ID_CARD: "Action"
    TRELLO_GET_CARDS_STICKERS_BY_ID_CARD_BY_ID_STICKER: "Action"
    TRELLO_GET_CHECKLISTS_BOARD_BY_ID_CHECKLIST: "Action"
    TRELLO_GET_CHECKLISTS_BOARD_BY_ID_CHECKLIST_BY_FIELD: "Action"
    TRELLO_GET_CHECKLISTS_BY_ID_CHECKLIST: "Action"
    TRELLO_GET_CHECKLISTS_BY_ID_CHECKLIST_BY_FIELD: "Action"
    TRELLO_GET_CHECKLISTS_CARDS_BY_ID_CHECKLIST: "Action"
    TRELLO_GET_CHECKLISTS_CARDS_BY_ID_CHECKLIST_BY_FILTER: "Action"
    TRELLO_GET_CHECKLISTS_CHECK_ITEMS_BY_ID_CHECKLIST: "Action"
    TRELLO_GET_CHECKLISTS_CHECK_ITEMS_BY_ID_CHECKLIST_BY_ID_CHECK_ITEM: "Action"
    TRELLO_GET_LABELS_BOARD_BY_ID_LABEL: "Action"
    TRELLO_GET_LABELS_BOARD_BY_ID_LABEL_BY_FIELD: "Action"
    TRELLO_GET_LABELS_BY_ID_LABEL: "Action"
    TRELLO_GET_LISTS_ACTIONS_BY_ID_LIST: "Action"
    TRELLO_GET_LISTS_BOARD_BY_ID_LIST: "Action"
    TRELLO_GET_LISTS_BOARD_BY_ID_LIST_BY_FIELD: "Action"
    TRELLO_GET_LISTS_BY_ID_LIST: "Action"
    TRELLO_GET_LISTS_BY_ID_LIST_BY_FIELD: "Action"
    TRELLO_GET_LISTS_CARDS_BY_ID_LIST: "Action"
    TRELLO_GET_LISTS_CARDS_BY_ID_LIST_BY_FILTER: "Action"
    TRELLO_GET_MEMBERS_ACTIONS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BOARDS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BOARDS_BY_ID_MEMBER_BY_FILTER: "Action"
    TRELLO_GET_MEMBERS_BOARDS_INVITED_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BOARDS_INVITED_BY_ID_MEMBER_BY_FIELD: "Action"
    TRELLO_GET_MEMBERS_BOARD_BACKGROUNDS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BOARD_BACKGROUNDS_BY_ID_MEMBER_BY_ID_BOARD_BACKGROUND: "Action"
    TRELLO_GET_MEMBERS_BOARD_STARS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BOARD_STARS_BY_ID_MEMBER_BY_ID_BOARD_STAR: "Action"
    TRELLO_GET_MEMBERS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_BY_ID_MEMBER_BY_FIELD: "Action"
    TRELLO_GET_MEMBERS_CARDS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_CARDS_BY_ID_MEMBER_BY_FILTER: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_BOARD_BACKGROUNDS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_BOARD_BACKGROUNDS_BY_ID_MEMBER_BY_ID_BOARD_BACKGROUND: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_EMOJI_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_EMOJI_BY_ID_MEMBER_BY_ID_CUSTOM_EMOJI: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_STICKERS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_CUSTOM_STICKERS_BY_ID_MEMBER_BY_ID_CUSTOM_STICKER: "Action"
    TRELLO_GET_MEMBERS_DELTAS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_NOTIFICATIONS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_NOTIFICATIONS_BY_ID_MEMBER_BY_FILTER: "Action"
    TRELLO_GET_MEMBERS_ORGANIZATIONS_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_ORGANIZATIONS_BY_ID_MEMBER_BY_FILTER: "Action"
    TRELLO_GET_MEMBERS_ORGANIZATIONS_INVITED_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_ORGANIZATIONS_INVITED_BY_ID_MEMBER_BY_FIELD: "Action"
    TRELLO_GET_MEMBERS_SAVED_SEARCHES_BY_ID_MEMBER: "Action"
    TRELLO_GET_MEMBERS_SAVED_SEARCHES_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_GET_MEMBERS_TOKENS_BY_ID_MEMBER: "Action"
    TRELLO_GET_NOTIFICATIONS_BOARD_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_BOARD_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_CARD_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_CARD_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_DISPLAY_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_ENTITIES_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_LIST_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_LIST_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_MEMBER_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_MEMBER_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_MEMBER_CREATOR_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_MEMBER_CREATOR_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_NOTIFICATIONS_ORGANIZATION_BY_ID_NOTIFICATION: "Action"
    TRELLO_GET_NOTIFICATIONS_ORGANIZATION_BY_ID_NOTIFICATION_BY_FIELD: "Action"
    TRELLO_GET_ORGANIZATIONS_ACTIONS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_BOARDS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_BOARDS_BY_ID_ORG_BY_FILTER: "Action"
    TRELLO_GET_ORGANIZATIONS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_BY_ID_ORG_BY_FIELD: "Action"
    TRELLO_GET_ORGANIZATIONS_DELTAS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERSHIPS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERSHIPS_BY_ID_ORG_BY_ID_MEMBERSHIP: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERS_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERS_BY_ID_ORG_BY_FILTER: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERS_CARDS_BY_ID_ORG_BY_ID_MEMBER: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERS_INVITED_BY_ID_ORG: "Action"
    TRELLO_GET_ORGANIZATIONS_MEMBERS_INVITED_BY_ID_ORG_BY_FIELD: "Action"
    TRELLO_GET_SEARCH: "Action"
    TRELLO_GET_SEARCH_MEMBERS: "Action"
    TRELLO_GET_SESSIONS_SOCKET: "Action"
    TRELLO_GET_TOKENS_BY_TOKEN: "Action"
    TRELLO_GET_TOKENS_BY_TOKEN_BY_FIELD: "Action"
    TRELLO_GET_TOKENS_MEMBER_BY_TOKEN: "Action"
    TRELLO_GET_TOKENS_MEMBER_BY_TOKEN_BY_FIELD: "Action"
    TRELLO_GET_TOKENS_WEBHOOKS_BY_TOKEN: "Action"
    TRELLO_GET_TOKENS_WEBHOOKS_BY_TOKEN_BY_ID_WEBHOOK: "Action"
    TRELLO_GET_TYPES_BY_ID: "Action"
    TRELLO_GET_WEBHOOKS_BY_ID_WEBHOOK: "Action"
    TRELLO_GET_WEBHOOKS_BY_ID_WEBHOOK_BY_FIELD: "Action"
    TRELLO_LIST_GET_BY_ID_LIST: "Action"
    TRELLO_LIST_ID_BOARD_GET: "Action"
    TRELLO_MEMBER_GET_BOARDS_BY_ID_MEMBER: "Action"
    TRELLO_MEMBER_GET_BY_ID: "Action"
    TRELLO_REMOVE_CHECKLIST_ITEM_FROM_CARD_BY_IDS: "Action"
    TRELLO_REMOVE_SPECIFIC_MEMBER_S_BOARD_BACKGROUNDS: "Action"
    TRELLO_SEARCH_GET_RESULTS: "Action"
    TRELLO_UPDATE_ACTIONS_BY_ID_ACTION: "Action"
    TRELLO_UPDATE_ACTIONS_TEXT_BY_ID_ACTION: "Action"
    TRELLO_UPDATE_BOARDS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_CLOSED_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_DESC_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_ID_ORGANIZATION_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_BLUE_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_GREEN_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_ORANGE_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_PURPLE_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_RED_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_LABEL_NAMES_YELLOW_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MEMBERSHIPS_BY_ID_BOARD_BY_ID_MEMBERSHIP: "Action"
    TRELLO_UPDATE_BOARDS_MEMBERS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MEMBERS_BY_ID_BOARD_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_EMAIL_POSITION_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_ID_EMAIL_LIST_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_SHOW_LIST_GUIDE_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_SHOW_SIDEBAR_ACTIVITY_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_SHOW_SIDEBAR_BOARD_ACTIONS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_SHOW_SIDEBAR_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_MY_PREFS_SHOW_SIDEBAR_MEMBERS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_NAME_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_BACKGROUND_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_CALENDAR_FEED_ENABLED_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_CARD_AGING_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_CARD_COVERS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_COMMENTS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_INVITATIONS_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_PERMISSION_LEVEL_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_SELF_JOIN_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_PREFS_VOTING_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_BOARDS_SUBSCRIBED_BY_ID_BOARD: "Action"
    TRELLO_UPDATE_CARDS_ACTIONS_COMMENTS_BY_ID_CARD_BY_ID_ACTION: "Action"
    TRELLO_UPDATE_CARDS_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_CLOSED_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_DESC_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_DUE_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_ID_ATTACHMENT_COVER_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_ID_BOARD_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_ID_LIST_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_ID_MEMBERS_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_LABELS_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_NAME_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_POS_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARDS_STICKERS_BY_ID_CARD_BY_ID_STICKER: "Action"
    TRELLO_UPDATE_CARDS_SUBSCRIBED_BY_ID_CARD: "Action"
    TRELLO_UPDATE_CARD_CHECKLIST_ITEM_POSITION: "Action"
    TRELLO_UPDATE_CARD_CHECKLIST_ITEM_STATE_BY_IDS: "Action"
    TRELLO_UPDATE_CHECKLISTS_BY_ID_CHECKLIST: "Action"
    TRELLO_UPDATE_CHECKLISTS_ID_CARD_BY_ID_CHECKLIST: "Action"
    TRELLO_UPDATE_CHECKLISTS_NAME_BY_ID_CHECKLIST: "Action"
    TRELLO_UPDATE_CHECKLISTS_POS_BY_ID_CHECKLIST: "Action"
    TRELLO_UPDATE_CHECKLIST_ITEM_BY_IDS: "Action"
    TRELLO_UPDATE_CHECKLIST_ITEM_NAME_IN_CARD: "Action"
    TRELLO_UPDATE_LABELS_BY_ID_LABEL: "Action"
    TRELLO_UPDATE_LABELS_COLOR_BY_ID_LABEL: "Action"
    TRELLO_UPDATE_LABELS_NAME_BY_ID_LABEL: "Action"
    TRELLO_UPDATE_LISTS_BY_ID_LIST: "Action"
    TRELLO_UPDATE_LISTS_CLOSED_BY_ID_LIST: "Action"
    TRELLO_UPDATE_LISTS_ID_BOARD_BY_ID_LIST: "Action"
    TRELLO_UPDATE_LISTS_NAME_BY_ID_LIST: "Action"
    TRELLO_UPDATE_LISTS_POS_BY_ID_LIST: "Action"
    TRELLO_UPDATE_LISTS_SUBSCRIBED_BY_ID_LIST: "Action"
    TRELLO_UPDATE_MEMBERS_AVATAR_SOURCE_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_BIO_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_BOARD_BACKGROUNDS_BY_ID_MEMBER_BY_ID_BOARD_BACKGROUND: "Action"
    TRELLO_UPDATE_MEMBERS_BOARD_STARS_BY_ID_MEMBER_BY_ID_BOARD_STAR: "Action"
    TRELLO_UPDATE_MEMBERS_BOARD_STARS_ID_BOARD_BY_ID_MEMBER_BY_ID_BOARD_STAR: "Action"
    TRELLO_UPDATE_MEMBERS_BOARD_STARS_POS_BY_ID_MEMBER_BY_ID_BOARD_STAR: "Action"
    TRELLO_UPDATE_MEMBERS_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_FULL_NAME_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_INITIALS_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_PREFS_COLOR_BLIND_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_PREFS_LOCALE_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_PREFS_MINUTES_BETWEEN_SUMMARIES_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBERS_SAVED_SEARCHES_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_UPDATE_MEMBERS_SAVED_SEARCHES_NAME_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_UPDATE_MEMBERS_SAVED_SEARCHES_POS_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_UPDATE_MEMBERS_SAVED_SEARCHES_QUERY_BY_ID_MEMBER_BY_ID_SAVED_SEARCH: "Action"
    TRELLO_UPDATE_MEMBERS_USERNAME_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_MEMBER_S_CUSTOM_BOARD_BACKGROUNDS: "Action"
    TRELLO_UPDATE_NOTIFICATIONS_BY_ID_NOTIFICATION: "Action"
    TRELLO_UPDATE_NOTIFICATIONS_UNREAD_BY_ID_NOTIFICATION: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_DESC_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_DISPLAY_NAME_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_MEMBERSHIPS_BY_ID_ORG_BY_ID_MEMBERSHIP: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_MEMBERS_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_MEMBERS_BY_ID_ORG_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_MEMBERS_DEACTIVATED_BY_ID_ORG_BY_ID_MEMBER: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_NAME_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_ASSOCIATED_DOMAIN_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_BOARD_VISIBILITY_RESTRICT_ORG_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_BOARD_VISIBILITY_RESTRICT_PRIVATE_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_BOARD_VISIBILITY_RESTRICT_PUBLIC_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_EXTERNAL_MEMBERS_DISABLED_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_GOOGLE_APPS_VERSION_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_ORG_INVITE_RESTRICT_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_PREFS_PERMISSION_LEVEL_BY_ID_ORG: "Action"
    TRELLO_UPDATE_ORGANIZATIONS_WEBSITE_BY_ID_ORG: "Action"
    TRELLO_UPDATE_SESSIONS_BY_ID_SESSION: "Action"
    TRELLO_UPDATE_SESSIONS_STATUS_BY_ID_SESSION: "Action"
    TRELLO_UPDATE_TOKENS_WEBHOOKS_BY_TOKEN: "Action"
    TRELLO_UPDATE_WEBHOOKS: "Action"
    TRELLO_UPDATE_WEBHOOKS_ACTIVE_BY_ID_WEBHOOK: "Action"
    TRELLO_UPDATE_WEBHOOKS_BY_ID_WEBHOOK: "Action"
    TRELLO_UPDATE_WEBHOOKS_CALLBACK_URLBY_ID_WEBHOOK: "Action"
    TRELLO_UPDATE_WEBHOOKS_DESCRIPTION_BY_ID_WEBHOOK: "Action"
    TRELLO_UPDATE_WEBHOOKS_ID_MODEL_BY_ID_WEBHOOK: "Action"
    TWILIO_SEND_SMS: "Action"
    TWILIO_SEND_WHATS_APP_MESSAGE: "Action"
    TYPEFORM_GET_ABOUT_ME: "Action"
    WEATHERMAP_WEATHER: "Action"
    WEBTOOL_SCRAPE_WEBSITE_CONTENT: "Action"
    WEBTOOL_SCRAPE_WEBSITE_ELEMENT: "Action"
    WHATSAPP_BACKUP_SETTINGS: "Action"
    WHATSAPP_CHECK_CONTACT: "Action"
    WHATSAPP_CHECK_HEALTH: "Action"
    WHATSAPP_CREATE_GROUP: "Action"
    WHATSAPP_CREATE_USER: "Action"
    WHATSAPP_DELETE_GROUP_ICON: "Action"
    WHATSAPP_DELETE_GROUP_INVITE: "Action"
    WHATSAPP_DELETE_MEDIA: "Action"
    WHATSAPP_DELETE_MEDIA_PROVIDERS: "Action"
    WHATSAPP_DELETE_PROFILE_PHOTO: "Action"
    WHATSAPP_DELETE_USER: "Action"
    WHATSAPP_DELETE_WEBHOOK_CA_CERTIFICATE: "Action"
    WHATSAPP_DEMOTE_GROUP_ADMIN: "Action"
    WHATSAPP_DISABLE_TWO_STEP: "Action"
    WHATSAPP_DOWNLOAD_CA_CERTIFICATE: "Action"
    WHATSAPP_DOWNLOAD_MEDIA: "Action"
    WHATSAPP_DOWNLOAD_WEBHOOK_CA_CERTIFICATE: "Action"
    WHATSAPP_ENABLE_TWO_STEP: "Action"
    WHATSAPP_GET_ALL_GROUPS: "Action"
    WHATSAPP_GET_APPLICATION_SETTINGS: "Action"
    WHATSAPP_GET_APP_STATS: "Action"
    WHATSAPP_GET_BUSINESS_PROFILE: "Action"
    WHATSAPP_GET_DB_STATS: "Action"
    WHATSAPP_GET_GROUP_ICON_BINARY: "Action"
    WHATSAPP_GET_GROUP_INFO: "Action"
    WHATSAPP_GET_GROUP_INVITE: "Action"
    WHATSAPP_GET_MEDIA_PROVIDERS: "Action"
    WHATSAPP_GET_METRICS_SINCE_V2213: "Action"
    WHATSAPP_GET_PROFILE_ABOUT: "Action"
    WHATSAPP_GET_PROFILE_PHOTO: "Action"
    WHATSAPP_GET_SUPPORT_INFO: "Action"
    WHATSAPP_GET_USER: "Action"
    WHATSAPP_LEAVE_GROUP: "Action"
    WHATSAPP_LOGIN_USER: "Action"
    WHATSAPP_LOGOUT_USER: "Action"
    WHATSAPP_MARK_MESSAGE_AS_READ: "Action"
    WHATSAPP_PROMOTE_TO_GROUP_ADMIN: "Action"
    WHATSAPP_REGISTER_ACCOUNT: "Action"
    WHATSAPP_REMOVE_GROUP_PARTICIPANT: "Action"
    WHATSAPP_REQUEST_CODE: "Action"
    WHATSAPP_RESET_APPLICATION_SETTINGS: "Action"
    WHATSAPP_RESTORE_SETTINGS: "Action"
    WHATSAPP_SEND_MESSAGE: "Action"
    WHATSAPP_SET_GROUP_ICON: "Action"
    WHATSAPP_SET_SHARDS: "Action"
    WHATSAPP_UPDATE_APPLICATION_SETTINGS: "Action"
    WHATSAPP_UPDATE_BUSINESS_PROFILE: "Action"
    WHATSAPP_UPDATE_GROUP_INFO: "Action"
    WHATSAPP_UPDATE_PROFILE_ABOUT: "Action"
    WHATSAPP_UPDATE_PROFILE_PHOTO: "Action"
    WHATSAPP_UPDATE_USER: "Action"
    WHATSAPP_UPLOAD_CERTIFICATE: "Action"
    WHATSAPP_UPLOAD_MEDIA: "Action"
    WHATSAPP_UPLOAD_WEBHOOK_CA_CERTIFICATE: "Action"
    WORKABLE_GET_ACCOUNT_DEPARTMENT_ACTION: "Action"
    WORKABLE_GET_EXTERNAL_RECRUITER_LIST_ACTION: "Action"
    WORKABLE_GET_LEGAL_ENTITIES_ACTION: "Action"
    WORKABLE_GET_MEMBERS_LIST_ACTION: "Action"
    WORKABLE_GET_REQUIREMENT_PIPELINE_STAGE_ACTION: "Action"
    WORKABLE_GET_SPECIFIC_ACCOUNT_ACTION: "Action"
    WORKABLE_WORKABLE_ACCOUNT_ACCESS_ACTION: "Action"
    YOUSEARCH_SEARCH: "Action"
    YOUTUBE_LIST_CAPTION_TRACK: "Action"
    YOUTUBE_LIST_CHANNEL_VIDEOS: "Action"
    YOUTUBE_LIST_USER_PLAYLISTS: "Action"
    YOUTUBE_LIST_USER_SUBSCRIPTIONS: "Action"
    YOUTUBE_LOAD_CAPTIONS: "Action"
    YOUTUBE_SEARCH_YOU_TUBE: "Action"
    YOUTUBE_SUBSCRIBE_CHANNEL: "Action"
    YOUTUBE_UPDATE_THUMBNAIL: "Action"
    YOUTUBE_UPDATE_VIDEO: "Action"
    YOUTUBE_VIDEO_DETAILS: "Action"
    ZENDESK_COUNT_ZENDESK_ORGANIZATIONS: "Action"
    ZENDESK_CREATE_ZENDESK_ORGANIZATION: "Action"
    ZENDESK_CREATE_ZENDESK_TICKET: "Action"
    ZENDESK_DELETE_ZENDESK_ORGANIZATION: "Action"
    ZENDESK_DELETE_ZENDESK_TICKET: "Action"
    ZENDESK_GET_ABOUT_ME: "Action"
    ZENDESK_GET_ALL_ZENDESK_ORGANIZATIONS: "Action"
    ZENDESK_GET_ZENDESK_ORGANIZATION: "Action"
    ZENDESK_UPDATE_ZENDESK_ORGANIZATION: "Action"
    ZEPTOOL_ADD_MEMORY: "Action"
    ZEPTOOL_CREATE_SESSION: "Action"
    ZEPTOOL_GET_MEMORY: "Action"
    ZEPTOOL_SEARCH_MEMORY: "Action"
    ZOOM_ADD_A_MEETING_REGISTRANT: "Action"
    ZOOM_ADD_A_NEW_DEVICE: "Action"
    ZOOM_ADD_A_USER_S_TSP_ACCOUNT: "Action"
    ZOOM_ADD_A_WEBINAR_REGISTRANT: "Action"
    ZOOM_ADD_PANELISTS: "Action"
    ZOOM_ASSIGN_A_DEVICE_TO_A_USER_OR_COMMONAREA: "Action"
    ZOOM_CHANGE_DEVICE: "Action"
    ZOOM_CHANGE_DEVICE_ASSOCIATION: "Action"
    ZOOM_CREATE_AH323_SIP_DEVICE: "Action"
    ZOOM_CREATE_A_MEETING: "Action"
    ZOOM_CREATE_A_MEETING_POLL: "Action"
    ZOOM_CREATE_A_MEETING_TEMPLATE_FROM_AN_EXISTING_MEETING: "Action"
    ZOOM_CREATE_A_RECORDING_REGISTRANT: "Action"
    ZOOM_CREATE_A_TRACKING_FIELD: "Action"
    ZOOM_CREATE_A_WEBINAR: "Action"
    ZOOM_CREATE_A_WEBINAR_S_BRANDING_NAME_TAG: "Action"
    ZOOM_CREATE_A_WEBINAR_S_POLL: "Action"
    ZOOM_CREATE_A_WEBINAR_TEMPLATE: "Action"
    ZOOM_CREATE_MEETING_S_INVITE_LINKS: "Action"
    ZOOM_CREATE_WEBINAR_S_INVITE_LINKS: "Action"
    ZOOM_DELETE_AH323_SIP_DEVICE: "Action"
    ZOOM_DELETE_A_LIVE_MEETING_MESSAGE: "Action"
    ZOOM_DELETE_A_LIVE_WEBINAR_MESSAGE: "Action"
    ZOOM_DELETE_A_MEETING: "Action"
    ZOOM_DELETE_A_MEETING_POLL: "Action"
    ZOOM_DELETE_A_MEETING_RECORDING_FILE: "Action"
    ZOOM_DELETE_A_MEETING_REGISTRANT: "Action"
    ZOOM_DELETE_A_MEETING_SURVEY: "Action"
    ZOOM_DELETE_A_MEETING_S_ARCHIVED_FILES: "Action"
    ZOOM_DELETE_A_TRACKING_FIELD: "Action"
    ZOOM_DELETE_A_USER_S_TSP_ACCOUNT: "Action"
    ZOOM_DELETE_A_WEBINAR: "Action"
    ZOOM_DELETE_A_WEBINAR_POLL: "Action"
    ZOOM_DELETE_A_WEBINAR_REGISTRANT: "Action"
    ZOOM_DELETE_A_WEBINAR_SURVEY: "Action"
    ZOOM_DELETE_A_WEBINAR_S_BRANDING_NAME_TAG: "Action"
    ZOOM_DELETE_A_WEBINAR_S_BRANDING_VIRTUAL_BACKGROUNDS: "Action"
    ZOOM_DELETE_A_WEBINAR_S_BRANDING_WALLPAPER: "Action"
    ZOOM_DELETE_DEVICE: "Action"
    ZOOM_DELETE_MEETING_RECORDINGS: "Action"
    ZOOM_DELETE_SIP_PHONE: "Action"
    ZOOM_DELETE_ZPA_DEVICE_BY_VENDOR_AND_MAC_ADDRESS: "Action"
    ZOOM_ENABLE_SIP_PHONE: "Action"
    ZOOM_GET_ACCOUNT_S_TSP_INFORMATION: "Action"
    ZOOM_GET_ACTIVE_INACTIVE_HOST_REPORTS: "Action"
    ZOOM_GET_ARCHIVED_FILE_STATISTICS: "Action"
    ZOOM_GET_A_MEETING: "Action"
    ZOOM_GET_A_MEETING_POLL: "Action"
    ZOOM_GET_A_MEETING_REGISTRANT: "Action"
    ZOOM_GET_A_MEETING_SIP_URI_WITH_PASSCODE: "Action"
    ZOOM_GET_A_MEETING_SUMMARY: "Action"
    ZOOM_GET_A_MEETING_SURVEY: "Action"
    ZOOM_GET_A_MEETING_S_ARCHIVED_FILES: "Action"
    ZOOM_GET_A_MEETING_S_ARCHIVE_TOKEN_FOR_LOCAL_ARCHIVING: "Action"
    ZOOM_GET_A_MEETING_S_JOIN_TOKEN_FOR_LIVE_STREAMING: "Action"
    ZOOM_GET_A_MEETING_S_JOIN_TOKEN_FOR_LOCAL_RECORDING: "Action"
    ZOOM_GET_A_TRACKING_FIELD: "Action"
    ZOOM_GET_A_USER_S_TSP_ACCOUNT: "Action"
    ZOOM_GET_A_WEBINAR: "Action"
    ZOOM_GET_A_WEBINAR_POLL: "Action"
    ZOOM_GET_A_WEBINAR_REGISTRANT: "Action"
    ZOOM_GET_A_WEBINAR_SIP_URI_WITH_PASSCODE: "Action"
    ZOOM_GET_A_WEBINAR_SURVEY: "Action"
    ZOOM_GET_A_WEBINAR_S_ARCHIVE_TOKEN_FOR_LOCAL_ARCHIVING: "Action"
    ZOOM_GET_A_WEBINAR_S_JOIN_TOKEN_FOR_LIVE_STREAMING: "Action"
    ZOOM_GET_A_WEBINAR_S_JOIN_TOKEN_FOR_LOCAL_RECORDING: "Action"
    ZOOM_GET_BILLING_INVOICE_REPORTS: "Action"
    ZOOM_GET_BILLING_REPORTS: "Action"
    ZOOM_GET_CLOUD_RECORDING_USAGE_REPORT: "Action"
    ZOOM_GET_DAILY_USAGE_REPORT: "Action"
    ZOOM_GET_DEVICE_DETAIL: "Action"
    ZOOM_GET_LIVESTREAM_DETAILS: "Action"
    ZOOM_GET_LIVE_STREAM_DETAILS: "Action"
    ZOOM_GET_MEETING_DETAIL_REPORTS: "Action"
    ZOOM_GET_MEETING_INVITATION: "Action"
    ZOOM_GET_MEETING_PARTICIPANT_REPORTS: "Action"
    ZOOM_GET_MEETING_POLL_REPORTS: "Action"
    ZOOM_GET_MEETING_QA_REPORT: "Action"
    ZOOM_GET_MEETING_RECORDINGS: "Action"
    ZOOM_GET_MEETING_RECORDING_SETTINGS: "Action"
    ZOOM_GET_MEETING_RECORDING_S_ANALYTICS_DETAILS: "Action"
    ZOOM_GET_MEETING_RECORDING_S_ANALYTICS_SUMMARY: "Action"
    ZOOM_GET_MEETING_REPORTS: "Action"
    ZOOM_GET_MEETING_SURVEY_REPORT: "Action"
    ZOOM_GET_MEETING_S_TOKEN: "Action"
    ZOOM_GET_OPERATION_LOGS_REPORT: "Action"
    ZOOM_GET_PAST_MEETING_DETAILS: "Action"
    ZOOM_GET_PAST_MEETING_PARTICIPANTS: "Action"
    ZOOM_GET_REGISTRATION_QUESTIONS: "Action"
    ZOOM_GET_SIGN_IN_SIGN_OUT_ACTIVITY_REPORT: "Action"
    ZOOM_GET_TELEPHONE_REPORTS: "Action"
    ZOOM_GET_UPCOMING_EVENTS_REPORT: "Action"
    ZOOM_GET_WEBINAR_ABSENTEES: "Action"
    ZOOM_GET_WEBINAR_DETAIL_REPORTS: "Action"
    ZOOM_GET_WEBINAR_PARTICIPANT_REPORTS: "Action"
    ZOOM_GET_WEBINAR_POLL_REPORTS: "Action"
    ZOOM_GET_WEBINAR_QA_REPORT: "Action"
    ZOOM_GET_WEBINAR_SURVEY_REPORT: "Action"
    ZOOM_GET_WEBINAR_S_SESSION_BRANDING: "Action"
    ZOOM_GET_WEBINAR_S_TOKEN: "Action"
    ZOOM_GET_WEBINAR_TRACKING_SOURCES: "Action"
    ZOOM_GET_ZDM_GROUP_INFO: "Action"
    ZOOM_GET_ZPA_VERSION_INFO: "Action"
    ZOOM_LIST_ALL_RECORDINGS: "Action"
    ZOOM_LIST_ARCHIVED_FILES: "Action"
    ZOOM_LIST_A_USER_S_PAC_ACCOUNTS: "Action"
    ZOOM_LIST_A_WEBINAR_S_POLLS: "Action"
    ZOOM_LIST_DEVICES: "Action"
    ZOOM_LIST_H323_SIP_DEVICES: "Action"
    ZOOM_LIST_MEETINGS: "Action"
    ZOOM_LIST_MEETING_POLLS: "Action"
    ZOOM_LIST_MEETING_REGISTRANTS: "Action"
    ZOOM_LIST_MEETING_SUMMARIES_OF_AN_ACCOUNT: "Action"
    ZOOM_LIST_MEETING_TEMPLATES: "Action"
    ZOOM_LIST_PANELISTS: "Action"
    ZOOM_LIST_PAST_MEETINGS_QA: "Action"
    ZOOM_LIST_PAST_MEETING_INSTANCES: "Action"
    ZOOM_LIST_PAST_MEETING_S_POLL_RESULTS: "Action"
    ZOOM_LIST_PAST_WEBINAR_INSTANCES: "Action"
    ZOOM_LIST_PAST_WEBINAR_POLL_RESULTS: "Action"
    ZOOM_LIST_Q_AS_OF_A_PAST_WEBINAR: "Action"
    ZOOM_LIST_RECORDING_REGISTRANTS: "Action"
    ZOOM_LIST_REGISTRATION_QUESTIONS_FOR_MEETING: "Action"
    ZOOM_LIST_REGISTRATION_QUESTIONS_FOR_WEBINAR: "Action"
    ZOOM_LIST_SIP_PHONES: "Action"
    ZOOM_LIST_TRACKING_FIELDS: "Action"
    ZOOM_LIST_UPCOMING_MEETINGS: "Action"
    ZOOM_LIST_USER_S_TSP_ACCOUNTS: "Action"
    ZOOM_LIST_WEBINARS: "Action"
    ZOOM_LIST_WEBINAR_PARTICIPANTS: "Action"
    ZOOM_LIST_WEBINAR_REGISTRANTS: "Action"
    ZOOM_LIST_WEBINAR_TEMPLATES: "Action"
    ZOOM_PERFORM_BATCH_POLL_CREATION: "Action"
    ZOOM_PERFORM_BATCH_REGISTRATION: "Action"
    ZOOM_RECOVER_A_SINGLE_RECORDING: "Action"
    ZOOM_RECOVER_MEETING_RECORDINGS: "Action"
    ZOOM_REMOVE_A_PANELIST: "Action"
    ZOOM_REMOVE_WEBINAR_PANELISTS: "Action"
    ZOOM_SCHEDULE_USER_WEBINAR_WITH_REGISTRATION: "Action"
    ZOOM_SET_GLOBAL_DIAL_IN_URL_FOR_A_TSP_USER: "Action"
    ZOOM_SET_WEBINAR_S_DEFAULT_BRANDING_VIRTUAL_BACKGROUND: "Action"
    ZOOM_UPDATE_ACCOUNT_S_TSP_INFORMATION: "Action"
    ZOOM_UPDATE_AH323_SIP_DEVICE: "Action"
    ZOOM_UPDATE_AN_ARCHIVED_FILE_S_AUTO_DELETE_STATUS: "Action"
    ZOOM_UPDATE_A_LIVESTREAM: "Action"
    ZOOM_UPDATE_A_LIVE_MEETING_MESSAGE: "Action"
    ZOOM_UPDATE_A_LIVE_STREAM: "Action"
    ZOOM_UPDATE_A_MEETING: "Action"
    ZOOM_UPDATE_A_MEETING_POLL: "Action"
    ZOOM_UPDATE_A_MEETING_SURVEY: "Action"
    ZOOM_UPDATE_A_TRACKING_FIELD: "Action"
    ZOOM_UPDATE_A_TSP_ACCOUNT: "Action"
    ZOOM_UPDATE_A_WEBINAR: "Action"
    ZOOM_UPDATE_A_WEBINAR_POLL: "Action"
    ZOOM_UPDATE_A_WEBINAR_SURVEY: "Action"
    ZOOM_UPDATE_A_WEBINAR_S_BRANDING_NAME_TAG: "Action"
    ZOOM_UPDATE_LIVESTREAM_STATUS: "Action"
    ZOOM_UPDATE_LIVE_STREAM_STATUS: "Action"
    ZOOM_UPDATE_MEETING_RECORDING_SETTINGS: "Action"
    ZOOM_UPDATE_MEETING_REGISTRANT_STATUS: "Action"
    ZOOM_UPDATE_MEETING_STATUS: "Action"
    ZOOM_UPDATE_REGISTRANT_S_STATUS: "Action"
    ZOOM_UPDATE_REGISTRATION_QUESTIONS: "Action"
    ZOOM_UPDATE_SIP_PHONE: "Action"
    ZOOM_UPDATE_WEBINAR_REGISTRANT_STATUS: "Action"
    ZOOM_UPDATE_WEBINAR_REGISTRATION_FIELDS: "Action"
    ZOOM_UPDATE_WEBINAR_STATUS: "Action"
    ZOOM_UPDATE_ZOOM_MEETING_REGISTRATION_QUESTIONS: "Action"
    ZOOM_UPGRADE_ZPA_OS_APP: "Action"
    ZOOM_UPLOAD_A_WEBINAR_S_BRANDING_VIRTUAL_BACKGROUND: "Action"
    ZOOM_UPLOAD_A_WEBINAR_S_BRANDING_WALLPAPER: "Action"
    ZOOM_USE_IN_MEETING_CONTROLS: "Action"

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_CREATE_TASK_ATTACHMENT instead.")
    def CLICKUP_ATTACHMENTS_UPLOAD_FILE_TO_TASK_AS_ATTACHMENT(cls) -> "Action":
        return cls.CLICKUP_CREATE_TASK_ATTACHMENT

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_ACCESS_TOKEN instead.")
    def CLICKUP_AUTHORIZATION_GET_ACCESS_TOKEN(cls) -> "Action":
        return cls.CLICKUP_GET_ACCESS_TOKEN

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_CREATE_FOLDER instead.")
    def CLICKUP_FOLDERS_CREATE_NEW_FOLDER(cls) -> "Action":
        return cls.CLICKUP_CREATE_FOLDER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_FOLDERS instead.")
    def CLICKUP_FOLDERS_GET_CONTENTS_OF(cls) -> "Action":
        return cls.CLICKUP_GET_FOLDERS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_FOLDER instead.")
    def CLICKUP_FOLDERS_GET_FOLDER_CONTENT(cls) -> "Action":
        return cls.CLICKUP_GET_FOLDER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_LISTS instead.")
    def CLICKUP_LISTS_GET_FOLDER_LISTS(cls) -> "Action":
        return cls.CLICKUP_GET_LISTS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_LIST_MEMBERS instead.")
    def CLICKUP_MEMBERS_GET_LIST_USERS(cls) -> "Action":
        return cls.CLICKUP_GET_LIST_MEMBERS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_SPACE instead.")
    def CLICKUP_SPACES_GET_DETAILS(cls) -> "Action":
        return cls.CLICKUP_GET_SPACE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_SPACES instead.")
    def CLICKUP_SPACES_GET_SPACE_DETAILS(cls) -> "Action":
        return cls.CLICKUP_GET_SPACES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_CREATE_CHECKLIST instead.")
    def CLICKUP_TASK_CHECKLISTS_CREATE_NEW_CHECKLIST(cls) -> "Action":
        return cls.CLICKUP_CREATE_CHECKLIST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_TASKS instead.")
    def CLICKUP_TASKS_GET_LIST_TASKS(cls) -> "Action":
        return cls.CLICKUP_GET_TASKS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_CREATE_TEAM instead.")
    def CLICKUP_TEAMS_USER_GROUPS_CREATE_TEAM(cls) -> "Action":
        return cls.CLICKUP_CREATE_TEAM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use CLICKUP_GET_SPACE_VIEWS instead.")
    def CLICKUP_VIEWS_SPACE_VIEWS_GET(cls) -> "Action":
        return cls.CLICKUP_GET_SPACE_VIEWS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use DISCORD_CREATE_GUILD instead.")
    def DISCORD_CREATEGUILD(cls) -> "Action":
        return cls.DISCORD_CREATE_GUILD

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use DISCORD_GET_MESSAGE instead.")
    def DISCORD_GETMESSAGE(cls) -> "Action":
        return cls.DISCORD_GET_MESSAGE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use DISCORD_GET_MY_APPLICATION instead.")
    def DISCORD_GETMYAPPLICATION(cls) -> "Action":
        return cls.DISCORD_GET_MY_APPLICATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use DISCORD_GET_MY_USER instead.")
    def DISCORD_GETMYUSER(cls) -> "Action":
        return cls.DISCORD_GET_MY_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIO_FILE instead.")
    def ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIOFILE_V_1_DUBBING_POST(cls) -> "Action":
        return cls.ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIO_FILE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use ELEVENLABS_GET_MODELS instead.")
    def ELEVENLABS_GET_MODELS_V_1_MODELS_GET(cls) -> "Action":
        return cls.ELEVENLABS_GET_MODELS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use ELEVENLABS_GET_USER_INFO instead.")
    def ELEVENLABS_GET_USER_INFO_V_1_USER_GET(cls) -> "Action":
        return cls.ELEVENLABS_GET_USER_INFO

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use ELEVENLABS_GET_VOICES instead.")
    def ELEVENLABS_GET_VOICES_V_1_VOICES_GET(cls) -> "Action":
        return cls.ELEVENLABS_GET_VOICES

    @classmethod  # type: ignore
    @property
    @te.deprecated(
        "Use GITHUB_LIST_REPOSITORIES_STARRED_BY_THE_AUTHENTICATED_USER instead."
    )
    def GITHUB_ACTIVITY_LIST_REPO_S_STARRED_BY_AUTHENTICATED_USER(cls) -> "Action":
        return cls.GITHUB_LIST_REPOSITORIES_STARRED_BY_THE_AUTHENTICATED_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_EMOJIS instead.")
    def GITHUB_EMO_J_IS_GET(cls) -> "Action":
        return cls.GITHUB_GET_EMOJIS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_A_GIST instead.")
    def GITHUB_GIST_S_CREATE(cls) -> "Action":
        return cls.GITHUB_CREATE_A_GIST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_PUBLIC_GISTS instead.")
    def GITHUB_GIST_S_LIST_PUBLIC(cls) -> "Action":
        return cls.GITHUB_LIST_PUBLIC_GISTS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_AN_ISSUE instead.")
    def GITHUB_ISSUES_CREATE(cls) -> "Action":
        return cls.GITHUB_CREATE_AN_ISSUE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_AN_ISSUE_COMMENT instead.")
    def GITHUB_ISSUES_CREATE_COMMENT(cls) -> "Action":
        return cls.GITHUB_CREATE_AN_ISSUE_COMMENT

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_AN_ISSUE instead.")
    def GITHUB_ISSUES_GET(cls) -> "Action":
        return cls.GITHUB_GET_AN_ISSUE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER instead.")
    def GITHUB_ISSUES_LIST(cls) -> "Action":
        return cls.GITHUB_LIST_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_ASSIGNEES instead.")
    def GITHUB_ISSUES_LIST_ASSIGN_EES(cls) -> "Action":
        return cls.GITHUB_LIST_ASSIGNEES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_ISSUE_EVENTS_FOR_A_REPOSITORY instead.")
    def GITHUB_ISSUES_LIST_EVENTS_FOR_REPO(cls) -> "Action":
        return cls.GITHUB_LIST_ISSUE_EVENTS_FOR_A_REPOSITORY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CHECK_IF_A_PULL_REQUEST_HAS_BEEN_MERGED instead.")
    def GITHUB_PULLS_CHECK_IF_MERGED(cls) -> "Action":
        return cls.GITHUB_CHECK_IF_A_PULL_REQUEST_HAS_BEEN_MERGED

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_A_PULL_REQUEST instead.")
    def GITHUB_PULLS_GET(cls) -> "Action":
        return cls.GITHUB_GET_A_PULL_REQUEST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_A_FORK instead.")
    def GITHUB_REPO_S_CREATE_FORK(cls) -> "Action":
        return cls.GITHUB_CREATE_A_FORK

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_AN_ORGANIZATION_REPOSITORY instead.")
    def GITHUB_REPO_S_CREATE_IN_ORG(cls) -> "Action":
        return cls.GITHUB_CREATE_AN_ORGANIZATION_REPOSITORY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_CREATE_OR_UPDATE_FILE_CONTENTS instead.")
    def GITHUB_REPO_S_CREATE_OR_UPDATE_FILE_CONTENTS(cls) -> "Action":
        return cls.GITHUB_CREATE_OR_UPDATE_FILE_CONTENTS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_THE_WEEKLY_COMMIT_ACTIVITY instead.")
    def GITHUB_REPO_S_GET_CODE_FREQUENCY_STATS(cls) -> "Action":
        return cls.GITHUB_GET_THE_WEEKLY_COMMIT_ACTIVITY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY instead.")
    def GITHUB_REPO_S_GET_CONTRIBUTORS_STATS(cls) -> "Action":
        return cls.GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_BRANCHES instead.")
    def GITHUB_REPO_S_LIST_BRANCHES(cls) -> "Action":
        return cls.GITHUB_LIST_BRANCHES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_REPOSITORY_COLLABORATORS instead.")
    def GITHUB_REPO_S_LIST_COLLABORATORS(cls) -> "Action":
        return cls.GITHUB_LIST_REPOSITORY_COLLABORATORS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_COMMITS instead.")
    def GITHUB_REPO_S_LIST_COMMITS(cls) -> "Action":
        return cls.GITHUB_LIST_COMMITS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_REPOSITORY_CONTRIBUTORS instead.")
    def GITHUB_REPO_S_LIST_CONTRIBUTORS(cls) -> "Action":
        return cls.GITHUB_LIST_REPOSITORY_CONTRIBUTORS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_REPOSITORIES_FOR_THE_AUTHENTICATED_USER instead.")
    def GITHUB_REPO_S_LIST_FOR_AUTHENTICATED_USER(cls) -> "Action":
        return cls.GITHUB_LIST_REPOSITORIES_FOR_THE_AUTHENTICATED_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_REPOSITORIES_FOR_A_USER instead.")
    def GITHUB_REPO_S_LIST_FOR_USER(cls) -> "Action":
        return cls.GITHUB_LIST_REPOSITORIES_FOR_A_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_GLOBAL_SECURITY_ADVISORIES instead.")
    def GITHUB_SECURITY_ADVISORIES_LIST_GLOBAL_ADVISORIES(cls) -> "Action":
        return cls.GITHUB_LIST_GLOBAL_SECURITY_ADVISORIES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_GET_CONTEXTUAL_INFORMATION_FOR_A_USER instead.")
    def GITHUB_USERS_GET_CONTEXT_FOR_USER(cls) -> "Action":
        return cls.GITHUB_GET_CONTEXTUAL_INFORMATION_FOR_A_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated(
        "Use GITHUB_LIST_EMAIL_ADDRESSES_FOR_THE_AUTHENTICATED_USER instead."
    )
    def GITHUB_USERS_LIST_EMAILS_FOR_AUTHENTICATED_USER(cls) -> "Action":
        return cls.GITHUB_LIST_EMAIL_ADDRESSES_FOR_THE_AUTHENTICATED_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use GITHUB_LIST_FOLLOWERS_OF_THE_AUTHENTICATED_USER instead.")
    def GITHUB_USERS_LIST_FOLLOWERS_FOR_AUTHENTICATED_USER(cls) -> "Action":
        return cls.GITHUB_LIST_FOLLOWERS_OF_THE_AUTHENTICATED_USER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use NASA_GET_ORGANIZATION_DETAILS_AND_INFO instead.")
    def NASA_ORGANIZATION_GET_INFORMATION(cls) -> "Action":
        return cls.NASA_GET_ORGANIZATION_DETAILS_AND_INFO

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use NASA_LIST_AVAILABLE_ORGANIZATION_TYPES instead.")
    def NASA_ORGANIZATION_LIST_TYPES(cls) -> "Action":
        return cls.NASA_LIST_AVAILABLE_ORGANIZATION_TYPES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use NASA_FIND_PROJECTS_MATCHING_SEARCH_TERMS instead.")
    def NASA_PROJECT_FIND_MATCHING_PROJECTS(cls) -> "Action":
        return cls.NASA_FIND_PROJECTS_MATCHING_SEARCH_TERMS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use NASA_LIST_AVAILABLE_TECHNOLOGY_PROJECT_IDS instead.")
    def NASA_PROJECT_LIST_AVAILABLE_IDS(cls) -> "Action":
        return cls.NASA_LIST_AVAILABLE_TECHNOLOGY_PROJECT_IDS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use NASA_FETCH_API_SWAGGER_SPECIFICATION instead.")
    def NASA_RESOURCE_GET_SPECIFICATION(cls) -> "Action":
        return cls.NASA_FETCH_API_SWAGGER_SPECIFICATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_LIST_APP_PERMISSIONS_ON_A_TEAM instead.")
    def SLACK_APPS_PERMISSIONS_LIST_PERMISSIONS(cls) -> "Action":
        return cls.SLACK_LIST_APP_PERMISSIONS_ON_A_TEAM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM instead.")
    def SLACK_APPS_PERMISSIONS_SCOPES_GET_LIST(cls) -> "Action":
        return cls.SLACK_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL instead.")
    def SLACK_CHAT_POST_MESSAGE(cls) -> "Action":
        return cls.SLACK_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_RETRIEVE_CONVERSATION_INFORMATION instead.")
    def SLACK_CONVERSATIONS_INFO(cls) -> "Action":
        return cls.SLACK_RETRIEVE_CONVERSATION_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated(
        "Use SLACK_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS instead."
    )
    def SLACK_CONVERSATIONS_LIST(cls) -> "Action":
        return cls.SLACK_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_CREATE_A_REMINDER instead.")
    def SLACK_REMINDERS_ADD(cls) -> "Action":
        return cls.SLACK_CREATE_A_REMINDER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_SEARCH_FOR_MESSAGES_WITH_QUERY instead.")
    def SLACK_SEARCH_MESSAGES(cls) -> "Action":
        return cls.SLACK_SEARCH_FOR_MESSAGES_WITH_QUERY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_RETRIEVE_DETAILED_USER_INFORMATION instead.")
    def SLACK_USERS_INFO(cls) -> "Action":
        return cls.SLACK_RETRIEVE_DETAILED_USER_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION instead.")
    def SLACK_USERS_LIST(cls) -> "Action":
        return cls.SLACK_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_FIND_USER_BY_EMAIL_ADDRESS instead.")
    def SLACK_USERS_LOOKUP_BY_EMAIL(cls) -> "Action":
        return cls.SLACK_FIND_USER_BY_EMAIL_ADDRESS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACK_RETRIEVE_USER_PROFILE_INFORMATION instead.")
    def SLACK_USERS_PROFILE_GET_PROFILE_INFO(cls) -> "Action":
        return cls.SLACK_RETRIEVE_USER_PROFILE_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_LIST_APP_PERMISSIONS_ON_A_TEAM instead.")
    def SLACKBOT_APPS_PERMISSIONS_LIST_PERMISSIONS(cls) -> "Action":
        return cls.SLACKBOT_LIST_APP_PERMISSIONS_ON_A_TEAM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM instead.")
    def SLACKBOT_APPS_PERMISSIONS_SCOPES_GET_LIST(cls) -> "Action":
        return cls.SLACKBOT_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL instead.")
    def SLACKBOT_CHAT_POST_MESSAGE(cls) -> "Action":
        return cls.SLACKBOT_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_RETRIEVE_CONVERSATION_INFORMATION instead.")
    def SLACKBOT_CONVERSATIONS_INFO(cls) -> "Action":
        return cls.SLACKBOT_RETRIEVE_CONVERSATION_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated(
        "Use SLACKBOT_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS instead."
    )
    def SLACKBOT_CONVERSATIONS_LIST(cls) -> "Action":
        return cls.SLACKBOT_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_CREATE_A_REMINDER instead.")
    def SLACKBOT_REMINDERS_ADD(cls) -> "Action":
        return cls.SLACKBOT_CREATE_A_REMINDER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_SEARCH_FOR_MESSAGES_WITH_QUERY instead.")
    def SLACKBOT_SEARCH_MESSAGES(cls) -> "Action":
        return cls.SLACKBOT_SEARCH_FOR_MESSAGES_WITH_QUERY

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_RETRIEVE_DETAILED_USER_INFORMATION instead.")
    def SLACKBOT_USERS_INFO(cls) -> "Action":
        return cls.SLACKBOT_RETRIEVE_DETAILED_USER_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION instead.")
    def SLACKBOT_USERS_LIST(cls) -> "Action":
        return cls.SLACKBOT_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_FIND_USER_BY_EMAIL_ADDRESS instead.")
    def SLACKBOT_USERS_LOOKUP_BY_EMAIL(cls) -> "Action":
        return cls.SLACKBOT_FIND_USER_BY_EMAIL_ADDRESS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SLACKBOT_RETRIEVE_USER_PROFILE_INFORMATION instead.")
    def SLACKBOT_USERS_PROFILE_GET_PROFILE_INFO(cls) -> "Action":
        return cls.SLACKBOT_RETRIEVE_USER_PROFILE_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_ADD_ITEMS_TO_PLAYLIST instead.")
    def SPOTIFY_ADD_TRACKS_TO_PLAYLIST(cls) -> "Action":
        return cls.SPOTIFY_ADD_ITEMS_TO_PLAYLIST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_CURRENT_USER_S_PLAYLISTS instead.")
    def SPOTIFY_GET_A_LIST_OF_CURRENT_USERS_PLAYLISTS(cls) -> "Action":
        return cls.SPOTIFY_GET_CURRENT_USER_S_PLAYLISTS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_SHOW_EPISODES instead.")
    def SPOTIFY_GET_A_SHOWS_EPISODES(cls) -> "Action":
        return cls.SPOTIFY_GET_SHOW_EPISODES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_ARTIST instead.")
    def SPOTIFY_GET_AN_ARTIST(cls) -> "Action":
        return cls.SPOTIFY_GET_ARTIST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_ARTIST_S_TOP_TRACKS instead.")
    def SPOTIFY_GET_AN_ARTISTS_TOP_TRACKS(cls) -> "Action":
        return cls.SPOTIFY_GET_ARTIST_S_TOP_TRACKS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_CURRENT_USER_S_PROFILE instead.")
    def SPOTIFY_GET_CURRENT_USERS_PROFILE(cls) -> "Action":
        return cls.SPOTIFY_GET_CURRENT_USER_S_PROFILE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_PLAYBACK_STATE instead.")
    def SPOTIFY_GET_INFORMATION_ABOUT_THE_USERS_CURRENT_PLAYBACK(cls) -> "Action":
        return cls.SPOTIFY_GET_PLAYBACK_STATE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_RECENTLY_PLAYED_TRACKS instead.")
    def SPOTIFY_GET_RECENTLY_PLAYED(cls) -> "Action":
        return cls.SPOTIFY_GET_RECENTLY_PLAYED_TRACKS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_USER_S_PROFILE instead.")
    def SPOTIFY_GET_USERS_PROFILE(cls) -> "Action":
        return cls.SPOTIFY_GET_USER_S_PROFILE

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_GET_USER_S_SAVED_TRACKS instead.")
    def SPOTIFY_GET_USERS_SAVED_TRACKS(cls) -> "Action":
        return cls.SPOTIFY_GET_USER_S_SAVED_TRACKS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_SEARCH_FOR_ITEM instead.")
    def SPOTIFY_SEARCH(cls) -> "Action":
        return cls.SPOTIFY_SEARCH_FOR_ITEM

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_SKIP_TO_NEXT instead.")
    def SPOTIFY_SKIP_USERS_PLAYBACK_TO_NEXT_TRACK(cls) -> "Action":
        return cls.SPOTIFY_SKIP_TO_NEXT

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use SPOTIFY_START_RESUME_PLAYBACK instead.")
    def SPOTIFY_START_A_USERS_PLAYBACK(cls) -> "Action":
        return cls.SPOTIFY_START_RESUME_PLAYBACK

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TASKADE_CREATE_PROJECT_TASKS_WITH_DETAILED_OPTIONS instead.")
    def TASKADE_CREATE_TASK_IN_PROJECT(cls) -> "Action":
        return cls.TASKADE_CREATE_PROJECT_TASKS_WITH_DETAILED_OPTIONS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TASKADE_GET_WORKSPACE_FOLDERS instead.")
    def TASKADE_GET_ALL_FOLDERS_FOR_WORKSPACE(cls) -> "Action":
        return cls.TASKADE_GET_WORKSPACE_FOLDERS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TASKADE_GET_MY_PROJECTS_WITH_SORTING_AND_PAGINATION instead.")
    def TASKADE_GET_ALL_PROJECTS_MINE(cls) -> "Action":
        return cls.TASKADE_GET_MY_PROJECTS_WITH_SORTING_AND_PAGINATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TASKADE_RETRIEVE_USER_S_WORKSPACES instead.")
    def TASKADE_GET_ALL_WORKSPACES_FOR_USER(cls) -> "Action":
        return cls.TASKADE_RETRIEVE_USER_S_WORKSPACES

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TASKADE_RETRIEVE_DETAILED_TASK_INFORMATION instead.")
    def TASKADE_GET_TASK_WITH_ID(cls) -> "Action":
        return cls.TASKADE_RETRIEVE_DETAILED_TASK_INFORMATION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_ACTIONS_BOARD_BY_ID_ACTION instead.")
    def TRELLO_ACTION_GET_BOARD_BY_ID_ACTION(cls) -> "Action":
        return cls.TRELLO_GET_ACTIONS_BOARD_BY_ID_ACTION

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_ADD_BOARDS instead.")
    def TRELLO_BOARD_CREATE_BOARD(cls) -> "Action":
        return cls.TRELLO_ADD_BOARDS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD_BY_FILTER instead.")
    def TRELLO_BOARD_FILTER_CARDS_BY_ID_BOARD(cls) -> "Action":
        return cls.TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD_BY_FILTER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_BOARDS_BY_ID_BOARD instead.")
    def TRELLO_BOARD_GET_BY_ID(cls) -> "Action":
        return cls.TRELLO_GET_BOARDS_BY_ID_BOARD

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD instead.")
    def TRELLO_BOARD_GET_CARDS_BY_ID_BOARD(cls) -> "Action":
        return cls.TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_ADD_CARDS instead.")
    def TRELLO_CARD_CREATE_AND_UPDATE(cls) -> "Action":
        return cls.TRELLO_ADD_CARDS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_CARDS_BY_ID_CARD_BY_FIELD instead.")
    def TRELLO_CARD_GET_BY_ID_FIELD(cls) -> "Action":
        return cls.TRELLO_GET_CARDS_BY_ID_CARD_BY_FIELD

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_UPDATE_CARDS_BY_ID_CARD instead.")
    def TRELLO_CARD_UPDATE_BY_ID_CARD(cls) -> "Action":
        return cls.TRELLO_UPDATE_CARDS_BY_ID_CARD

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_ADD_LISTS instead.")
    def TRELLO_LIST_CREATE_LIST(cls) -> "Action":
        return cls.TRELLO_ADD_LISTS

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_LISTS_CARDS_BY_ID_LIST instead.")
    def TRELLO_LIST_GET_CARDS_BY_ID_LIST(cls) -> "Action":
        return cls.TRELLO_GET_LISTS_CARDS_BY_ID_LIST

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_MEMBERS_BOARDS_BY_ID_MEMBER_BY_FILTER instead.")
    def TRELLO_MEMBER_GET_BOARDS(cls) -> "Action":
        return cls.TRELLO_GET_MEMBERS_BOARDS_BY_ID_MEMBER_BY_FILTER

    @classmethod  # type: ignore
    @property
    @te.deprecated("Use TRELLO_GET_TOKENS_MEMBER_BY_TOKEN instead.")
    def TRELLO_TOKEN_GET_MEMBER_BY_TOKEN(cls) -> "Action":
        return cls.TRELLO_GET_TOKENS_MEMBER_BY_TOKEN

    _deprecated: t.Dict = {
        "CLICKUP_ATTACHMENTS_UPLOAD_FILE_TO_TASK_AS_ATTACHMENT": "CLICKUP_CREATE_TASK_ATTACHMENT",
        "CLICKUP_AUTHORIZATION_GET_ACCESS_TOKEN": "CLICKUP_GET_ACCESS_TOKEN",
        "CLICKUP_FOLDERS_CREATE_NEW_FOLDER": "CLICKUP_CREATE_FOLDER",
        "CLICKUP_FOLDERS_GET_CONTENTS_OF": "CLICKUP_GET_FOLDERS",
        "CLICKUP_FOLDERS_GET_FOLDER_CONTENT": "CLICKUP_GET_FOLDER",
        "CLICKUP_LISTS_GET_FOLDER_LISTS": "CLICKUP_GET_LISTS",
        "CLICKUP_MEMBERS_GET_LIST_USERS": "CLICKUP_GET_LIST_MEMBERS",
        "CLICKUP_SPACES_GET_DETAILS": "CLICKUP_GET_SPACE",
        "CLICKUP_SPACES_GET_SPACE_DETAILS": "CLICKUP_GET_SPACES",
        "CLICKUP_TASK_CHECKLISTS_CREATE_NEW_CHECKLIST": "CLICKUP_CREATE_CHECKLIST",
        "CLICKUP_TASKS_GET_LIST_TASKS": "CLICKUP_GET_TASKS",
        "CLICKUP_TEAMS_USER_GROUPS_CREATE_TEAM": "CLICKUP_CREATE_TEAM",
        "CLICKUP_VIEWS_SPACE_VIEWS_GET": "CLICKUP_GET_SPACE_VIEWS",
        "DISCORD_CREATEGUILD": "DISCORD_CREATE_GUILD",
        "DISCORD_GETMESSAGE": "DISCORD_GET_MESSAGE",
        "DISCORD_GETMYAPPLICATION": "DISCORD_GET_MY_APPLICATION",
        "DISCORD_GETMYUSER": "DISCORD_GET_MY_USER",
        "ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIOFILE_V_1_DUBBING_POST": "ELEVENLABS_DUB_A_VIDEO_OR_AN_AUDIO_FILE",
        "ELEVENLABS_GET_MODELS_V_1_MODELS_GET": "ELEVENLABS_GET_MODELS",
        "ELEVENLABS_GET_USER_INFO_V_1_USER_GET": "ELEVENLABS_GET_USER_INFO",
        "ELEVENLABS_GET_VOICES_V_1_VOICES_GET": "ELEVENLABS_GET_VOICES",
        "GITHUB_ACTIVITY_LIST_REPO_S_STARRED_BY_AUTHENTICATED_USER": "GITHUB_LIST_REPOSITORIES_STARRED_BY_THE_AUTHENTICATED_USER",
        "GITHUB_EMO_J_IS_GET": "GITHUB_GET_EMOJIS",
        "GITHUB_GIST_S_CREATE": "GITHUB_CREATE_A_GIST",
        "GITHUB_GIST_S_LIST_PUBLIC": "GITHUB_LIST_PUBLIC_GISTS",
        "GITHUB_ISSUES_CREATE": "GITHUB_CREATE_AN_ISSUE",
        "GITHUB_ISSUES_CREATE_COMMENT": "GITHUB_CREATE_AN_ISSUE_COMMENT",
        "GITHUB_ISSUES_GET": "GITHUB_GET_AN_ISSUE",
        "GITHUB_ISSUES_LIST": "GITHUB_LIST_ISSUES_ASSIGNED_TO_THE_AUTHENTICATED_USER",
        "GITHUB_ISSUES_LIST_ASSIGN_EES": "GITHUB_LIST_ASSIGNEES",
        "GITHUB_ISSUES_LIST_EVENTS_FOR_REPO": "GITHUB_LIST_ISSUE_EVENTS_FOR_A_REPOSITORY",
        "GITHUB_PULLS_CHECK_IF_MERGED": "GITHUB_CHECK_IF_A_PULL_REQUEST_HAS_BEEN_MERGED",
        "GITHUB_PULLS_GET": "GITHUB_GET_A_PULL_REQUEST",
        "GITHUB_REPO_S_CREATE_FORK": "GITHUB_CREATE_A_FORK",
        "GITHUB_REPO_S_CREATE_IN_ORG": "GITHUB_CREATE_AN_ORGANIZATION_REPOSITORY",
        "GITHUB_REPO_S_CREATE_OR_UPDATE_FILE_CONTENTS": "GITHUB_CREATE_OR_UPDATE_FILE_CONTENTS",
        "GITHUB_REPO_S_GET_CODE_FREQUENCY_STATS": "GITHUB_GET_THE_WEEKLY_COMMIT_ACTIVITY",
        "GITHUB_REPO_S_GET_CONTRIBUTORS_STATS": "GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY",
        "GITHUB_REPO_S_LIST_BRANCHES": "GITHUB_LIST_BRANCHES",
        "GITHUB_REPO_S_LIST_COLLABORATORS": "GITHUB_LIST_REPOSITORY_COLLABORATORS",
        "GITHUB_REPO_S_LIST_COMMITS": "GITHUB_LIST_COMMITS",
        "GITHUB_REPO_S_LIST_CONTRIBUTORS": "GITHUB_LIST_REPOSITORY_CONTRIBUTORS",
        "GITHUB_REPO_S_LIST_FOR_AUTHENTICATED_USER": "GITHUB_LIST_REPOSITORIES_FOR_THE_AUTHENTICATED_USER",
        "GITHUB_REPO_S_LIST_FOR_USER": "GITHUB_LIST_REPOSITORIES_FOR_A_USER",
        "GITHUB_SECURITY_ADVISORIES_LIST_GLOBAL_ADVISORIES": "GITHUB_LIST_GLOBAL_SECURITY_ADVISORIES",
        "GITHUB_USERS_GET_CONTEXT_FOR_USER": "GITHUB_GET_CONTEXTUAL_INFORMATION_FOR_A_USER",
        "GITHUB_USERS_LIST_EMAILS_FOR_AUTHENTICATED_USER": "GITHUB_LIST_EMAIL_ADDRESSES_FOR_THE_AUTHENTICATED_USER",
        "GITHUB_USERS_LIST_FOLLOWERS_FOR_AUTHENTICATED_USER": "GITHUB_LIST_FOLLOWERS_OF_THE_AUTHENTICATED_USER",
        "NASA_ORGANIZATION_GET_INFORMATION": "NASA_GET_ORGANIZATION_DETAILS_AND_INFO",
        "NASA_ORGANIZATION_LIST_TYPES": "NASA_LIST_AVAILABLE_ORGANIZATION_TYPES",
        "NASA_PROJECT_FIND_MATCHING_PROJECTS": "NASA_FIND_PROJECTS_MATCHING_SEARCH_TERMS",
        "NASA_PROJECT_LIST_AVAILABLE_IDS": "NASA_LIST_AVAILABLE_TECHNOLOGY_PROJECT_IDS",
        "NASA_RESOURCE_GET_SPECIFICATION": "NASA_FETCH_API_SWAGGER_SPECIFICATION",
        "SLACK_APPS_PERMISSIONS_LIST_PERMISSIONS": "SLACK_LIST_APP_PERMISSIONS_ON_A_TEAM",
        "SLACK_APPS_PERMISSIONS_SCOPES_GET_LIST": "SLACK_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM",
        "SLACK_CHAT_POST_MESSAGE": "SLACK_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL",
        "SLACK_CONVERSATIONS_INFO": "SLACK_RETRIEVE_CONVERSATION_INFORMATION",
        "SLACK_CONVERSATIONS_LIST": "SLACK_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS",
        "SLACK_REMINDERS_ADD": "SLACK_CREATE_A_REMINDER",
        "SLACK_SEARCH_MESSAGES": "SLACK_SEARCH_FOR_MESSAGES_WITH_QUERY",
        "SLACK_USERS_INFO": "SLACK_RETRIEVE_DETAILED_USER_INFORMATION",
        "SLACK_USERS_LIST": "SLACK_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION",
        "SLACK_USERS_LOOKUP_BY_EMAIL": "SLACK_FIND_USER_BY_EMAIL_ADDRESS",
        "SLACK_USERS_PROFILE_GET_PROFILE_INFO": "SLACK_RETRIEVE_USER_PROFILE_INFORMATION",
        "SLACKBOT_APPS_PERMISSIONS_LIST_PERMISSIONS": "SLACKBOT_LIST_APP_PERMISSIONS_ON_A_TEAM",
        "SLACKBOT_APPS_PERMISSIONS_SCOPES_GET_LIST": "SLACKBOT_LIST_APP_PERMISSIONS_SCOPES_ON_A_TEAM",
        "SLACKBOT_CHAT_POST_MESSAGE": "SLACKBOT_SENDS_A_MESSAGE_TO_A_SLACK_CHANNEL",
        "SLACKBOT_CONVERSATIONS_INFO": "SLACKBOT_RETRIEVE_CONVERSATION_INFORMATION",
        "SLACKBOT_CONVERSATIONS_LIST": "SLACKBOT_LIST_ALL_SLACK_TEAM_CHANNELS_WITH_VARIOUS_FILTERS",
        "SLACKBOT_REMINDERS_ADD": "SLACKBOT_CREATE_A_REMINDER",
        "SLACKBOT_SEARCH_MESSAGES": "SLACKBOT_SEARCH_FOR_MESSAGES_WITH_QUERY",
        "SLACKBOT_USERS_INFO": "SLACKBOT_RETRIEVE_DETAILED_USER_INFORMATION",
        "SLACKBOT_USERS_LIST": "SLACKBOT_LIST_ALL_SLACK_TEAM_USERS_WITH_PAGINATION",
        "SLACKBOT_USERS_LOOKUP_BY_EMAIL": "SLACKBOT_FIND_USER_BY_EMAIL_ADDRESS",
        "SLACKBOT_USERS_PROFILE_GET_PROFILE_INFO": "SLACKBOT_RETRIEVE_USER_PROFILE_INFORMATION",
        "SPOTIFY_ADD_TRACKS_TO_PLAYLIST": "SPOTIFY_ADD_ITEMS_TO_PLAYLIST",
        "SPOTIFY_GET_A_LIST_OF_CURRENT_USERS_PLAYLISTS": "SPOTIFY_GET_CURRENT_USER_S_PLAYLISTS",
        "SPOTIFY_GET_A_SHOWS_EPISODES": "SPOTIFY_GET_SHOW_EPISODES",
        "SPOTIFY_GET_AN_ARTIST": "SPOTIFY_GET_ARTIST",
        "SPOTIFY_GET_AN_ARTISTS_TOP_TRACKS": "SPOTIFY_GET_ARTIST_S_TOP_TRACKS",
        "SPOTIFY_GET_CURRENT_USERS_PROFILE": "SPOTIFY_GET_CURRENT_USER_S_PROFILE",
        "SPOTIFY_GET_INFORMATION_ABOUT_THE_USERS_CURRENT_PLAYBACK": "SPOTIFY_GET_PLAYBACK_STATE",
        "SPOTIFY_GET_RECENTLY_PLAYED": "SPOTIFY_GET_RECENTLY_PLAYED_TRACKS",
        "SPOTIFY_GET_USERS_PROFILE": "SPOTIFY_GET_USER_S_PROFILE",
        "SPOTIFY_GET_USERS_SAVED_TRACKS": "SPOTIFY_GET_USER_S_SAVED_TRACKS",
        "SPOTIFY_SEARCH": "SPOTIFY_SEARCH_FOR_ITEM",
        "SPOTIFY_SKIP_USERS_PLAYBACK_TO_NEXT_TRACK": "SPOTIFY_SKIP_TO_NEXT",
        "SPOTIFY_START_A_USERS_PLAYBACK": "SPOTIFY_START_RESUME_PLAYBACK",
        "TASKADE_CREATE_TASK_IN_PROJECT": "TASKADE_CREATE_PROJECT_TASKS_WITH_DETAILED_OPTIONS",
        "TASKADE_GET_ALL_FOLDERS_FOR_WORKSPACE": "TASKADE_GET_WORKSPACE_FOLDERS",
        "TASKADE_GET_ALL_PROJECTS_MINE": "TASKADE_GET_MY_PROJECTS_WITH_SORTING_AND_PAGINATION",
        "TASKADE_GET_ALL_WORKSPACES_FOR_USER": "TASKADE_RETRIEVE_USER_S_WORKSPACES",
        "TASKADE_GET_TASK_WITH_ID": "TASKADE_RETRIEVE_DETAILED_TASK_INFORMATION",
        "TRELLO_ACTION_GET_BOARD_BY_ID_ACTION": "TRELLO_GET_ACTIONS_BOARD_BY_ID_ACTION",
        "TRELLO_BOARD_CREATE_BOARD": "TRELLO_ADD_BOARDS",
        "TRELLO_BOARD_FILTER_CARDS_BY_ID_BOARD": "TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD_BY_FILTER",
        "TRELLO_BOARD_GET_BY_ID": "TRELLO_GET_BOARDS_BY_ID_BOARD",
        "TRELLO_BOARD_GET_CARDS_BY_ID_BOARD": "TRELLO_GET_BOARDS_CARDS_BY_ID_BOARD",
        "TRELLO_CARD_CREATE_AND_UPDATE": "TRELLO_ADD_CARDS",
        "TRELLO_CARD_GET_BY_ID_FIELD": "TRELLO_GET_CARDS_BY_ID_CARD_BY_FIELD",
        "TRELLO_CARD_UPDATE_BY_ID_CARD": "TRELLO_UPDATE_CARDS_BY_ID_CARD",
        "TRELLO_LIST_CREATE_LIST": "TRELLO_ADD_LISTS",
        "TRELLO_LIST_GET_CARDS_BY_ID_LIST": "TRELLO_GET_LISTS_CARDS_BY_ID_LIST",
        "TRELLO_MEMBER_GET_BOARDS": "TRELLO_GET_MEMBERS_BOARDS_BY_ID_MEMBER_BY_FILTER",
        "TRELLO_TOKEN_GET_MEMBER_BY_TOKEN": "TRELLO_GET_TOKENS_MEMBER_BY_TOKEN",
    }

    @property
    def name(self) -> str:
        """Action name."""
        return self.load().name

    @property
    def app(self) -> str:
        """App name where the actions belongs to."""
        return self.load().app

    @property
    def tags(self) -> t.List[str]:
        """List of tags for action."""
        return self.load().tags

    @property
    def no_auth(self) -> bool:
        """If set `True` the action does not require authentication."""
        return self.load().no_auth

    @property
    def is_local(self) -> bool:
        """If set `True` the `app` is a local app."""
        return self.load().is_local

    @property
    def is_runtime(self) -> bool:
        """If set `True` the `app` is a runtime app."""
        return self.load().is_runtime

    @property
    def shell(self) -> bool:
        """If set `True` the tool will be executed using a shell."""
        return self.load().shell

    @classmethod  # type: ignore
    def add(cls, name: str, data: ActionData) -> None:
        """Add a new action."""
        add_runtime_action(name=name, data=data)
